/*************** Base States * */
.background { color: #3c3c3c; background-color: #cecece; }

.background:backdrop { color: #858585; background-color: #cecece; text-shadow: none; -gtk-icon-shadow: none; }

dnd { color: #3c3c3c; }

.normal-icons { -gtk-icon-size: 16px; }

.large-icons { -gtk-icon-size: 32px; }

image:disabled { -gtk-icon-filter: opacity(0.5); }

.view, iconview, .view text, iconview text, textview text { color: #212121; background-color: #fcfcfc; }

.view:backdrop, iconview:backdrop, .view text:backdrop, iconview text:backdrop, textview text:backdrop { color: #4c4c4c; background-color: #f9f9f9; }

.view:backdrop:disabled, label:disabled selection:backdrop, iconview:backdrop:disabled, .view text:backdrop:disabled, iconview text:backdrop:disabled, textview text:backdrop:disabled { color: #a8a8a8; }

.view:disabled, label:disabled selection.view, iconview:disabled, .view text:disabled, iconview text:disabled, textview text:disabled { color: #858585; background-color: #e0e0e0; }

.view:selected:focus, iconview:selected:focus, headerbar.selection-mode iconview.subtitle:focus:link, .view:selected, .selection-mode.titlebar:not(headerbar) .view.subtitle:link, headerbar.selection-mode .view.subtitle:link, iconview:selected, .selection-mode.titlebar:not(headerbar) iconview.subtitle:link, headerbar.selection-mode iconview.subtitle:link, textview text:selected:focus, textview headerbar.selection-mode text.subtitle:focus:link, headerbar.selection-mode textview text.subtitle:focus:link, .view text:selected, .view .selection-mode.titlebar:not(headerbar) text.subtitle:link, .selection-mode.titlebar:not(headerbar) .view text.subtitle:link, .view headerbar.selection-mode text.subtitle:link, headerbar.selection-mode .view text.subtitle:link, iconview text:selected, iconview .selection-mode.titlebar:not(headerbar) text.subtitle:link, .selection-mode.titlebar:not(headerbar) iconview text.subtitle:link, iconview headerbar.selection-mode text.subtitle:link, headerbar.selection-mode iconview text.subtitle:link, textview text:selected, textview .selection-mode.titlebar:not(headerbar) text.subtitle:link, .selection-mode.titlebar:not(headerbar) textview text.subtitle:link, textview headerbar.selection-mode text.subtitle:link, headerbar.selection-mode textview text.subtitle:link { border-radius: 3px; }

textview border { background-color: #e5e5e5; }

.rubberband, rubberband, .content-view rubberband, .content-view .rubberband, columnview.view rubberband, treeview.view rubberband, flowbox rubberband { border: 1px solid #1a74d3; background-color: rgba(26, 116, 211, 0.2); }

flowbox flowboxchild { padding: 3px; border-radius: 3px; }

flowbox flowboxchild:selected, flowbox .selection-mode.titlebar:not(headerbar) flowboxchild.subtitle:link, .selection-mode.titlebar:not(headerbar) flowbox flowboxchild.subtitle:link, flowbox headerbar.selection-mode flowboxchild.subtitle:link, headerbar.selection-mode flowbox flowboxchild.subtitle:link { outline-offset: -2px; }

.content-view .tile { margin: 2px; background-color: transparent; border-radius: 0; padding: 0; }

.content-view .tile:backdrop { background-color: transparent; }

.content-view .tile:active, .content-view .tile:selected, .content-view .selection-mode.titlebar:not(headerbar) .tile.subtitle:link, .selection-mode.titlebar:not(headerbar) .content-view .tile.subtitle:link, .content-view headerbar.selection-mode .tile.subtitle:link, headerbar.selection-mode .content-view .tile.subtitle:link { background-color: transparent; }

.content-view .tile:disabled, .content-view label:disabled selection.tile, label:disabled .content-view selection.tile { background-color: transparent; }

label { caret-color: currentColor; }

label.separator { color: #3c3c3c; }

label.separator:backdrop { color: #858585; }

label:disabled { color: #858585; }

button label:disabled { color: inherit; }

label:disabled:backdrop { color: #a8a8a8; }

button label:disabled:backdrop { color: inherit; }

label:backdrop selection { color: #7d7d7d; background-color: #d1d1d1; }

.dim-label, .titlebar:not(headerbar) .subtitle, headerbar .subtitle, label.separator { opacity: 0.55; text-shadow: none; }

assistant .sidebar { background-color: #fcfcfc; border-top: 1px solid #828282; }

assistant .sidebar:backdrop { background-color: #f9f9f9; border-color: #898989; }

assistant.csd .sidebar { border-top-style: none; }

assistant .sidebar label { padding: 6px 12px; }

assistant .sidebar label.highlight { background-color: #b1b1b1; }

.osd .scale-popup, .app-notification, .app-notification.frame, .csd popover.background.osd, popover.background.osd, .csd popover.background.touch-selection, .csd popover.background.magnifier, popover.background.touch-selection, popover.background.magnifier, .osd { color: #eeeeee; border: none; background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; outline-color: rgba(238, 238, 238, 0.3); text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; }

.osd .scale-popup:backdrop, .app-notification:backdrop, popover.background.osd:backdrop, popover.background.touch-selection:backdrop, popover.background.magnifier:backdrop, .osd:backdrop { color: shade(#eeeeee, 1.2); background-color: shade(rgba(34, 34, 34, 0.8), 1.6); text-shadow: none; -gtk-icon-shadow: none; }

/********************* Spinner Animation * */
@keyframes spin { to { transform: rotate(1turn); } }

spinner { background: none; opacity: 0; -gtk-icon-source: -gtk-icontheme("process-working-symbolic"); }

spinner:backdrop { color: #858585; }

spinner:checked { opacity: 1; animation: spin 1s linear infinite; }

spinner:checked:disabled, label:disabled selection:checked { opacity: 0.5; }

/********************** General Typography * */
.large-title { font-weight: 300; font-size: 24pt; }

.title-1 { font-weight: 800; font-size: 20pt; }

.title-2 { font-weight: 800; font-size: 15pt; }

.title-3 { font-weight: 700; font-size: 15pt; }

.title-4 { font-weight: 700; font-size: 13pt; }

.heading { font-weight: 700; font-size: 11pt; }

.body { font-weight: 400; font-size: 11pt; }

.caption-heading { font-weight: 700; font-size: 9pt; }

.caption { font-weight: 400; font-size: 9pt; }

/**************** Text Entries * */
spinbutton:not(.vertical), entry { min-height: 28px; padding-left: 4px; padding-right: 4px; border: 1px solid; border-radius: 3px; transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); color: #212121; border-color: #828282; background-color: #fcfcfc; box-shadow: inset 0 0 0 1px rgba(57, 142, 231, 0); }

spinbutton:not(.vertical) image.left, entry image.left { margin-right: 6px; }

spinbutton:not(.vertical) image.right, entry image.right { margin-left: 6px; }

spinbutton:not(.vertical) undershoot.left, entry undershoot.left { background-color: transparent; background-image: linear-gradient(to top, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%); padding-left: 1px; background-size: 1px 10px; background-repeat: repeat-y; background-origin: content-box; background-position: left center; border: none; box-shadow: none; }

spinbutton:not(.vertical) undershoot.right, entry undershoot.right { background-color: transparent; background-image: linear-gradient(to top, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%); padding-right: 1px; background-size: 1px 10px; background-repeat: repeat-y; background-origin: content-box; background-position: right center; border: none; box-shadow: none; }

label:disabled selection.flat, label:disabled selection:backdrop, spinbutton.flat:not(.vertical), entry.flat { min-height: 0; padding: 2px; background-color: transparent; border-color: transparent; border-radius: 0; }

spinbutton:focus-within:not(.vertical), entry:focus-within { border-color: #398ee7; }

spinbutton:disabled:not(.vertical), entry:disabled { color: #858585; border-color: #828282; background-color: #e0e0e0; box-shadow: none; }

spinbutton:backdrop:not(.vertical), entry:backdrop { color: #4c4c4c; border-color: #898989; background-color: #f9f9f9; box-shadow: none; transition: 200ms ease-out; }

spinbutton:backdrop:disabled:not(.vertical), label:disabled selection:backdrop, entry:backdrop:disabled { color: #a8a8a8; border-color: #898989; background-color: #e0e0e0; box-shadow: none; }

spinbutton.error:not(.vertical), entry.error { background-color: rgba(204, 0, 0, 0.1); color: #cc0000; text-shadow: none; border-color: entry_focus-within_border(#cc0000); }

spinbutton.error:focus-within:not(.vertical), entry.error:focus-within { border-color: #cc0000; }

spinbutton.error:not(.vertical) selection, entry.error selection { background-color: #cc0000; }

spinbutton.warning:not(.vertical), entry.warning { background-color: rgba(245, 121, 0, 0.1); color: #f57900; text-shadow: none; border-color: entry_focus-within_border(#f57900); }

spinbutton.warning:focus-within:not(.vertical), entry.warning:focus-within { border-color: #f57900; }

spinbutton.warning:not(.vertical) selection, entry.warning selection { background-color: #f57900; }

spinbutton:not(.vertical) image, entry image { color: #626262; }

spinbutton:not(.vertical) image:hover, entry image:hover { color: #3c3c3c; }

spinbutton:not(.vertical) image:active, entry image:active { color: #398ee7; }

spinbutton:not(.vertical) image:backdrop, entry image:backdrop { color: #9c9c9c; }

spinbutton:drop(active):not(.vertical), entry:drop(active):focus-within, entry:drop(active) { border-color: #4e9a06; box-shadow: inset 0 0 0 1px #4e9a06; }

.osd spinbutton:not(.vertical), .osd entry { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(0, 0, 0, 0.5); background-clip: padding-box; box-shadow: none; text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; }

.osd spinbutton:backdrop:not(.vertical), .osd entry:backdrop { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(0, 0, 0, 0.5); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

.osd spinbutton:disabled:not(.vertical), .osd entry:disabled { color: #888888; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

spinbutton:not(.vertical) progress, entry progress { margin: 2px -6px; background-color: transparent; background-image: none; border-radius: 0; border-width: 0 0 2px; border-color: #398ee7; border-style: solid; box-shadow: none; }

spinbutton:not(.vertical) progress:backdrop, entry progress:backdrop { background-color: transparent; }

.linked:not(.vertical) > spinbutton:focus-within:not(.vertical) + spinbutton:not(.vertical), .linked:not(.vertical) > spinbutton:focus-within:not(.vertical) + button, .linked:not(.vertical) > spinbutton:focus-within:not(.vertical) + combobox > box > button.combo, .linked:not(.vertical) > spinbutton:focus-within:not(.vertical) + entry, .linked:not(.vertical) > entry:focus-within + button, .linked:not(.vertical) > entry:focus-within + combobox > box > button.combo, .linked:not(.vertical) > entry:focus-within + spinbutton:not(.vertical), .linked:not(.vertical) > entry:focus-within + entry { border-left-color: entry_focus-within_border(); }

.linked:not(.vertical) > spinbutton:focus-within.error:not(.vertical) + spinbutton:not(.vertical), .linked:not(.vertical) > spinbutton:focus-within.error:not(.vertical) + button, .linked:not(.vertical) > spinbutton:focus-within.error:not(.vertical) + combobox > box > button.combo, .linked:not(.vertical) > spinbutton:focus-within.error:not(.vertical) + entry, .linked:not(.vertical) > entry:focus-within.error + button, .linked:not(.vertical) > entry:focus-within.error + combobox > box > button.combo, .linked:not(.vertical) > entry:focus-within.error + spinbutton:not(.vertical), .linked:not(.vertical) > entry:focus-within.error + entry { border-left-color: entry_focus-within_border(#cc0000); }

.linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + spinbutton:not(.vertical), .linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + button, .linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + combobox > box > button.combo, .linked:not(.vertical) > spinbutton:drop(active):not(.vertical) + entry, .linked:not(.vertical) > entry:drop(active) + button, .linked:not(.vertical) > entry:drop(active) + combobox > box > button.combo, .linked:not(.vertical) > entry:drop(active) + spinbutton:not(.vertical), .linked:not(.vertical) > entry:drop(active) + entry { border-left-color: #4e9a06; }

.linked.vertical > spinbutton:not(:disabled):not(.vertical) + entry:not(:disabled), .linked.vertical > spinbutton:not(:disabled):not(.vertical) + spinbutton:not(:disabled):not(.vertical), .linked.vertical > entry:not(:disabled) + entry:not(:disabled), .linked.vertical > entry:not(:disabled) + spinbutton:not(:disabled):not(.vertical) { border-top-color: #d7d7d7; background-color: #fcfcfc; }

.linked.vertical > spinbutton:not(:disabled):not(.vertical) + entry:not(:disabled):backdrop, .linked.vertical > spinbutton:not(:disabled):not(.vertical) + spinbutton:not(:disabled):backdrop:not(.vertical), .linked.vertical > entry:not(:disabled) + entry:not(:disabled):backdrop, .linked.vertical > entry:not(:disabled) + spinbutton:not(:disabled):backdrop:not(.vertical) { border-top-color: #d8d8d8; background-color: #f9f9f9; }

.linked.vertical > spinbutton:disabled:not(.vertical) + spinbutton:disabled:not(.vertical), .linked.vertical > spinbutton:disabled:not(.vertical) + entry:disabled, .linked.vertical > entry:disabled + spinbutton:disabled:not(.vertical), .linked.vertical > entry:disabled + entry:disabled { border-top-color: #d7d7d7; }

.linked.vertical > spinbutton:not(.vertical) + spinbutton:focus-within:not(:only-child):not(.vertical), .linked.vertical > spinbutton:not(.vertical) + entry:focus-within:not(:only-child), .linked.vertical > entry + spinbutton:focus-within:not(:only-child):not(.vertical), .linked.vertical > entry + entry:focus-within:not(:only-child) { border-top-color: entry_focus-within_border(); }

.linked.vertical > spinbutton:not(.vertical) + spinbutton:focus-within.error:not(:only-child):not(.vertical), .linked.vertical > spinbutton:not(.vertical) + entry:focus-within.error:not(:only-child), .linked.vertical > entry + spinbutton:focus-within.error:not(:only-child):not(.vertical), .linked.vertical > entry + entry:focus-within.error:not(:only-child) { border-top-color: entry_focus-within_border(#cc0000); }

.linked.vertical > spinbutton:not(.vertical) + spinbutton:drop(active):not(:only-child):not(.vertical), .linked.vertical > spinbutton:not(.vertical) + entry:drop(active):not(:only-child), .linked.vertical > entry + spinbutton:drop(active):not(:only-child):not(.vertical), .linked.vertical > entry + entry:drop(active):not(:only-child) { border-top-color: #4e9a06; }

.linked.vertical > spinbutton:focus-within:not(:only-child):not(.vertical) + spinbutton:not(.vertical), .linked.vertical > spinbutton:focus-within:not(:only-child):not(.vertical) + entry, .linked.vertical > spinbutton:focus-within:not(:only-child):not(.vertical) + button, .linked.vertical > spinbutton:focus-within:not(:only-child):not(.vertical) + combobox > box > button.combo, .linked.vertical > entry:focus-within:not(:only-child) + spinbutton:not(.vertical), .linked.vertical > entry:focus-within:not(:only-child) + entry, .linked.vertical > entry:focus-within:not(:only-child) + button, .linked.vertical > entry:focus-within:not(:only-child) + combobox > box > button.combo { border-top-color: entry_focus-within_border(); }

.linked.vertical > spinbutton:focus-within.error:not(:only-child):not(.vertical) + spinbutton:not(.vertical), .linked.vertical > spinbutton:focus-within.error:not(:only-child):not(.vertical) + entry, .linked.vertical > spinbutton:focus-within.error:not(:only-child):not(.vertical) + button, .linked.vertical > spinbutton:focus-within.error:not(:only-child):not(.vertical) + combobox > box > button.combo, .linked.vertical > entry:focus-within.error:not(:only-child) + spinbutton:not(.vertical), .linked.vertical > entry:focus-within.error:not(:only-child) + entry, .linked.vertical > entry:focus-within.error:not(:only-child) + button, .linked.vertical > entry:focus-within.error:not(:only-child) + combobox > box > button.combo { border-top-color: entry_focus-within_border(#cc0000); }

.linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + spinbutton:not(.vertical), .linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + entry, .linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + button, .linked.vertical > spinbutton:drop(active):not(:only-child):not(.vertical) + combobox > box > button.combo, .linked.vertical > entry:drop(active):not(:only-child) + spinbutton:not(.vertical), .linked.vertical > entry:drop(active):not(:only-child) + entry, .linked.vertical > entry:drop(active):not(:only-child) + button, .linked.vertical > entry:drop(active):not(:only-child) + combobox > box > button.combo { border-top-color: #4e9a06; }

treeview entry:focus-within:dir(rtl), treeview entry:focus-within:dir(ltr) { background-color: #fcfcfc; transition-property: color, background; }

treeview entry.flat, treeview entry { border-radius: 0; background-image: none; background-color: #fcfcfc; }

treeview entry.flat:focus-within, treeview entry:focus-within { border-color: #398ee7; }

/******************* Editable Labels * */
editablelabel > stack > text { color: #212121; border-color: #828282; background-color: #fcfcfc; box-shadow: inset 0 0 0 1px rgba(57, 142, 231, 0); }

/*********** Buttons * */
@keyframes needs_attention { from { background-image: -gtk-gradient(radial, center center, 0, center center, 0.01, to(#398ee7), to(transparent)); }
  to { background-image: -gtk-gradient(radial, center center, 0, center center, 0.5, to(#398ee7), to(transparent)); } }

notebook > header > tabs > arrow, windowcontrols button, dropdown:drop(active) button.combo, combobox:drop(active) button.combo, button { min-height: 24px; min-width: 22px; padding: 1px 2px; border: 1px solid; border-radius: 3px; transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); color: #3c3c3c; outline-color: rgba(60, 60, 60, 0.3); border-top-color: shade(#cecece, 0.8); border-right-color: shade(#cecece, 0.72); border-left-color: shade(#cecece, 0.72); border-bottom-color: shade(#cecece, 0.7); background-image: linear-gradient(to bottom, shade(shade(#cecece, 1.02), 1.05), shade(shade(#cecece, 1.02), 0.97)); box-shadow: inset 0 1px rgba(255, 255, 255, 0.6); }

notebook > header > tabs > arrow.flat, dropdown:drop(active) button.flat.combo, dropdown:drop(active) button.combo.sidebar-button, combobox:drop(active) button.flat.combo, combobox:drop(active) button.combo.sidebar-button, button.flat, button.sidebar-button { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; transition: none; }

notebook > header > tabs > arrow.flat:hover, dropdown:drop(active) button.flat.combo:hover, dropdown:drop(active) button.combo.sidebar-button:hover, combobox:drop(active) button.flat.combo:hover, combobox:drop(active) button.combo.sidebar-button:hover, button.flat:hover, button.sidebar-button:hover { transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); transition-duration: 500ms; }

notebook > header > tabs > arrow.flat:hover:active, dropdown:drop(active) button.flat.combo:hover:active, dropdown:drop(active) button.combo.sidebar-button:hover:active, combobox:drop(active) button.flat.combo:hover:active, combobox:drop(active) button.combo.sidebar-button:hover:active, button.flat:hover:active, button.sidebar-button:hover:active { transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

notebook > header > tabs > arrow:hover, dropdown:drop(active) button.combo:hover, combobox:drop(active) button.combo:hover, button:hover { color: #3c3c3c; outline-color: rgba(60, 60, 60, 0.3); border-color: #828282; background-image: linear-gradient(to bottom, shade(#cecece, 1.15), shade(#cecece, 1.07)); box-shadow: inset 0 1px rgba(255, 255, 255, 0.6); -gtk-icon-effect: highlight; }

notebook > header > tabs > arrow:active, dropdown:drop(active) button.combo:active, combobox:drop(active) button.combo:active, notebook > header > tabs > arrow:checked, dropdown:drop(active) button.combo:checked, combobox:drop(active) button.combo:checked, button:active, button:checked { color: #3c3c3c; outline-color: rgba(60, 60, 60, 0.3); border-color: #828282; background-image: linear-gradient(to bottom, shade(shade(#cecece, 0.85), 1.05), shade(shade(#cecece, 0.85), 0.97)); box-shadow: inset 0 2px 1px -2px rgba(0, 0, 0, 0.6); transition-duration: 50ms; }

popover.background checkbutton:backdrop, popover.background radiobutton:backdrop, notebook > header > tabs > arrow:backdrop, dropdown:drop(active) button.combo:backdrop, combobox:drop(active) button.combo:backdrop, popover.background checkbutton:backdrop, popover.background radiobutton:backdrop, button:backdrop.flat, popover.background checkbutton:backdrop, popover.background radiobutton:backdrop, button:backdrop { border-color: #898989; background-color: #cecece; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); transition: 200ms ease-out; -gtk-icon-effect: none; }

popover.background checkbutton:backdrop label, popover.background radiobutton:backdrop label, popover.background checkbutton:backdrop, popover.background radiobutton:backdrop, notebook > header > tabs > arrow:backdrop label, dropdown:drop(active) button.combo:backdrop label, combobox:drop(active) button.combo:backdrop label, notebook > header > tabs > arrow:backdrop, dropdown:drop(active) button.combo:backdrop, combobox:drop(active) button.combo:backdrop, popover.background checkbutton:backdrop label, popover.background radiobutton:backdrop label, popover.background checkbutton:backdrop, popover.background radiobutton:backdrop, button:backdrop.flat label, popover.background checkbutton:backdrop label, popover.background radiobutton:backdrop label, button:backdrop.flat, popover.background checkbutton:backdrop, popover.background radiobutton:backdrop, button:backdrop label, button:backdrop { color: #858585; }

popover.background checkbutton:backdrop:active, popover.background radiobutton:backdrop:active, popover.background checkbutton:backdrop:checked, popover.background radiobutton:backdrop:checked, notebook > header > tabs > arrow:backdrop:active, dropdown:drop(active) button.combo:backdrop:active, combobox:drop(active) button.combo:backdrop:active, notebook > header > tabs > arrow:backdrop:checked, dropdown:drop(active) button.combo:backdrop:checked, combobox:drop(active) button.combo:backdrop:checked, button:backdrop.flat:active, button:backdrop.flat:checked, button:backdrop:active, button:backdrop:checked { border-color: #898989; background-color: #b6b6b6; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

popover.background checkbutton:backdrop:active label, popover.background radiobutton:backdrop:active label, popover.background checkbutton:backdrop:active, popover.background radiobutton:backdrop:active, popover.background checkbutton:backdrop:checked label, popover.background radiobutton:backdrop:checked label, popover.background checkbutton:backdrop:checked, popover.background radiobutton:backdrop:checked, notebook > header > tabs > arrow:backdrop:active label, dropdown:drop(active) button.combo:backdrop:active label, combobox:drop(active) button.combo:backdrop:active label, notebook > header > tabs > arrow:backdrop:active, dropdown:drop(active) button.combo:backdrop:active, combobox:drop(active) button.combo:backdrop:active, notebook > header > tabs > arrow:backdrop:checked label, dropdown:drop(active) button.combo:backdrop:checked label, combobox:drop(active) button.combo:backdrop:checked label, notebook > header > tabs > arrow:backdrop:checked, dropdown:drop(active) button.combo:backdrop:checked, combobox:drop(active) button.combo:backdrop:checked, button:backdrop.flat:active label, button:backdrop.flat:active, button:backdrop.flat:checked label, button:backdrop.flat:checked, button:backdrop:active label, button:backdrop:active, button:backdrop:checked label, button:backdrop:checked { color: #858585; }

popover.background checkbutton:backdrop:disabled, popover.background radiobutton:backdrop:disabled, label:disabled selection.flat, notebook > header > tabs > arrow:backdrop:disabled, dropdown:drop(active) button.combo:backdrop:disabled, combobox:drop(active) button.combo:backdrop:disabled, label:disabled selection:backdrop, button:backdrop.flat:disabled, button:backdrop:disabled { border-color: #898989; background-color: #e0e0e0; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

popover.background checkbutton:backdrop:disabled label, popover.background radiobutton:backdrop:disabled label, label:disabled selection.flat label, popover.background checkbutton:backdrop:disabled, popover.background radiobutton:backdrop:disabled, label:disabled selection.flat, notebook > header > tabs > arrow:backdrop:disabled label, dropdown:drop(active) button.combo:backdrop:disabled label, combobox:drop(active) button.combo:backdrop:disabled label, label:disabled selection:backdrop label, notebook > header > tabs > arrow:backdrop:disabled, dropdown:drop(active) button.combo:backdrop:disabled, combobox:drop(active) button.combo:backdrop:disabled, label:disabled selection:backdrop, button:backdrop.flat:disabled label, button:backdrop.flat:disabled, button:backdrop:disabled label, button:backdrop:disabled { color: #a8a8a8; }

popover.background checkbutton:backdrop:disabled:active, popover.background radiobutton:backdrop:disabled:active, label:disabled selection.flat:active, popover.background checkbutton:backdrop:disabled:checked, popover.background radiobutton:backdrop:disabled:checked, label:disabled selection.flat:checked, notebook > header > tabs > arrow:backdrop:disabled:active, dropdown:drop(active) button.combo:backdrop:disabled:active, combobox:drop(active) button.combo:backdrop:disabled:active, label:disabled selection:backdrop:active, notebook > header > tabs > arrow:backdrop:disabled:checked, dropdown:drop(active) button.combo:backdrop:disabled:checked, combobox:drop(active) button.combo:backdrop:disabled:checked, label:disabled selection:backdrop:checked, button:backdrop.flat:disabled:active, button:backdrop.flat:disabled:checked, button:backdrop:disabled:active, button:backdrop:disabled:checked { border-color: #898989; background-color: lightgray; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

popover.background checkbutton:backdrop:disabled:active label, popover.background radiobutton:backdrop:disabled:active label, label:disabled selection.flat:active label, popover.background checkbutton:backdrop:disabled:checked label, popover.background radiobutton:backdrop:disabled:checked label, label:disabled selection.flat:checked label, notebook > header > tabs > arrow:backdrop:disabled:active label, label:disabled selection:backdrop:active label, notebook > header > tabs > arrow:backdrop:disabled:checked label, label:disabled selection:backdrop:checked label, button:backdrop.flat:disabled:active label, button:backdrop.flat:disabled:checked label, button:backdrop:disabled:active label, button:backdrop:disabled:checked label { color: #a8a8a8; }

notebook > header > tabs > arrow:disabled, dropdown:drop(active) button.combo:disabled, combobox:drop(active) button.combo:disabled, button:disabled { border-color: #828282; background-color: #e0e0e0; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); -gtk-icon-filter: opacity(0.5); }

notebook > header > tabs > arrow:disabled label, dropdown:drop(active) button.combo:disabled label, combobox:drop(active) button.combo:disabled label, notebook > header > tabs > arrow:disabled, dropdown:drop(active) button.combo:disabled, combobox:drop(active) button.combo:disabled, button:disabled label, button:disabled { color: #858585; }

notebook > header > tabs > arrow:disabled:active, dropdown:drop(active) button.combo:disabled:active, combobox:drop(active) button.combo:disabled:active, notebook > header > tabs > arrow:disabled:checked, dropdown:drop(active) button.combo:disabled:checked, combobox:drop(active) button.combo:disabled:checked, button:disabled:active, button:disabled:checked { border-color: #828282; background-image: linear-gradient(to bottom, #d7d7d7, #e0e0e0); box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

notebook > header > tabs > arrow:disabled:active label, dropdown:drop(active) button.combo:disabled:active label, combobox:drop(active) button.combo:disabled:active label, notebook > header > tabs > arrow:disabled:active, dropdown:drop(active) button.combo:disabled:active, combobox:drop(active) button.combo:disabled:active, notebook > header > tabs > arrow:disabled:checked label, dropdown:drop(active) button.combo:disabled:checked label, combobox:drop(active) button.combo:disabled:checked label, notebook > header > tabs > arrow:disabled:checked, dropdown:drop(active) button.combo:disabled:checked, combobox:drop(active) button.combo:disabled:checked, button:disabled:active label, button:disabled:active, button:disabled:checked label, button:disabled:checked { color: #858585; }

button.sidebar-button, notebook > header > tabs > arrow, windowcontrols button, .toolbar notebook > header > tabs > arrow, .toolbar dropdown:drop(active) button.combo, dropdown:drop(active) .toolbar button.combo, .toolbar combobox:drop(active) button.combo, combobox:drop(active) .toolbar button.combo, notebook > header > tabs > arrow.flat, dropdown:drop(active) button.flat.combo, dropdown:drop(active) button.combo.sidebar-button, combobox:drop(active) button.flat.combo, combobox:drop(active) button.combo.sidebar-button, .toolbar button, button.flat { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; transition: none; }

button.sidebar-button:hover, notebook > header > tabs > arrow:hover, windowcontrols button:hover, .toolbar dropdown:drop(active) button.combo:hover, dropdown:drop(active) .toolbar button.combo:hover, .toolbar combobox:drop(active) button.combo:hover, combobox:drop(active) .toolbar button.combo:hover, dropdown:drop(active) button.flat.combo:hover, dropdown:drop(active) button.combo.sidebar-button:hover, combobox:drop(active) button.flat.combo:hover, combobox:drop(active) button.combo.sidebar-button:hover, .toolbar button:hover, button.flat:hover { color: #3c3c3c; outline-color: rgba(60, 60, 60, 0.3); border-color: #828282; background-image: linear-gradient(to bottom, shade(#cecece, 1.15), shade(#cecece, 1.07)); box-shadow: inset 0 1px rgba(255, 255, 255, 0.6); transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); transition-duration: 500ms; }

button.keyboard-activating.sidebar-button, notebook > header > tabs > arrow.keyboard-activating, windowcontrols button.keyboard-activating, button.sidebar-button:active, notebook > header > tabs > arrow:active, windowcontrols button:active, button.sidebar-button:checked, notebook > header > tabs > arrow:checked, windowcontrols button:checked, .toolbar dropdown:drop(active) button.keyboard-activating.combo, dropdown:drop(active) .toolbar button.keyboard-activating.combo, .toolbar combobox:drop(active) button.keyboard-activating.combo, combobox:drop(active) .toolbar button.keyboard-activating.combo, .toolbar dropdown:drop(active) button.combo:active, dropdown:drop(active) .toolbar button.combo:active, .toolbar combobox:drop(active) button.combo:active, combobox:drop(active) .toolbar button.combo:active, .toolbar dropdown:drop(active) button.combo:checked, dropdown:drop(active) .toolbar button.combo:checked, .toolbar combobox:drop(active) button.combo:checked, combobox:drop(active) .toolbar button.combo:checked, dropdown:drop(active) button.flat.keyboard-activating.combo, dropdown:drop(active) button.keyboard-activating.combo.sidebar-button, combobox:drop(active) button.flat.keyboard-activating.combo, combobox:drop(active) button.keyboard-activating.combo.sidebar-button, dropdown:drop(active) button.flat.combo:active, dropdown:drop(active) button.combo.sidebar-button:active, combobox:drop(active) button.flat.combo:active, combobox:drop(active) button.combo.sidebar-button:active, dropdown:drop(active) button.flat.combo:checked, dropdown:drop(active) button.combo.sidebar-button:checked, combobox:drop(active) button.flat.combo:checked, combobox:drop(active) button.combo.sidebar-button:checked, .toolbar button.keyboard-activating, .toolbar button:active, .toolbar button:checked, button.flat.keyboard-activating, button.flat:active, button.flat:checked { color: #3c3c3c; outline-color: rgba(60, 60, 60, 0.3); border-color: #828282; background-image: linear-gradient(to bottom, shade(shade(#cecece, 0.85), 1.05), shade(shade(#cecece, 0.85), 0.97)); box-shadow: inset 0 2px 1px -2px rgba(0, 0, 0, 0.6); transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

button.sidebar-button:backdrop, notebook > header > tabs > arrow:backdrop, windowcontrols button:backdrop, button.sidebar-button:disabled, notebook > header > tabs > arrow:disabled, windowcontrols button:disabled, label:disabled selection:backdrop, .toolbar dropdown:drop(active) button.combo:backdrop, dropdown:drop(active) .toolbar button.combo:backdrop, .toolbar combobox:drop(active) button.combo:backdrop, combobox:drop(active) .toolbar button.combo:backdrop, .toolbar dropdown:drop(active) button.combo:disabled, dropdown:drop(active) .toolbar button.combo:disabled, .toolbar combobox:drop(active) button.combo:disabled, combobox:drop(active) .toolbar button.combo:disabled, dropdown:drop(active) button.flat.combo:backdrop, dropdown:drop(active) button.combo.sidebar-button:backdrop, combobox:drop(active) button.flat.combo:backdrop, combobox:drop(active) button.combo.sidebar-button:backdrop, dropdown:drop(active) button.flat.combo:disabled, dropdown:drop(active) button.combo.sidebar-button:disabled, combobox:drop(active) button.flat.combo:disabled, combobox:drop(active) button.combo.sidebar-button:disabled, label:disabled selection.flat, .toolbar button:backdrop, .toolbar button:disabled, .toolbar button:backdrop:disabled, button.flat:backdrop, button.flat:disabled, button.flat:backdrop:disabled { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; }

notebook > header > tabs > arrow.image-button, dropdown:drop(active) button.image-button.combo, combobox:drop(active) button.image-button.combo, button.image-button { min-height: 20px; min-width: 20px; padding: 2px; }

notebook > header > tabs > arrow.text-button, dropdown:drop(active) button.text-button.combo, combobox:drop(active) button.text-button.combo, button.text-button { padding-left: 8px; padding-right: 8px; }

notebook > header > tabs > arrow.text-button.image-button, dropdown:drop(active) button.text-button.image-button.combo, combobox:drop(active) button.text-button.image-button.combo, button.text-button.image-button { padding-left: 4px; padding-right: 4px; }

notebook > header > tabs > arrow.text-button.image-button label, dropdown:drop(active) button.text-button.image-button.combo label, combobox:drop(active) button.text-button.image-button.combo label, button.text-button.image-button label { padding-left: 4px; padding-right: 4px; }

notebook > header > tabs > arrow:drop(active), dropdown:drop(active) windowcontrols button.combo, windowcontrols dropdown:drop(active) button.combo, combobox:drop(active) windowcontrols button.combo, windowcontrols combobox:drop(active) button.combo, dropdown:drop(active) button.combo:drop(active), dropdown:drop(active) button.combo, dropdown:drop(active) combobox:drop(active) button.combo, combobox:drop(active) dropdown:drop(active) button.combo, combobox:drop(active) button.combo:drop(active), combobox:drop(active) button.combo, button:drop(active), dropdown:drop(active) button.combo, combobox:drop(active) button.combo { color: #4e9a06; border-color: #4e9a06; box-shadow: inset 0 0 0 1px #4e9a06; }

headerbar.selection-mode row.subtitle:link button.sidebar-button, row:selected button, .selection-mode.titlebar:not(headerbar) row.subtitle:link button, headerbar.selection-mode row.subtitle:link button { border-color: #0f4278; }

row:selected button.flat:not(:active):not(:checked):not(:hover):not(disabled), row:selected button.sidebar-button:not(:active):not(:checked):not(:hover):not(disabled), .selection-mode.titlebar:not(headerbar) row.subtitle:link button.flat:not(:active):not(:checked):not(:hover):not(disabled), .selection-mode.titlebar:not(headerbar) row.subtitle:link button.sidebar-button:not(:active):not(:checked):not(:hover):not(disabled), headerbar.selection-mode row.subtitle:link button.flat:not(:active):not(:checked):not(:hover):not(disabled), headerbar.selection-mode row.subtitle:link button.sidebar-button:not(:active):not(:checked):not(:hover):not(disabled) { color: #ffffff; border-color: transparent; }

row:selected button.flat:not(:active):not(:checked):not(:hover):not(disabled):backdrop, row:selected button.sidebar-button:not(:active):not(:checked):not(:hover):not(disabled):backdrop, .selection-mode.titlebar:not(headerbar) row.subtitle:link button.flat:not(:active):not(:checked):not(:hover):not(disabled):backdrop, .selection-mode.titlebar:not(headerbar) row.subtitle:link button.sidebar-button:not(:active):not(:checked):not(:hover):not(disabled):backdrop, headerbar.selection-mode row.subtitle:link button.flat:not(:active):not(:checked):not(:hover):not(disabled):backdrop, headerbar.selection-mode row.subtitle:link button.sidebar-button:not(:active):not(:checked):not(:hover):not(disabled):backdrop { color: #f9f9f9; }

button.osd { min-width: 24px; min-height: 32px; color: #eeeeee; border-radius: 5px; outline-color: rgba(238, 238, 238, 0.3); color: #eeeeee; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 238, 0.3); border: none; box-shadow: none; }

button.osd.image-button { min-width: 32px; }

button.osd:hover { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(65, 65, 65, 0.8); background-clip: padding-box; box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 238, 0.3); border: none; box-shadow: none; }

button.osd:active, button.osd:checked { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(0, 0, 0, 0.7); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; outline-color: rgba(238, 238, 238, 0.3); border: none; box-shadow: none; }

label:disabled selection.osd, button.osd:disabled:backdrop, button.osd:disabled { color: #888888; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; border: none; }

button.osd:backdrop { color: #eeeeee; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; border: none; }

.app-notification button, .app-notification.frame button, .csd popover.background.touch-selection button, .csd popover.background.magnifier button, popover.background.touch-selection button, popover.background.magnifier button, .osd button { color: #eeeeee; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 238, 0.3); }

.app-notification button:hover, popover.background.touch-selection button:hover, popover.background.magnifier button:hover, .osd button:hover { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(65, 65, 65, 0.8); background-clip: padding-box; box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 238, 0.3); }

.app-notification button:active, popover.background.touch-selection button:active, popover.background.magnifier button:active, .app-notification button:checked, popover.background.touch-selection button:checked, popover.background.magnifier button:checked, .osd button:active:backdrop, .osd button:active, .osd button:checked:backdrop, .osd button:checked { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(0, 0, 0, 0.7); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; outline-color: rgba(238, 238, 238, 0.3); }

.app-notification button:disabled, popover.background.touch-selection button:disabled, popover.background.magnifier button:disabled, .osd button:disabled:backdrop, .osd button:disabled { color: #888888; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

.app-notification button:backdrop, popover.background.touch-selection button:backdrop, popover.background.magnifier button:backdrop, .osd button:backdrop { color: #eeeeee; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

.app-notification button.flat, .app-notification button.sidebar-button, popover.background.touch-selection button.flat, popover.background.touch-selection button.sidebar-button, popover.background.magnifier button.flat, popover.background.magnifier button.sidebar-button, .osd button.flat, .osd button.sidebar-button { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; box-shadow: none; text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; }

.app-notification button.flat:hover, .app-notification button.sidebar-button:hover, popover.background.touch-selection button.flat:hover, popover.background.touch-selection button.sidebar-button:hover, popover.background.magnifier button.flat:hover, popover.background.magnifier button.sidebar-button:hover, .osd button.flat:hover, .osd button.sidebar-button:hover { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(65, 65, 65, 0.8); background-clip: padding-box; box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 238, 0.3); }

.app-notification button.flat:disabled, .app-notification button.sidebar-button:disabled, popover.background.touch-selection button.flat:disabled, popover.background.touch-selection button.sidebar-button:disabled, popover.background.magnifier button.flat:disabled, popover.background.magnifier button.sidebar-button:disabled, label:disabled selection.flat, .osd button.flat:disabled, .osd button.sidebar-button:disabled { color: #888888; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; background-image: none; border-color: transparent; box-shadow: none; }

.app-notification button.flat:backdrop, .app-notification button.sidebar-button:backdrop, popover.background.touch-selection button.flat:backdrop, popover.background.touch-selection button.sidebar-button:backdrop, popover.background.magnifier button.flat:backdrop, popover.background.magnifier button.sidebar-button:backdrop, .osd button.flat:backdrop, .osd button.sidebar-button:backdrop { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; }

.app-notification button.flat:active, .app-notification button.sidebar-button:active, popover.background.touch-selection button.flat:active, popover.background.touch-selection button.sidebar-button:active, popover.background.magnifier button.flat:active, popover.background.magnifier button.sidebar-button:active, .app-notification button.flat:checked, .app-notification button.sidebar-button:checked, popover.background.touch-selection button.flat:checked, popover.background.touch-selection button.sidebar-button:checked, popover.background.magnifier button.flat:checked, popover.background.magnifier button.sidebar-button:checked, .osd button.flat:active, .osd button.sidebar-button:active, .osd button.flat:checked, .osd button.sidebar-button:checked { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(0, 0, 0, 0.7); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; outline-color: rgba(238, 238, 238, 0.3); }

button.suggested-action { color: white; outline-color: rgba(255, 255, 255, 0.3); border-top-color: shade(#cecece, 0.8); border-right-color: shade(#cecece, 0.72); border-left-color: shade(#cecece, 0.72); border-bottom-color: shade(#cecece, 0.7); background-image: linear-gradient(to bottom, shade(shade(#398ee7, 1.02), 1.05), shade(shade(#398ee7, 1.02), 0.97)); box-shadow: inset 0 1px rgba(255, 255, 255, 0.4); }

button.suggested-action.sidebar-button, popover.background checkbutton.suggested-action, popover.background radiobutton.suggested-action, button.suggested-action.flat, popover.background checkbutton.suggested-action, popover.background radiobutton.suggested-action { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: #398ee7; }

button.suggested-action:hover { color: white; outline-color: rgba(255, 255, 255, 0.3); border-color: #114f8f; background-image: linear-gradient(to bottom, shade(#398ee7, 1.15), shade(#398ee7, 1.07)); box-shadow: inset 0 1px rgba(255, 255, 255, 0.4); }

button.suggested-action:active, button.suggested-action:checked { color: white; outline-color: rgba(255, 255, 255, 0.3); border-color: #114f8f; background-image: linear-gradient(to bottom, shade(shade(#398ee7, 0.85), 1.05), shade(shade(#398ee7, 0.85), 0.97)); box-shadow: inset 0 2px 1px -2px rgba(0, 0, 0, 0.6); }

popover.background checkbutton.suggested-action:backdrop, popover.background radiobutton.suggested-action:backdrop, button.suggested-action:backdrop, button.suggested-action.flat:backdrop { border-color: #398ee7; background-color: #398ee7; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

popover.background checkbutton.suggested-action:backdrop label, popover.background radiobutton.suggested-action:backdrop label, popover.background checkbutton.suggested-action:backdrop, popover.background radiobutton.suggested-action:backdrop, button.suggested-action:backdrop label, button.suggested-action:backdrop, button.suggested-action.flat:backdrop label, button.suggested-action.flat:backdrop { color: #d7e8fa; }

popover.background checkbutton.suggested-action:backdrop:active, popover.background radiobutton.suggested-action:backdrop:active, popover.background checkbutton.suggested-action:backdrop:checked, popover.background radiobutton.suggested-action:backdrop:checked, button.suggested-action:backdrop:active, button.suggested-action:backdrop:checked, button.suggested-action.flat:backdrop:active, button.suggested-action.flat:backdrop:checked { border-color: #1a74d3; background-color: #1a74d3; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

popover.background checkbutton.suggested-action:backdrop:active label, popover.background radiobutton.suggested-action:backdrop:active label, popover.background checkbutton.suggested-action:backdrop:active, popover.background radiobutton.suggested-action:backdrop:active, popover.background checkbutton.suggested-action:backdrop:checked label, popover.background radiobutton.suggested-action:backdrop:checked label, popover.background checkbutton.suggested-action:backdrop:checked, popover.background radiobutton.suggested-action:backdrop:checked, button.suggested-action:backdrop:active label, button.suggested-action:backdrop:active, button.suggested-action:backdrop:checked label, button.suggested-action:backdrop:checked, button.suggested-action.flat:backdrop:active label, button.suggested-action.flat:backdrop:active, button.suggested-action.flat:backdrop:checked label, button.suggested-action.flat:backdrop:checked { color: #d1e3f6; }

label:disabled selection:backdrop, popover.background checkbutton.suggested-action:backdrop:disabled, popover.background radiobutton.suggested-action:backdrop:disabled, button.suggested-action:backdrop:disabled, button.suggested-action.flat:backdrop:disabled { border-color: #898989; background-color: #e0e0e0; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

label:disabled selection:backdrop label, label:disabled selection:backdrop, popover.background checkbutton.suggested-action:backdrop:disabled label, popover.background radiobutton.suggested-action:backdrop:disabled label, popover.background checkbutton.suggested-action:backdrop:disabled, popover.background radiobutton.suggested-action:backdrop:disabled, button.suggested-action:backdrop:disabled label, button.suggested-action:backdrop:disabled, button.suggested-action.flat:backdrop:disabled label, button.suggested-action.flat:backdrop:disabled { color: #a8a8a8; }

label:disabled selection:backdrop:active, label:disabled selection:backdrop:checked, popover.background checkbutton.suggested-action:backdrop:disabled:active, popover.background radiobutton.suggested-action:backdrop:disabled:active, popover.background checkbutton.suggested-action:backdrop:disabled:checked, popover.background radiobutton.suggested-action:backdrop:disabled:checked, button.suggested-action:backdrop:disabled:active, button.suggested-action:backdrop:disabled:checked, button.suggested-action.flat:backdrop:disabled:active, button.suggested-action.flat:backdrop:disabled:checked { border-color: #3f92e7; background-color: #3f92e7; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

label:disabled selection:backdrop:active label, label:disabled selection:backdrop:checked label, popover.background checkbutton.suggested-action:backdrop:disabled:active label, popover.background radiobutton.suggested-action:backdrop:disabled:active label, popover.background checkbutton.suggested-action:backdrop:disabled:checked label, popover.background radiobutton.suggested-action:backdrop:disabled:checked label, button.suggested-action:backdrop:disabled:active label, button.suggested-action:backdrop:disabled:checked label, button.suggested-action.flat:backdrop:disabled:active label, button.suggested-action.flat:backdrop:disabled:checked label { color: #82b8f0; }

button.suggested-action.sidebar-button:backdrop, popover.background checkbutton.suggested-action:backdrop, popover.background radiobutton.suggested-action:backdrop, button.suggested-action.sidebar-button:disabled, popover.background checkbutton.suggested-action:disabled, popover.background radiobutton.suggested-action:disabled, label:disabled selection.flat, label:disabled selection:backdrop, button.suggested-action.flat:backdrop, button.suggested-action.flat:disabled, button.suggested-action.flat:backdrop:disabled { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: rgba(57, 142, 231, 0.8); }

label:disabled selection.suggested-action, button.suggested-action:disabled { border-color: #114f8f; background-color: #569fea; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

label:disabled selection.suggested-action label, label:disabled selection.suggested-action, button.suggested-action:disabled label, button.suggested-action:disabled { color: #abcff5; }

label:disabled selection.suggested-action:active, label:disabled selection.suggested-action:checked, button.suggested-action:disabled:active, button.suggested-action:disabled:checked { border-color: #114f8f; background-image: linear-gradient(to bottom, #3b8bde, #3f92e7); box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

label:disabled selection.suggested-action:active label, label:disabled selection.suggested-action:active, label:disabled selection.suggested-action:checked label, label:disabled selection.suggested-action:checked, button.suggested-action:disabled:active label, button.suggested-action:disabled:active, button.suggested-action:disabled:checked label, button.suggested-action:disabled:checked { color: #b2d3f5; }

.osd button.suggested-action { color: #eeeeee; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(57, 142, 231, 0.5); background-clip: padding-box; box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 238, 0.3); }

.osd button.suggested-action:hover { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(57, 142, 231, 0.7); background-clip: padding-box; box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 238, 0.3); }

.osd button.suggested-action:active:backdrop, .osd button.suggested-action:active, .osd button.suggested-action:checked:backdrop, .osd button.suggested-action:checked { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: #398ee7; background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; outline-color: rgba(238, 238, 238, 0.3); }

.osd label:disabled selection.suggested-action, label:disabled .osd selection.suggested-action, .osd button.suggested-action:disabled:backdrop, .osd button.suggested-action:disabled { color: #888888; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

.osd button.suggested-action:backdrop { color: #eeeeee; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(57, 142, 231, 0.5); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

button.destructive-action { color: white; outline-color: rgba(255, 255, 255, 0.3); border-top-color: shade(#cecece, 0.8); border-right-color: shade(#cecece, 0.72); border-left-color: shade(#cecece, 0.72); border-bottom-color: shade(#cecece, 0.7); background-image: linear-gradient(to bottom, shade(shade(#ef2929, 1.02), 1.05), shade(shade(#ef2929, 1.02), 0.97)); box-shadow: inset 0 1px rgba(255, 255, 255, 0.4); }

button.destructive-action.sidebar-button, popover.background checkbutton.destructive-action, popover.background radiobutton.destructive-action, button.destructive-action.flat, popover.background checkbutton.destructive-action, popover.background radiobutton.destructive-action { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: #ef2929; }

button.destructive-action:hover { color: white; outline-color: rgba(255, 255, 255, 0.3); border-color: #8e0b0b; background-image: linear-gradient(to bottom, shade(#ef2929, 1.15), shade(#ef2929, 1.07)); box-shadow: inset 0 1px rgba(255, 255, 255, 0.4); }

button.destructive-action:active, button.destructive-action:checked { color: white; outline-color: rgba(255, 255, 255, 0.3); border-color: #8e0b0b; background-image: linear-gradient(to bottom, shade(shade(#ef2929, 0.85), 1.05), shade(shade(#ef2929, 0.85), 0.97)); box-shadow: inset 0 2px 1px -2px rgba(0, 0, 0, 0.6); }

popover.background checkbutton.destructive-action:backdrop, popover.background radiobutton.destructive-action:backdrop, button.destructive-action:backdrop, button.destructive-action.flat:backdrop { border-color: #ef2929; background-color: #ef2929; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

popover.background checkbutton.destructive-action:backdrop label, popover.background radiobutton.destructive-action:backdrop label, popover.background checkbutton.destructive-action:backdrop, popover.background radiobutton.destructive-action:backdrop, button.destructive-action:backdrop label, button.destructive-action:backdrop, button.destructive-action.flat:backdrop label, button.destructive-action.flat:backdrop { color: #fcd4d4; }

popover.background checkbutton.destructive-action:backdrop:active, popover.background radiobutton.destructive-action:backdrop:active, popover.background checkbutton.destructive-action:backdrop:checked, popover.background radiobutton.destructive-action:backdrop:checked, button.destructive-action:backdrop:active, button.destructive-action:backdrop:checked, button.destructive-action.flat:backdrop:active, button.destructive-action.flat:backdrop:checked { border-color: #d51010; background-color: #d51010; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

popover.background checkbutton.destructive-action:backdrop:active label, popover.background radiobutton.destructive-action:backdrop:active label, popover.background checkbutton.destructive-action:backdrop:active, popover.background radiobutton.destructive-action:backdrop:active, popover.background checkbutton.destructive-action:backdrop:checked label, popover.background radiobutton.destructive-action:backdrop:checked label, popover.background checkbutton.destructive-action:backdrop:checked, popover.background radiobutton.destructive-action:backdrop:checked, button.destructive-action:backdrop:active label, button.destructive-action:backdrop:active, button.destructive-action:backdrop:checked label, button.destructive-action:backdrop:checked, button.destructive-action.flat:backdrop:active label, button.destructive-action.flat:backdrop:active, button.destructive-action.flat:backdrop:checked label, button.destructive-action.flat:backdrop:checked { color: #f7cfcf; }

label:disabled selection:backdrop, popover.background checkbutton.destructive-action:backdrop:disabled, popover.background radiobutton.destructive-action:backdrop:disabled, button.destructive-action:backdrop:disabled, button.destructive-action.flat:backdrop:disabled { border-color: #898989; background-color: #e0e0e0; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

label:disabled selection:backdrop label, label:disabled selection:backdrop, popover.background checkbutton.destructive-action:backdrop:disabled label, popover.background radiobutton.destructive-action:backdrop:disabled label, popover.background checkbutton.destructive-action:backdrop:disabled, popover.background radiobutton.destructive-action:backdrop:disabled, button.destructive-action:backdrop:disabled label, button.destructive-action:backdrop:disabled, button.destructive-action.flat:backdrop:disabled label, button.destructive-action.flat:backdrop:disabled { color: #a8a8a8; }

label:disabled selection:backdrop:active, label:disabled selection:backdrop:checked, popover.background checkbutton.destructive-action:backdrop:disabled:active, popover.background radiobutton.destructive-action:backdrop:disabled:active, popover.background checkbutton.destructive-action:backdrop:disabled:checked, popover.background radiobutton.destructive-action:backdrop:disabled:checked, button.destructive-action:backdrop:disabled:active, button.destructive-action:backdrop:disabled:checked, button.destructive-action.flat:backdrop:disabled:active, button.destructive-action.flat:backdrop:disabled:checked { border-color: #ef3131; background-color: #ef3131; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

label:disabled selection:backdrop:active label, label:disabled selection:backdrop:checked label, popover.background checkbutton.destructive-action:backdrop:disabled:active label, popover.background radiobutton.destructive-action:backdrop:disabled:active label, popover.background checkbutton.destructive-action:backdrop:disabled:checked label, popover.background radiobutton.destructive-action:backdrop:disabled:checked label, button.destructive-action:backdrop:disabled:active label, button.destructive-action:backdrop:disabled:checked label, button.destructive-action.flat:backdrop:disabled:active label, button.destructive-action.flat:backdrop:disabled:checked label { color: #f57979; }

button.destructive-action.sidebar-button:backdrop, popover.background checkbutton.destructive-action:backdrop, popover.background radiobutton.destructive-action:backdrop, button.destructive-action.sidebar-button:disabled, popover.background checkbutton.destructive-action:disabled, popover.background radiobutton.destructive-action:disabled, label:disabled selection.flat, label:disabled selection:backdrop, button.destructive-action.flat:backdrop, button.destructive-action.flat:disabled, button.destructive-action.flat:backdrop:disabled { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: rgba(239, 41, 41, 0.8); }

label:disabled selection.destructive-action, button.destructive-action:disabled { border-color: #8e0b0b; background-color: #f14949; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

label:disabled selection.destructive-action label, label:disabled selection.destructive-action, button.destructive-action:disabled label, button.destructive-action:disabled { color: #f8a4a4; }

label:disabled selection.destructive-action:active, label:disabled selection.destructive-action:checked, button.destructive-action:disabled:active, button.destructive-action:disabled:checked { border-color: #8e0b0b; background-image: linear-gradient(to bottom, #e52d2d, #ef3131); box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

label:disabled selection.destructive-action:active label, label:disabled selection.destructive-action:active, label:disabled selection.destructive-action:checked label, label:disabled selection.destructive-action:checked, button.destructive-action:disabled:active label, button.destructive-action:disabled:active, button.destructive-action:disabled:checked label, button.destructive-action:disabled:checked { color: #f9adad; }

.osd button.destructive-action { color: #eeeeee; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(239, 41, 41, 0.5); background-clip: padding-box; box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 238, 0.3); }

.osd button.destructive-action:hover { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(239, 41, 41, 0.7); background-clip: padding-box; box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 238, 0.3); }

.osd button.destructive-action:active:backdrop, .osd button.destructive-action:active, .osd button.destructive-action:checked:backdrop, .osd button.destructive-action:checked { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: #ef2929; background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; outline-color: rgba(238, 238, 238, 0.3); }

.osd label:disabled selection.destructive-action, label:disabled .osd selection.destructive-action, .osd button.destructive-action:disabled:backdrop, .osd button.destructive-action:disabled { color: #888888; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

.osd button.destructive-action:backdrop { color: #eeeeee; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(239, 41, 41, 0.5); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

.stack-switcher > button { outline-offset: -3px; }

.stack-switcher > button > label { padding-left: 6px; padding-right: 6px; }

.stack-switcher > button > image { padding-left: 6px; padding-right: 6px; padding-top: 3px; padding-bottom: 3px; }

.stack-switcher > button.text-button { padding-left: 10px; padding-right: 10px; }

.stack-switcher > button.image-button { padding-left: 2px; padding-right: 2px; }

.stack-switcher > button.needs-attention:active > label, .stack-switcher > button.needs-attention:active > image, .stack-switcher > button.needs-attention:checked > label, .stack-switcher > button.needs-attention:checked > image { animation: none; background-image: none; }

.inline-toolbar button, .inline-toolbar button:backdrop { border-radius: 2px; border-width: 1px; }

.inline-toolbar button button, .inline-toolbar button:backdrop button { padding-left: 4px; padding-right: 4px; }

.primary-toolbar button { -gtk-icon-shadow: none; }

button.circular { border-radius: 9999px; -gtk-outline-radius: 9999px; }

button.circular label { padding: 0; }

stacksidebar row.needs-attention > label, .stack-switcher > button.needs-attention > label, .stack-switcher > button.needs-attention > image { animation: needs_attention 150ms ease-in; background-image: radial-gradient(farthest-side, #398ee7 96%, rgba(57, 142, 231, 0)), radial-gradient(farthest-side, rgba(255, 255, 255, 0.769231) 95%, rgba(255, 255, 255, 0)); background-size: 6px 6px, 6px 6px; background-repeat: no-repeat; background-position: right 3px, right 4px; }

stacksidebar row.needs-attention > label:backdrop, .stack-switcher > button.needs-attention > label:backdrop, .stack-switcher > button.needs-attention > image:backdrop { background-size: 6px 6px, 0 0; }

stacksidebar row.needs-attention > label:dir(rtl), .stack-switcher > button.needs-attention > label:dir(rtl), .stack-switcher > button.needs-attention > image:dir(rtl) { background-position: left 3px, left 4px; }

.inline-toolbar toolbutton > button { color: #3c3c3c; outline-color: rgba(60, 60, 60, 0.3); border-top-color: shade(#cecece, 0.8); border-right-color: shade(#cecece, 0.72); border-left-color: shade(#cecece, 0.72); border-bottom-color: shade(#cecece, 0.7); background-image: linear-gradient(to bottom, shade(shade(#cecece, 1.02), 1.05), shade(shade(#cecece, 1.02), 0.97)); box-shadow: inset 0 1px rgba(255, 255, 255, 0.6); }

.inline-toolbar toolbutton > button:hover { color: #3c3c3c; outline-color: rgba(60, 60, 60, 0.3); border-color: #828282; background-image: linear-gradient(to bottom, shade(#cecece, 1.15), shade(#cecece, 1.07)); box-shadow: inset 0 1px rgba(255, 255, 255, 0.6); }

.inline-toolbar toolbutton > button:active, .inline-toolbar toolbutton > button:checked { color: #3c3c3c; outline-color: rgba(60, 60, 60, 0.3); border-color: #828282; background-image: linear-gradient(to bottom, shade(shade(#cecece, 0.85), 1.05), shade(shade(#cecece, 0.85), 0.97)); box-shadow: inset 0 2px 1px -2px rgba(0, 0, 0, 0.6); }

.inline-toolbar toolbutton > button:disabled { border-color: #828282; background-color: #e0e0e0; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.inline-toolbar toolbutton > button:disabled label, .inline-toolbar toolbutton > button:disabled { color: #858585; }

.inline-toolbar toolbutton > button:disabled:active, .inline-toolbar toolbutton > button:disabled:checked { border-color: #828282; background-image: linear-gradient(to bottom, #d7d7d7, #e0e0e0); box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.inline-toolbar toolbutton > button:disabled:active label, .inline-toolbar toolbutton > button:disabled:active, .inline-toolbar toolbutton > button:disabled:checked label, .inline-toolbar toolbutton > button:disabled:checked { color: #858585; }

.inline-toolbar toolbutton > button:backdrop { border-color: #898989; background-color: #cecece; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.inline-toolbar toolbutton > button:backdrop label, .inline-toolbar toolbutton > button:backdrop { color: #858585; }

.inline-toolbar toolbutton > button:backdrop:active, .inline-toolbar toolbutton > button:backdrop:checked { border-color: #898989; background-color: #b6b6b6; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.inline-toolbar toolbutton > button:backdrop:active label, .inline-toolbar toolbutton > button:backdrop:active, .inline-toolbar toolbutton > button:backdrop:checked label, .inline-toolbar toolbutton > button:backdrop:checked { color: #858585; }

.inline-toolbar toolbutton > button:backdrop:disabled, .inline-toolbar label:disabled toolbutton > selection:backdrop, label:disabled .inline-toolbar toolbutton > selection:backdrop { border-color: #898989; background-color: #e0e0e0; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.inline-toolbar toolbutton > button:backdrop:disabled label, .inline-toolbar label:disabled toolbutton > selection:backdrop label, label:disabled .inline-toolbar toolbutton > selection:backdrop label, .inline-toolbar toolbutton > button:backdrop:disabled, .inline-toolbar label:disabled toolbutton > selection:backdrop, label:disabled .inline-toolbar toolbutton > selection:backdrop { color: #a8a8a8; }

.inline-toolbar toolbutton > button:backdrop:disabled:active, .inline-toolbar label:disabled toolbutton > selection:backdrop:active, label:disabled .inline-toolbar toolbutton > selection:backdrop:active, .inline-toolbar toolbutton > button:backdrop:disabled:checked, .inline-toolbar label:disabled toolbutton > selection:backdrop:checked, label:disabled .inline-toolbar toolbutton > selection:backdrop:checked { border-color: #898989; background-color: lightgray; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.inline-toolbar toolbutton > button:backdrop:disabled:active label, .inline-toolbar label:disabled toolbutton > selection:backdrop:active label, label:disabled .inline-toolbar toolbutton > selection:backdrop:active label, .inline-toolbar toolbutton > button:backdrop:disabled:checked label, .inline-toolbar label:disabled toolbutton > selection:backdrop:checked label, label:disabled .inline-toolbar toolbutton > selection:backdrop:checked label { color: #a8a8a8; }

.linked > combobox > box > button.combo:dir(ltr), .linked > combobox > box > button.combo:dir(rtl), .linked:not(.vertical) > combobox:only-child > box > button.combo, .linked:not(.vertical) > combobox:last-child > box > button.combo, .linked:not(.vertical) > combobox:first-child > box > button.combo, dropdown.linked button:nth-child(2):dir(rtl), combobox.linked button:nth-child(2):dir(rtl), dropdown.linked button:nth-child(2):dir(ltr), combobox.linked button:nth-child(2):dir(ltr), .linked:not(.vertical) > spinbutton:not(.vertical), .linked:not(.vertical) > entry, .inline-toolbar button, .inline-toolbar button:backdrop, .linked:not(.vertical) > button, toolbar.inline-toolbar toolbutton > button.flat, toolbar.inline-toolbar toolbutton > button.sidebar-button { border-right-style: none; border-radius: 0; -gtk-outline-radius: 0; }

.linked.vertical > combobox:last-child > box > button.combo:dir(rtl), .linked:not(.vertical) > combobox:last-child > box > button.combo:dir(rtl), .linked.vertical > combobox:first-child > box > button.combo:dir(ltr), .linked:not(.vertical) > combobox:only-child > box > button.combo:first-child, .linked:not(.vertical) > combobox:last-child > box > button.combo:first-child, .linked:not(.vertical) > combobox:first-child > box > button.combo, dropdown.linked button:nth-child(2):dir(rtl), combobox.linked button:nth-child(2):dir(rtl), dropdown.linked button:first-child:nth-child(2):dir(ltr), combobox.linked button:first-child:nth-child(2):dir(ltr), .linked:not(.vertical) > spinbutton:first-child:not(.vertical), .linked:not(.vertical) > entry:first-child, .inline-toolbar button:first-child, .inline-toolbar .linked.vertical > combobox:first-child > box > button.combo, .inline-toolbar button:first-child:backdrop, .linked:not(.vertical) > button:first-child, .linked.vertical > combobox:first-child > box.linked:not(.vertical) > button.combo, toolbar.inline-toolbar toolbutton:first-child > button.flat, toolbar.inline-toolbar toolbutton:first-child > button.sidebar-button { border-top-left-radius: 3px; border-bottom-left-radius: 3px; -gtk-outline-top-left-radius: 3px; -gtk-outline-bottom-left-radius: 3px; }

.linked.vertical > combobox:first-child > box > button.combo:dir(rtl), .linked:not(.vertical) > combobox:first-child > box > button.combo:dir(rtl), dropdown.linked button:dir(rtl):nth-child(2), combobox.linked button:dir(rtl):nth-child(2), .linked.vertical > combobox:last-child > box > button.combo:dir(ltr), dropdown.linked button:dir(ltr):nth-child(2), combobox.linked button:dir(ltr):nth-child(2), .linked:not(.vertical) > combobox:only-child > box > button.combo:last-child, .linked:not(.vertical) > combobox:last-child > box > button.combo, .linked:not(.vertical) > combobox:first-child > box > button.combo:last-child, .linked:not(.vertical) > spinbutton:last-child:not(.vertical), .linked:not(.vertical) > entry:last-child, .inline-toolbar button:last-child, .inline-toolbar .linked.vertical > combobox:last-child > box > button.combo, .inline-toolbar button:last-child:backdrop, .linked:not(.vertical) > button:last-child, .linked.vertical > combobox:last-child > box.linked:not(.vertical) > button.combo, toolbar.inline-toolbar toolbutton:last-child > button.flat, toolbar.inline-toolbar toolbutton:last-child > button.sidebar-button { border-right-style: solid; border-top-right-radius: 3px; border-bottom-right-radius: 3px; -gtk-outline-top-right-radius: 3px; -gtk-outline-bottom-right-radius: 3px; }

.linked:not(.vertical) > combobox:only-child > box > button.combo, .linked:not(.vertical) > combobox:last-child > box > button.combo:only-child, .linked:not(.vertical) > combobox:first-child > box > button.combo:only-child, dropdown.linked button:only-child:nth-child(2):dir(rtl), dropdown.linked .linked.vertical > combobox:only-child > box > button.combo:nth-child(2):dir(rtl), combobox.linked button:only-child:nth-child(2):dir(rtl), combobox.linked .linked.vertical > combobox:only-child > box > button.combo:nth-child(2):dir(rtl), dropdown.linked button:only-child:nth-child(2):dir(ltr), dropdown.linked .linked.vertical > combobox:only-child > box > button.combo:nth-child(2):dir(ltr), combobox.linked button:only-child:nth-child(2):dir(ltr), combobox.linked .linked.vertical > combobox:only-child > box > button.combo:nth-child(2):dir(ltr), .linked:not(.vertical) > spinbutton:only-child:not(.vertical), .linked:not(.vertical) > entry:only-child, .inline-toolbar button:only-child, .inline-toolbar .linked.vertical > combobox:only-child > box > button.combo, .inline-toolbar button:only-child:backdrop, .linked:not(.vertical) > button:only-child, .linked.vertical > combobox:only-child > box.linked:not(.vertical) > button.combo, toolbar.inline-toolbar toolbutton:only-child > button.flat, toolbar.inline-toolbar toolbutton:only-child > button.sidebar-button { border-style: solid; border-radius: 3px; -gtk-outline-radius: 3px; }

.linked.vertical > combobox > box > button.combo, .linked.vertical > combobox:only-child > box > button.combo, .linked.vertical > combobox:last-child > box > button.combo, .linked.vertical > combobox:first-child > box > button.combo, .linked.vertical > spinbutton:not(.vertical), .linked.vertical > entry, .linked.vertical > button { border-style: solid solid none solid; border-radius: 0; -gtk-outline-radius: 0; }

.linked.vertical > combobox:only-child > box > button.combo:first-child, .linked.vertical > combobox:last-child > box > button.combo:first-child, .linked.vertical > combobox:first-child > box > button.combo, dropdown.linked .linked.vertical > combobox:only-child > box > button.combo:nth-child(2):dir(rtl), dropdown.linked .linked.vertical > combobox:last-child > box > button.combo:nth-child(2):dir(rtl), combobox.linked .linked.vertical > combobox:only-child > box > button.combo:nth-child(2):dir(rtl), combobox.linked .linked.vertical > combobox:last-child > box > button.combo:nth-child(2):dir(rtl), .linked.vertical > spinbutton:first-child:not(.vertical), .linked.vertical > entry:first-child, .linked.vertical > button:first-child, .linked:not(.vertical) > combobox:first-child > box.linked.vertical > button.combo, dropdown.linked .linked.vertical > button:nth-child(2):dir(rtl), combobox.linked .linked.vertical > button:nth-child(2):dir(rtl) { border-top-left-radius: 3px; border-top-right-radius: 3px; -gtk-outline-top-left-radius: 3px; -gtk-outline-top-right-radius: 3px; }

.linked.vertical > combobox:only-child > box > button.combo:last-child, .linked.vertical > combobox:last-child > box > button.combo, .linked.vertical > combobox:first-child > box > button.combo:last-child, dropdown.linked .linked.vertical > combobox:only-child > box > button.combo:nth-child(2):dir(ltr), dropdown.linked .linked.vertical > combobox:first-child > box > button.combo:nth-child(2):dir(ltr), combobox.linked .linked.vertical > combobox:only-child > box > button.combo:nth-child(2):dir(ltr), combobox.linked .linked.vertical > combobox:first-child > box > button.combo:nth-child(2):dir(ltr), .linked.vertical > spinbutton:last-child:not(.vertical), .linked.vertical > entry:last-child, .linked.vertical > button:last-child, .linked:not(.vertical) > combobox:last-child > box.linked.vertical > button.combo, dropdown.linked .linked.vertical > button:nth-child(2):dir(ltr), combobox.linked .linked.vertical > button:nth-child(2):dir(ltr) { border-bottom-style: solid; border-bottom-left-radius: 3px; border-bottom-right-radius: 3px; -gtk-outline-bottom-left-radius: 3px; -gtk-outline-bottom-right-radius: 3px; }

.linked.vertical > combobox:only-child > box > button.combo, .linked.vertical > combobox:last-child > box > button.combo:only-child, .linked.vertical > combobox:first-child > box > button.combo:only-child, .linked.vertical > spinbutton:only-child:not(.vertical), .linked.vertical > entry:only-child, .linked.vertical > button:only-child, .linked:not(.vertical) > combobox:only-child > box.linked.vertical > button.combo { border-style: solid; border-radius: 3px; -gtk-outline-radius: 3px; }

.scale-popup button:backdrop:hover, .scale-popup button:backdrop:disabled, .scale-popup label:disabled selection:backdrop, label:disabled .scale-popup selection:backdrop, .scale-popup button:backdrop, .scale-popup button:hover, calendar.button, button.link:hover, button.link:active, button.link:checked, button:visited:hover, button:visited:active, button:visited:checked, button.link, button:visited, modelbutton.flat:backdrop, popover.background checkbutton.flat:backdrop, popover.background radiobutton.flat:backdrop, modelbutton.flat:backdrop:hover, modelbutton.flat, popover.background checkbutton.flat, popover.background radiobutton.flat, .menuitem.button.flat, button.button.sidebar-button, popover.background checkbutton.button, popover.background radiobutton.button { background-color: transparent; background-image: none; border-color: transparent; box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; }

/* menu buttons */
modelbutton.flat, popover.background checkbutton.flat, popover.background radiobutton.flat, .menuitem.button.flat, button.button.sidebar-button, popover.background checkbutton.button, popover.background radiobutton.button { min-height: 26px; padding-left: 5px; padding-right: 5px; border-radius: 3px; outline-offset: -2px; }

modelbutton.flat:hover, popover.background checkbutton.flat:hover, popover.background radiobutton.flat:hover, .menuitem.button.flat:hover, button.button.sidebar-button:hover, popover.background checkbutton.button:hover, popover.background radiobutton.button:hover { background-color: #398ee7; }

modelbutton.flat:disabled, popover.background checkbutton.flat:disabled, popover.background radiobutton.flat:disabled, .menuitem.button.flat:disabled, button.button.sidebar-button:disabled, popover.background checkbutton.button:disabled, popover.background radiobutton.button:disabled, label:disabled selection.flat { color: #858585; }

modelbutton.flat:disabled:backdrop, popover.background checkbutton.flat:disabled:backdrop, popover.background radiobutton.flat:disabled:backdrop, label:disabled selection.flat:backdrop, .menuitem.button.flat:disabled:backdrop, button.button.sidebar-button:disabled:backdrop, popover.background checkbutton.button:disabled:backdrop, popover.background radiobutton.button:disabled:backdrop { color: #a8a8a8; }

modelbutton.flat arrow, popover.background checkbutton.flat arrow, popover.background radiobutton.flat arrow { background: none; }

modelbutton.flat arrow:hover, popover.background checkbutton.flat arrow:hover, popover.background radiobutton.flat arrow:hover { background: none; }

modelbutton.flat arrow.left, popover.background checkbutton.flat arrow.left, popover.background radiobutton.flat arrow.left { -gtk-icon-source: -gtk-icontheme("pan-start-symbolic"); }

modelbutton.flat arrow.right, popover.background checkbutton.flat arrow.right, popover.background radiobutton.flat arrow.right { -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); }

button.color { padding: 4px; }

button.color colorswatch:only-child { box-shadow: 0 1px rgba(255, 255, 255, 0.769231); }

button.color colorswatch:only-child, button.color colorswatch:only-child overlay { border-radius: 0; }

button.color colorswatch:only-child:disabled colorswatch:only-child, button.color label:disabled selection:only-child colorswatch:only-child, label:disabled button.color selection:only-child colorswatch:only-child, button.color colorswatch:only-child:backdrop colorswatch:only-child, button.color colorswatch:only-child:active colorswatch:only-child, button.color colorswatch:only-child:checked colorswatch:only-child { box-shadow: none; }

/********* Links * */
button.link > label, button:visited > label, button.link, button:visited, link { color: #2d71b8; text-decoration: underline; }

button.link > label:visited, button:visited > label:visited, button:visited, link:visited { color: #145ba6; }

*:selected button.link > label:visited, .selection-mode.titlebar:not(headerbar) .subtitle:link button.link > label:visited, headerbar.selection-mode .subtitle:link button.link > label:visited, *:selected button:visited > label:visited, .selection-mode.titlebar:not(headerbar) .subtitle:link button:visited > label:visited, headerbar.selection-mode .subtitle:link button:visited > label:visited, *:selected button:visited, .selection-mode.titlebar:not(headerbar) .subtitle:link button:visited, headerbar.selection-mode .subtitle:link button:visited, *:selected link:visited, .selection-mode.titlebar:not(headerbar) .subtitle:link link:visited, headerbar.selection-mode .subtitle:link link:visited { color: #b0d2f5; }

button.link > label:hover, button:visited > label:hover, button.link:hover, button:hover:visited, link:hover { color: #468ad2; }

*:selected button.link > label:hover, .selection-mode.titlebar:not(headerbar) .subtitle:link button.link > label:hover, headerbar.selection-mode .subtitle:link button.link > label:hover, *:selected button:visited > label:hover, .selection-mode.titlebar:not(headerbar) .subtitle:link button:visited > label:hover, headerbar.selection-mode .subtitle:link button:visited > label:hover, *:selected button.link:hover, .selection-mode.titlebar:not(headerbar) .subtitle:link button.link:hover, headerbar.selection-mode .subtitle:link button.link:hover, *:selected button:hover:visited, .selection-mode.titlebar:not(headerbar) .subtitle:link button:hover:visited, headerbar.selection-mode .subtitle:link button:hover:visited, *:selected link:hover, .selection-mode.titlebar:not(headerbar) .subtitle:link link:hover, headerbar.selection-mode .subtitle:link link:hover { color: #ebf4fd; }

button.link > label:active, button:visited > label:active, button.link:active, button:active:visited, link:active { color: #2d71b8; }

*:selected button.link > label:active, .selection-mode.titlebar:not(headerbar) .subtitle:link button.link > label:active, headerbar.selection-mode .subtitle:link button.link > label:active, *:selected button:visited > label:active, .selection-mode.titlebar:not(headerbar) .subtitle:link button:visited > label:active, headerbar.selection-mode .subtitle:link button:visited > label:active, *:selected button.link:active, .selection-mode.titlebar:not(headerbar) .subtitle:link button.link:active, headerbar.selection-mode .subtitle:link button.link:active, *:selected button:active:visited, .selection-mode.titlebar:not(headerbar) .subtitle:link button:active:visited, headerbar.selection-mode .subtitle:link button:active:visited, *:selected link:active, .selection-mode.titlebar:not(headerbar) .subtitle:link link:active, headerbar.selection-mode .subtitle:link link:active { color: #d7e8fa; }

button.link > label:disabled, button:visited > label:disabled, button.link:disabled, button:disabled:visited, link:disabled, link:disabled:backdrop { color: rgba(115, 115, 115, 0.8); }

.selection-mode.titlebar:not(headerbar) .subtitle:hover:link, headerbar.selection-mode .subtitle:hover:link, button.link > label:backdrop, button:visited > label:backdrop, button.link:backdrop, button:backdrop:visited, link:backdrop:backdrop:hover, link:backdrop:backdrop:hover:selected, link:backdrop { color: #398ee7; }

.info *:link, .info headerbar.selection-mode .subtitle:link, headerbar.selection-mode .info .subtitle:link, .info .selection-mode.titlebar:not(headerbar) .subtitle:link, .selection-mode.titlebar:not(headerbar) .info .subtitle:link, .info .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .info .subtitle:link, .info headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .info .subtitle:link, .question *:link, .question headerbar.selection-mode .subtitle:link, headerbar.selection-mode .question .subtitle:link, .question .selection-mode.titlebar:not(headerbar) .subtitle:link, .selection-mode.titlebar:not(headerbar) .question .subtitle:link, .question .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .question .subtitle:link, .question headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .question .subtitle:link, .warning *:link, .warning headerbar.selection-mode .subtitle:link, headerbar.selection-mode .warning .subtitle:link, .warning .selection-mode.titlebar:not(headerbar) .subtitle:link, .selection-mode.titlebar:not(headerbar) .warning .subtitle:link, .warning .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .warning .subtitle:link, .warning headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .warning .subtitle:link, .error *:link, .error headerbar.selection-mode .subtitle:link, headerbar.selection-mode .error .subtitle:link, .error .selection-mode.titlebar:not(headerbar) .subtitle:link, .selection-mode.titlebar:not(headerbar) .error .subtitle:link, .error .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .subtitle:link, .selection-mode.titlebar:not(headerbar) headerbar.selection-mode .error .subtitle:link, .error headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .subtitle:link, headerbar.selection-mode .selection-mode.titlebar:not(headerbar) .error .subtitle:link, button.link > label:selected, .selection-mode.titlebar:not(headerbar) button.link > label.subtitle:link, headerbar.selection-mode button.link > label.subtitle:link, button:visited > label:selected, .selection-mode.titlebar:not(headerbar) button:visited > label.subtitle:link, headerbar.selection-mode button:visited > label.subtitle:link, button.link:selected, .selection-mode.titlebar:not(headerbar) .link.subtitle:link, headerbar.selection-mode .link.subtitle:link, button:selected:visited, .selection-mode.titlebar:not(headerbar) button.subtitle:visited:link, headerbar.selection-mode button.subtitle:visited:link, *:selected button.link > label, .selection-mode.titlebar:not(headerbar) .subtitle:link button.link > label, headerbar.selection-mode .subtitle:link button.link > label, *:selected button:visited > label, .selection-mode.titlebar:not(headerbar) .subtitle:link button:visited > label, headerbar.selection-mode .subtitle:link button:visited > label, *:selected button.link, .selection-mode.titlebar:not(headerbar) .subtitle:link button.link, headerbar.selection-mode .subtitle:link button.link, *:selected button:visited, .selection-mode.titlebar:not(headerbar) .subtitle:link button:visited, headerbar.selection-mode .subtitle:link button:visited, link:selected, .selection-mode.titlebar:not(headerbar) link.subtitle:link, headerbar.selection-mode link.subtitle:link, *:selected link, .selection-mode.titlebar:not(headerbar) .subtitle:link link, headerbar.selection-mode .subtitle:link link, headerbar.selection-mode .subtitle:selected:link link, headerbar.selection-mode .subtitle:link link { color: #d7e8fa; }

button.link, button:visited { text-shadow: none; }

button.link:hover, button.link:active, button.link:checked, button:visited:hover, button:visited:active, button:visited:checked { text-shadow: none; }

button.link > label, button:visited > label { text-decoration: underline; }

/***************** GtkSpinButton * */
spinbutton:not(.vertical) { padding: 0; }

spinbutton:not(.vertical) entry { min-width: 28px; margin: 0; background: none; background-color: transparent; border: none; border-radius: 0; box-shadow: none; }

spinbutton:not(.vertical) button { min-height: 16px; margin: 0; padding-bottom: 0; padding-top: 0; color: #4f4f4f; background-image: none; border-style: none none none solid; border-color: rgba(130, 130, 130, 0.3); border-radius: 0; box-shadow: none; }

spinbutton:not(.vertical) button:dir(rtl) { border-style: none solid none none; }

spinbutton:not(.vertical) button:hover { color: #3c3c3c; background-color: rgba(60, 60, 60, 0.05); }

spinbutton:not(.vertical) button:disabled { color: rgba(133, 133, 133, 0.3); background-color: transparent; }

spinbutton:not(.vertical) button:active { background-color: rgba(0, 0, 0, 0.1); box-shadow: inset 0 2px 3px -1px rgba(0, 0, 0, 0.2); }

spinbutton:not(.vertical) button:backdrop { color: #919191; background-color: transparent; border-color: rgba(137, 137, 137, 0.3); transition: 200ms ease-out; }

spinbutton:not(.vertical) button:backdrop:disabled, spinbutton:not(.vertical) label:disabled selection:backdrop, label:disabled spinbutton:not(.vertical) selection:backdrop { color: rgba(168, 168, 168, 0.3); background-color: transparent; border-style: none none none solid; }

spinbutton:not(.vertical) button:backdrop:disabled:dir(rtl), spinbutton:not(.vertical) label:disabled selection:backdrop:dir(rtl), label:disabled spinbutton:not(.vertical) selection:backdrop:dir(rtl) { border-style: none solid none none; }

.osd spinbutton:not(.vertical) button { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: #eeeeee; border-style: none none none solid; border-color: rgba(0, 0, 0, 0.4); border-radius: 0; box-shadow: none; -gtk-icon-shadow: 0 1px black; }

.osd spinbutton:not(.vertical) button:dir(rtl) { border-style: none solid none none; }

.osd spinbutton:not(.vertical) button:hover { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: #eeeeee; border-color: rgba(0, 0, 0, 0.5); background-color: rgba(238, 238, 238, 0.1); -gtk-icon-shadow: 0 1px black; box-shadow: none; }

.osd spinbutton:not(.vertical) button:backdrop { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: #eeeeee; border-color: rgba(0, 0, 0, 0.5); -gtk-icon-shadow: none; box-shadow: none; }

.osd spinbutton:not(.vertical) button:disabled { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: #888888; border-color: rgba(0, 0, 0, 0.5); -gtk-icon-shadow: none; box-shadow: none; }

.osd spinbutton:not(.vertical) button:dir(ltr):last-child, .osd spinbutton:not(.vertical) .linked.vertical > combobox:last-child > box > button.combo:dir(ltr), .osd spinbutton:not(.vertical) .linked:not(.vertical) > combobox:last-child > box > button.combo:dir(ltr), .osd spinbutton:not(.vertical) dropdown.linked button:dir(ltr):nth-child(2), dropdown.linked .osd spinbutton:not(.vertical) button:dir(ltr):nth-child(2), .osd spinbutton:not(.vertical) combobox.linked button:dir(ltr):nth-child(2), combobox.linked .osd spinbutton:not(.vertical) button:dir(ltr):nth-child(2) { border-radius: 0 3px 3px 0; }

.osd spinbutton:not(.vertical) button:dir(rtl):first-child, .osd spinbutton:not(.vertical) .linked.vertical > combobox:first-child > box > button.combo:dir(rtl), .osd spinbutton:not(.vertical) .linked:not(.vertical) > combobox:first-child > box > button.combo:dir(rtl), .osd spinbutton:not(.vertical) dropdown.linked button:dir(rtl):nth-child(2), dropdown.linked .osd spinbutton:not(.vertical) button:dir(rtl):nth-child(2), .osd spinbutton:not(.vertical) combobox.linked button:dir(rtl):nth-child(2), combobox.linked .osd spinbutton:not(.vertical) button:dir(rtl):nth-child(2) { border-radius: 3px 0 0 3px; }

spinbutton.vertical:disabled, label:disabled selection.vertical { color: #858585; }

spinbutton.vertical:backdrop:disabled, label:disabled selection:backdrop { color: #a8a8a8; }

spinbutton.vertical:drop(active), dropdown:drop(active) button.vertical.combo, combobox:drop(active) button.vertical.combo { border-color: transparent; box-shadow: none; }

spinbutton.vertical entry { min-height: 32px; min-width: 32px; padding: 0; border-radius: 0; }

spinbutton.vertical button { min-height: 32px; min-width: 32px; padding: 0; }

spinbutton.vertical button.up { border-radius: 3px 3px 0 0; border-style: solid solid none solid; }

spinbutton.vertical button.down { border-radius: 0 0 3px 3px; border-style: none solid solid solid; }

.osd spinbutton.vertical button:first-child, .osd spinbutton.vertical .linked.vertical > combobox:first-child > box > button.combo, .osd spinbutton.vertical .linked:not(.vertical) > combobox:first-child > box > button.combo, .osd spinbutton.vertical dropdown.linked button:nth-child(2):dir(rtl), dropdown.linked .osd spinbutton.vertical button:nth-child(2):dir(rtl), .osd spinbutton.vertical combobox.linked button:nth-child(2):dir(rtl), combobox.linked .osd spinbutton.vertical button:nth-child(2):dir(rtl) { color: #eeeeee; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 238, 0.3); }

.osd spinbutton.vertical button:first-child:hover, .osd spinbutton.vertical .linked.vertical > combobox:first-child > box > button.combo:hover, .osd spinbutton.vertical .linked:not(.vertical) > combobox:first-child > box > button.combo:hover, .osd spinbutton.vertical dropdown.linked button:hover:nth-child(2):dir(rtl), dropdown.linked .osd spinbutton.vertical button:hover:nth-child(2):dir(rtl), .osd spinbutton.vertical combobox.linked button:hover:nth-child(2):dir(rtl), combobox.linked .osd spinbutton.vertical button:hover:nth-child(2):dir(rtl) { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(65, 65, 65, 0.8); background-clip: padding-box; box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 238, 0.3); }

.osd spinbutton.vertical button:first-child:active, .osd spinbutton.vertical .linked.vertical > combobox:first-child > box > button.combo:active, .osd spinbutton.vertical .linked:not(.vertical) > combobox:first-child > box > button.combo:active, .osd spinbutton.vertical dropdown.linked button:active:nth-child(2):dir(rtl), dropdown.linked .osd spinbutton.vertical button:active:nth-child(2):dir(rtl), .osd spinbutton.vertical combobox.linked button:active:nth-child(2):dir(rtl), combobox.linked .osd spinbutton.vertical button:active:nth-child(2):dir(rtl) { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(0, 0, 0, 0.7); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; outline-color: rgba(238, 238, 238, 0.3); }

.osd spinbutton.vertical button:first-child:disabled, .osd spinbutton.vertical .linked.vertical > combobox:first-child > box > button.combo:disabled, .osd spinbutton.vertical .linked:not(.vertical) > combobox:first-child > box > button.combo:disabled, .osd spinbutton.vertical dropdown.linked button:disabled:nth-child(2):dir(rtl), dropdown.linked .osd spinbutton.vertical button:disabled:nth-child(2):dir(rtl), .osd spinbutton.vertical combobox.linked button:disabled:nth-child(2):dir(rtl), combobox.linked .osd spinbutton.vertical button:disabled:nth-child(2):dir(rtl), .osd spinbutton.vertical label:disabled selection:first-child, label:disabled .osd spinbutton.vertical selection:first-child { color: #888888; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

.osd spinbutton.vertical button:first-child:backdrop, .osd spinbutton.vertical .linked.vertical > combobox:first-child > box > button.combo:backdrop, .osd spinbutton.vertical .linked:not(.vertical) > combobox:first-child > box > button.combo:backdrop, .osd spinbutton.vertical dropdown.linked button:backdrop:nth-child(2):dir(rtl), dropdown.linked .osd spinbutton.vertical button:backdrop:nth-child(2):dir(rtl), .osd spinbutton.vertical combobox.linked button:backdrop:nth-child(2):dir(rtl), combobox.linked .osd spinbutton.vertical button:backdrop:nth-child(2):dir(rtl) { color: #eeeeee; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

treeview spinbutton:not(.vertical) { min-height: 0; border-style: none; border-radius: 0; }

treeview spinbutton:not(.vertical) entry { min-height: 0; padding: 1px 2px; }

/************** ComboBoxes * */
dropdown > popover.menu.background > contents { padding: 0; }

dropdown > button > box { border-spacing: 6px; }

dropdown > button > box > stack > row.activatable:hover { background: none; box-shadow: none; }

dropdown arrow, combobox arrow { -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); min-height: 16px; min-width: 16px; }

dropdown > popover.menu > contents modelbutton, dropdown > popover.menu > contents popover.background checkbutton, popover.background dropdown > popover.menu > contents checkbutton, dropdown > popover.menu > contents popover.background radiobutton, popover.background dropdown > popover.menu > contents radiobutton, combobox > popover.menu > contents modelbutton, combobox > popover.menu > contents popover.background checkbutton, popover.background combobox > popover.menu > contents checkbutton, combobox > popover.menu > contents popover.background radiobutton, popover.background combobox > popover.menu > contents radiobutton { padding-left: 9px; padding-right: 9px; }

dropdown:drop(active), combobox:drop(active) { box-shadow: none; }

/************ Toolbars * */
searchbar, .location-bar, .inline-toolbar, .toolbar, toolbar { -GtkWidget-window-dragging: true; padding: 4px; background-color: #cecece; }

.toolbar, toolbar { background: #cecece linear-gradient(to bottom, #cecece, shade(#cecece, 0.88)); box-shadow: inset 0 1px rgba(255, 255, 255, 0.8); box-shadow: none; border-bottom: 1px solid #828282; padding: 4px 3px 3px 4px; }

.osd .toolbar, .osd toolbar { background-color: transparent; }

.toolbar.osd, toolbar.osd { padding: 13px; border: none; border-radius: 5px; background-color: rgba(34, 34, 34, 0.8); }

.toolbar.osd.left, .toolbar.osd.right, .toolbar.osd.top, .toolbar.osd.bottom, toolbar.osd.left, toolbar.osd.right, toolbar.osd.top, toolbar.osd.bottom { border-radius: 0; }

.toolbar.horizontal separator, toolbar.horizontal separator { margin: 0 7px 1px 6px; }

.toolbar.vertical separator, toolbar.vertical separator { margin: 6px 1px 7px 0; }

.toolbar:not(.inline-toolbar):not(.osd) switch, .toolbar:not(.inline-toolbar):not(.osd) scale, .toolbar:not(.inline-toolbar):not(.osd) entry, .toolbar:not(.inline-toolbar):not(.osd) spinbutton, .toolbar:not(.inline-toolbar):not(.osd) button, toolbar:not(.inline-toolbar):not(.osd) switch, toolbar:not(.inline-toolbar):not(.osd) scale, toolbar:not(.inline-toolbar):not(.osd) entry, toolbar:not(.inline-toolbar):not(.osd) spinbutton, toolbar:not(.inline-toolbar):not(.osd) button { margin-right: 1px; margin-bottom: 1px; }

.inline-toolbar { padding: 3px; border-width: 0 1px 1px; border-radius: 0  0 5px 5px; }

searchbar, .location-bar { border-width: 0 0 1px; padding: 3px; }

.inline-toolbar, searchbar, .location-bar { border-style: solid; border-color: #828282; background-color: #b7b7b7; }

.inline-toolbar:backdrop, searchbar:backdrop, .location-bar:backdrop { border-color: #898989; background-color: #b6b6b6; box-shadow: none; transition: 200ms ease-out; }

/***************** Title buttons * */
windowcontrols { border-spacing: 2px; }

windowcontrols:not(.empty).start:dir(ltr), windowcontrols:not(.empty).end:dir(rtl) { margin-right: 7px; }

windowcontrols:not(.empty).start:dir(rtl), windowcontrols:not(.empty).end:dir(ltr) { margin-left: 7px; }

windowcontrols button { border-radius: 9999px; padding: 3px; margin: 0 2px; min-width: 0; min-height: 0; }

windowcontrols button:hover { color: #3c3c3c; outline-color: rgba(60, 60, 60, 0.3); border-color: #7f7f7f; background-image: linear-gradient(to bottom, shade(#bfbfbf, 1.15), shade(#bfbfbf, 1.07)); box-shadow: inset 0 1px rgba(255, 255, 255, 0.6); }

windowcontrols button:active, windowcontrols button:checked { color: #3c3c3c; outline-color: rgba(60, 60, 60, 0.3); border-color: #757575; background-image: linear-gradient(to bottom, shade(shade(#b5b5b5, 0.85), 1.05), shade(shade(#b5b5b5, 0.85), 0.97)); box-shadow: inset 0 2px 1px -2px rgba(0, 0, 0, 0.6); }

/*************** Header bars * */
.titlebar:not(headerbar), headerbar { padding: 0 5px; min-height: 32px; border-width: 0 0 1px; border-style: solid; border-color: #828282; border-radius: 0; background: #cecece linear-gradient(to bottom, #cecece, shade(#cecece, 0.88)); box-shadow: inset 0 1px rgba(255, 255, 255, 0.8); /* Darken switchbuttons for headerbars. issue #1588 */ }

.titlebar:backdrop:not(headerbar), headerbar:backdrop { border-color: #898989; background-color: #cecece; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0.8); transition: 200ms ease-out; }

.titlebar:not(headerbar) .title, headerbar .title { padding-left: 12px; padding-right: 12px; font-weight: bold; }

.titlebar:not(headerbar) .subtitle, headerbar .subtitle { font-size: smaller; padding-left: 12px; padding-right: 12px; }

.titlebar:not(headerbar) stackswitcher > button:checked, .titlebar:not(headerbar) button.toggle:checked, headerbar stackswitcher > button:checked, headerbar button.toggle:checked { background: image(#a3a3a3); border-color: #7a7a7a; border-top-color: #6d6d6d; }

.titlebar:not(headerbar) stackswitcher > button:checked:backdrop, .titlebar:not(headerbar) button.toggle:checked:backdrop, headerbar stackswitcher > button:checked:backdrop, headerbar button.toggle:checked:backdrop { border-color: #898989; background-color: #b6b6b6; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.titlebar:not(headerbar) stackswitcher > button:checked:backdrop label, .titlebar:not(headerbar) stackswitcher > button:checked:backdrop, .titlebar:not(headerbar) button.toggle:checked:backdrop label, .titlebar:not(headerbar) button.toggle:checked:backdrop, headerbar stackswitcher > button:checked:backdrop label, headerbar stackswitcher > button:checked:backdrop, headerbar button.toggle:checked:backdrop label, headerbar button.toggle:checked:backdrop { color: #858585; }

.selection-mode.titlebar:not(headerbar), headerbar.selection-mode { color: #ffffff; text-shadow: none; border-color: #0f4278; background: #398ee7 linear-gradient(to bottom, #398ee7, shade(#398ee7, 0.88)); box-shadow: inset 0 1px rgba(136, 187, 241, 0.9); }

.selection-mode.titlebar:backdrop:not(headerbar), headerbar.selection-mode:backdrop { background-color: #398ee7; background-image: none; box-shadow: inset 0 1px rgba(156, 199, 243, 0.88); }

.selection-mode.titlebar:not(headerbar) button, headerbar.selection-mode button { color: #ffffff; outline-color: rgba(255, 255, 255, 0.3); border-top-color: shade(#cecece, 0.8); border-right-color: shade(#cecece, 0.72); border-left-color: shade(#cecece, 0.72); border-bottom-color: shade(#cecece, 0.7); background-image: linear-gradient(to bottom, shade(shade(#398ee7, 1.02), 1.05), shade(shade(#398ee7, 1.02), 0.97)); box-shadow: inset 0 1px rgba(255, 255, 255, 0.4); }

.selection-mode.titlebar:not(headerbar) button.flat, .selection-mode.titlebar:not(headerbar) button.sidebar-button, headerbar.selection-mode button.flat, headerbar.selection-mode button.sidebar-button { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; }

.selection-mode.titlebar:not(headerbar) button:hover, headerbar.selection-mode button:hover { color: #ffffff; outline-color: rgba(255, 255, 255, 0.3); border-color: #114f8f; background-image: linear-gradient(to bottom, shade(#398ee7, 1.15), shade(#398ee7, 1.07)); box-shadow: inset 0 1px rgba(255, 255, 255, 0.4); }

.selection-mode.titlebar:not(headerbar) button:active, .selection-mode.titlebar:not(headerbar) button:checked, headerbar.selection-mode button:active, headerbar.selection-mode button:checked { color: #ffffff; outline-color: rgba(255, 255, 255, 0.3); border-color: #114f8f; background-image: linear-gradient(to bottom, shade(shade(#398ee7, 0.85), 1.05), shade(shade(#398ee7, 0.85), 0.97)); box-shadow: inset 0 2px 1px -2px rgba(0, 0, 0, 0.6); }

.selection-mode.titlebar:not(headerbar) button:backdrop, headerbar.selection-mode button:backdrop.flat, headerbar.selection-mode button.sidebar-button:backdrop, headerbar.selection-mode popover.background checkbutton:backdrop, popover.background headerbar.selection-mode checkbutton:backdrop, headerbar.selection-mode popover.background radiobutton:backdrop, popover.background headerbar.selection-mode radiobutton:backdrop, headerbar.selection-mode button:backdrop { border-color: #398ee7; background-color: #398ee7; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); -gtk-icon-effect: none; border-color: #0f4278; }

.selection-mode.titlebar:not(headerbar) button:backdrop label, .selection-mode.titlebar:not(headerbar) button:backdrop, headerbar.selection-mode button:backdrop.flat label, headerbar.selection-mode button.sidebar-button:backdrop label, headerbar.selection-mode popover.background checkbutton:backdrop label, popover.background headerbar.selection-mode checkbutton:backdrop label, headerbar.selection-mode popover.background radiobutton:backdrop label, popover.background headerbar.selection-mode radiobutton:backdrop label, headerbar.selection-mode button:backdrop.flat, headerbar.selection-mode button.sidebar-button:backdrop, headerbar.selection-mode popover.background checkbutton:backdrop, popover.background headerbar.selection-mode checkbutton:backdrop, headerbar.selection-mode popover.background radiobutton:backdrop, popover.background headerbar.selection-mode radiobutton:backdrop, headerbar.selection-mode button:backdrop label, headerbar.selection-mode button:backdrop { color: #d7e8fa; }

.selection-mode.titlebar:not(headerbar) button:backdrop:active, .selection-mode.titlebar:not(headerbar) button:backdrop:checked, headerbar.selection-mode button:backdrop.flat:active, headerbar.selection-mode button.sidebar-button:backdrop:active, headerbar.selection-mode popover.background checkbutton:backdrop:active, popover.background headerbar.selection-mode checkbutton:backdrop:active, headerbar.selection-mode popover.background radiobutton:backdrop:active, popover.background headerbar.selection-mode radiobutton:backdrop:active, headerbar.selection-mode button:backdrop.flat:checked, headerbar.selection-mode button.sidebar-button:backdrop:checked, headerbar.selection-mode popover.background checkbutton:backdrop:checked, popover.background headerbar.selection-mode checkbutton:backdrop:checked, headerbar.selection-mode popover.background radiobutton:backdrop:checked, popover.background headerbar.selection-mode radiobutton:backdrop:checked, headerbar.selection-mode button:backdrop:active, headerbar.selection-mode button:backdrop:checked { border-color: #1a74d3; background-color: #1a74d3; box-shadow: inset 0 1px rgba(255, 255, 255, 0); border-color: #0f4278; }

.selection-mode.titlebar:not(headerbar) button:backdrop:active label, .selection-mode.titlebar:not(headerbar) button:backdrop:active, .selection-mode.titlebar:not(headerbar) button:backdrop:checked label, .selection-mode.titlebar:not(headerbar) button:backdrop:checked, headerbar.selection-mode button:backdrop.flat:active label, headerbar.selection-mode button.sidebar-button:backdrop:active label, headerbar.selection-mode popover.background checkbutton:backdrop:active label, popover.background headerbar.selection-mode checkbutton:backdrop:active label, headerbar.selection-mode popover.background radiobutton:backdrop:active label, popover.background headerbar.selection-mode radiobutton:backdrop:active label, headerbar.selection-mode button:backdrop.flat:active, headerbar.selection-mode button.sidebar-button:backdrop:active, headerbar.selection-mode popover.background checkbutton:backdrop:active, popover.background headerbar.selection-mode checkbutton:backdrop:active, headerbar.selection-mode popover.background radiobutton:backdrop:active, popover.background headerbar.selection-mode radiobutton:backdrop:active, headerbar.selection-mode button:backdrop.flat:checked label, headerbar.selection-mode button.sidebar-button:backdrop:checked label, headerbar.selection-mode popover.background checkbutton:backdrop:checked label, popover.background headerbar.selection-mode checkbutton:backdrop:checked label, headerbar.selection-mode popover.background radiobutton:backdrop:checked label, popover.background headerbar.selection-mode radiobutton:backdrop:checked label, headerbar.selection-mode button:backdrop.flat:checked, headerbar.selection-mode button.sidebar-button:backdrop:checked, headerbar.selection-mode popover.background checkbutton:backdrop:checked, popover.background headerbar.selection-mode checkbutton:backdrop:checked, headerbar.selection-mode popover.background radiobutton:backdrop:checked, popover.background headerbar.selection-mode radiobutton:backdrop:checked, headerbar.selection-mode button:backdrop:active label, headerbar.selection-mode button:backdrop:active, headerbar.selection-mode button:backdrop:checked label, headerbar.selection-mode button:backdrop:checked { color: #d1e3f6; }

.selection-mode.titlebar:not(headerbar) label:disabled selection.flat, label:disabled .selection-mode.titlebar:not(headerbar) selection.flat, .selection-mode.titlebar:not(headerbar) button:backdrop:disabled, .selection-mode.titlebar:not(headerbar) label:disabled selection:backdrop, label:disabled .selection-mode.titlebar:not(headerbar) selection:backdrop, headerbar.selection-mode button:backdrop.flat:disabled, headerbar.selection-mode button.sidebar-button:backdrop:disabled, headerbar.selection-mode popover.background checkbutton:backdrop:disabled, popover.background headerbar.selection-mode checkbutton:backdrop:disabled, headerbar.selection-mode popover.background radiobutton:backdrop:disabled, popover.background headerbar.selection-mode radiobutton:backdrop:disabled, headerbar.selection-mode label:disabled selection.flat, label:disabled headerbar.selection-mode selection.flat, headerbar.selection-mode button:backdrop:disabled, headerbar.selection-mode label:disabled selection:backdrop, label:disabled headerbar.selection-mode selection:backdrop { border-color: #569fea; background-color: #569fea; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); border-color: #0f4278; }

.selection-mode.titlebar:not(headerbar) label:disabled selection.flat label, label:disabled .selection-mode.titlebar:not(headerbar) selection.flat label, .selection-mode.titlebar:not(headerbar) label:disabled selection.flat, label:disabled .selection-mode.titlebar:not(headerbar) selection.flat, .selection-mode.titlebar:not(headerbar) button:backdrop:disabled label, .selection-mode.titlebar:not(headerbar) label:disabled selection:backdrop label, label:disabled .selection-mode.titlebar:not(headerbar) selection:backdrop label, .selection-mode.titlebar:not(headerbar) button:backdrop:disabled, .selection-mode.titlebar:not(headerbar) label:disabled selection:backdrop, label:disabled .selection-mode.titlebar:not(headerbar) selection:backdrop, headerbar.selection-mode button:backdrop.flat:disabled label, headerbar.selection-mode button.sidebar-button:backdrop:disabled label, headerbar.selection-mode popover.background checkbutton:backdrop:disabled label, popover.background headerbar.selection-mode checkbutton:backdrop:disabled label, headerbar.selection-mode popover.background radiobutton:backdrop:disabled label, popover.background headerbar.selection-mode radiobutton:backdrop:disabled label, headerbar.selection-mode label:disabled selection.flat label, label:disabled headerbar.selection-mode selection.flat label, headerbar.selection-mode button:backdrop.flat:disabled, headerbar.selection-mode button.sidebar-button:backdrop:disabled, headerbar.selection-mode popover.background checkbutton:backdrop:disabled, popover.background headerbar.selection-mode checkbutton:backdrop:disabled, headerbar.selection-mode popover.background radiobutton:backdrop:disabled, popover.background headerbar.selection-mode radiobutton:backdrop:disabled, headerbar.selection-mode label:disabled selection.flat, label:disabled headerbar.selection-mode selection.flat, headerbar.selection-mode button:backdrop:disabled label, headerbar.selection-mode label:disabled selection:backdrop label, label:disabled headerbar.selection-mode selection:backdrop label, headerbar.selection-mode button:backdrop:disabled, headerbar.selection-mode label:disabled selection:backdrop, label:disabled headerbar.selection-mode selection:backdrop { color: #91c1f1; }

.selection-mode.titlebar:not(headerbar) label:disabled selection.flat:active, label:disabled .selection-mode.titlebar:not(headerbar) selection.flat:active, .selection-mode.titlebar:not(headerbar) label:disabled selection.flat:checked, label:disabled .selection-mode.titlebar:not(headerbar) selection.flat:checked, .selection-mode.titlebar:not(headerbar) button:backdrop:disabled:active, .selection-mode.titlebar:not(headerbar) label:disabled selection:backdrop:active, label:disabled .selection-mode.titlebar:not(headerbar) selection:backdrop:active, .selection-mode.titlebar:not(headerbar) button:backdrop:disabled:checked, .selection-mode.titlebar:not(headerbar) label:disabled selection:backdrop:checked, label:disabled .selection-mode.titlebar:not(headerbar) selection:backdrop:checked, headerbar.selection-mode button:backdrop.flat:disabled:active, headerbar.selection-mode popover.background checkbutton:backdrop:disabled:active, popover.background headerbar.selection-mode checkbutton:backdrop:disabled:active, headerbar.selection-mode popover.background radiobutton:backdrop:disabled:active, popover.background headerbar.selection-mode radiobutton:backdrop:disabled:active, headerbar.selection-mode label:disabled selection.flat:active, label:disabled headerbar.selection-mode selection.flat:active, headerbar.selection-mode button:backdrop.flat:disabled:checked, headerbar.selection-mode popover.background checkbutton:backdrop:disabled:checked, popover.background headerbar.selection-mode checkbutton:backdrop:disabled:checked, headerbar.selection-mode popover.background radiobutton:backdrop:disabled:checked, popover.background headerbar.selection-mode radiobutton:backdrop:disabled:checked, headerbar.selection-mode label:disabled selection.flat:checked, label:disabled headerbar.selection-mode selection.flat:checked, headerbar.selection-mode button:backdrop:disabled:active, headerbar.selection-mode label:disabled selection:backdrop:active, label:disabled headerbar.selection-mode selection:backdrop:active, headerbar.selection-mode button:backdrop:disabled:checked, headerbar.selection-mode label:disabled selection:backdrop:checked, label:disabled headerbar.selection-mode selection:backdrop:checked { border-color: #3f92e7; background-color: #3f92e7; box-shadow: inset 0 1px rgba(255, 255, 255, 0); border-color: #0f4278; }

.selection-mode.titlebar:not(headerbar) label:disabled selection.flat:active label, label:disabled .selection-mode.titlebar:not(headerbar) selection.flat:active label, .selection-mode.titlebar:not(headerbar) label:disabled selection.flat:checked label, label:disabled .selection-mode.titlebar:not(headerbar) selection.flat:checked label, .selection-mode.titlebar:not(headerbar) button:backdrop:disabled:active label, .selection-mode.titlebar:not(headerbar) label:disabled selection:backdrop:active label, label:disabled .selection-mode.titlebar:not(headerbar) selection:backdrop:active label, .selection-mode.titlebar:not(headerbar) button:backdrop:disabled:checked label, .selection-mode.titlebar:not(headerbar) label:disabled selection:backdrop:checked label, label:disabled .selection-mode.titlebar:not(headerbar) selection:backdrop:checked label, headerbar.selection-mode button:backdrop.flat:disabled:active label, headerbar.selection-mode popover.background checkbutton:backdrop:disabled:active label, popover.background headerbar.selection-mode checkbutton:backdrop:disabled:active label, headerbar.selection-mode popover.background radiobutton:backdrop:disabled:active label, popover.background headerbar.selection-mode radiobutton:backdrop:disabled:active label, headerbar.selection-mode label:disabled selection.flat:active label, label:disabled headerbar.selection-mode selection.flat:active label, headerbar.selection-mode button:backdrop.flat:disabled:checked label, headerbar.selection-mode popover.background checkbutton:backdrop:disabled:checked label, popover.background headerbar.selection-mode checkbutton:backdrop:disabled:checked label, headerbar.selection-mode popover.background radiobutton:backdrop:disabled:checked label, popover.background headerbar.selection-mode radiobutton:backdrop:disabled:checked label, headerbar.selection-mode label:disabled selection.flat:checked label, label:disabled headerbar.selection-mode selection.flat:checked label, headerbar.selection-mode button:backdrop:disabled:active label, headerbar.selection-mode label:disabled selection:backdrop:active label, label:disabled headerbar.selection-mode selection:backdrop:active label, headerbar.selection-mode button:backdrop:disabled:checked label, headerbar.selection-mode label:disabled selection:backdrop:checked label, label:disabled headerbar.selection-mode selection:backdrop:checked label { color: #82b8f0; }

.selection-mode.titlebar:not(headerbar) button.flat:backdrop, .selection-mode.titlebar:not(headerbar) button.sidebar-button:backdrop, .selection-mode.titlebar:not(headerbar) button.flat:disabled, .selection-mode.titlebar:not(headerbar) button.sidebar-button:disabled, .selection-mode.titlebar:not(headerbar) label:disabled selection.flat, label:disabled .selection-mode.titlebar:not(headerbar) selection.flat, .selection-mode.titlebar:not(headerbar) label:disabled selection:backdrop, label:disabled .selection-mode.titlebar:not(headerbar) selection:backdrop, headerbar.selection-mode button.flat:backdrop, headerbar.selection-mode button.sidebar-button:backdrop, headerbar.selection-mode button.flat:disabled, headerbar.selection-mode button.sidebar-button:disabled, headerbar.selection-mode label:disabled selection.flat, label:disabled headerbar.selection-mode selection.flat, headerbar.selection-mode button.flat:backdrop:disabled, headerbar.selection-mode button.sidebar-button:backdrop:disabled, headerbar.selection-mode label:disabled selection:backdrop, label:disabled headerbar.selection-mode selection:backdrop { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; }

.selection-mode.titlebar:not(headerbar) button:disabled, headerbar.selection-mode button:disabled { border-color: #114f8f; background-color: #569fea; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.selection-mode.titlebar:not(headerbar) button:disabled label, .selection-mode.titlebar:not(headerbar) button:disabled, headerbar.selection-mode button:disabled label, headerbar.selection-mode button:disabled { color: #abcff5; }

.selection-mode.titlebar:not(headerbar) button:disabled:active, .selection-mode.titlebar:not(headerbar) button:disabled:checked, headerbar.selection-mode button:disabled:active, headerbar.selection-mode button:disabled:checked { border-color: #114f8f; background-image: linear-gradient(to bottom, #3b8bde, #3f92e7); box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.selection-mode.titlebar:not(headerbar) button:disabled:active label, .selection-mode.titlebar:not(headerbar) button:disabled:active, .selection-mode.titlebar:not(headerbar) button:disabled:checked label, .selection-mode.titlebar:not(headerbar) button:disabled:checked, headerbar.selection-mode button:disabled:active label, headerbar.selection-mode button:disabled:active, headerbar.selection-mode button:disabled:checked label, headerbar.selection-mode button:disabled:checked { color: #b2d3f5; }

.selection-mode.titlebar:not(headerbar) button.suggested-action, headerbar.selection-mode button.suggested-action { color: #3c3c3c; outline-color: rgba(60, 60, 60, 0.3); border-top-color: shade(#cecece, 0.8); border-right-color: shade(#cecece, 0.72); border-left-color: shade(#cecece, 0.72); border-bottom-color: shade(#cecece, 0.7); background-image: linear-gradient(to bottom, shade(shade(#cecece, 1.02), 1.05), shade(shade(#cecece, 1.02), 0.97)); box-shadow: inset 0 1px rgba(255, 255, 255, 0.6); color: #ffffff; border-color: #0f4278; }

.selection-mode.titlebar:not(headerbar) button.suggested-action:hover, headerbar.selection-mode button.suggested-action:hover { color: #3c3c3c; outline-color: rgba(60, 60, 60, 0.3); border-color: #828282; background-image: linear-gradient(to bottom, shade(#cecece, 1.15), shade(#cecece, 1.07)); box-shadow: inset 0 1px rgba(255, 255, 255, 0.6); border-color: #0f4278; }

.selection-mode.titlebar:not(headerbar) button.suggested-action:active, headerbar.selection-mode button.suggested-action:active { color: #3c3c3c; outline-color: rgba(60, 60, 60, 0.3); border-color: #828282; background-image: linear-gradient(to bottom, shade(shade(#cecece, 0.85), 1.05), shade(shade(#cecece, 0.85), 0.97)); box-shadow: inset 0 2px 1px -2px rgba(0, 0, 0, 0.6); border-color: #0f4278; }

.selection-mode.titlebar:not(headerbar) button.suggested-action:disabled, .selection-mode.titlebar:not(headerbar) label:disabled selection.suggested-action, label:disabled .selection-mode.titlebar:not(headerbar) selection.suggested-action, headerbar.selection-mode button.suggested-action:disabled, headerbar.selection-mode label:disabled selection.suggested-action, label:disabled headerbar.selection-mode selection.suggested-action { border-color: #828282; background-color: #e0e0e0; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); background-image: none; background: #cecece; border-color: #0f4278; }

.selection-mode.titlebar:not(headerbar) button.suggested-action:disabled label, .selection-mode.titlebar:not(headerbar) label:disabled selection.suggested-action label, label:disabled .selection-mode.titlebar:not(headerbar) selection.suggested-action label, .selection-mode.titlebar:not(headerbar) button.suggested-action:disabled, .selection-mode.titlebar:not(headerbar) label:disabled selection.suggested-action, label:disabled .selection-mode.titlebar:not(headerbar) selection.suggested-action, headerbar.selection-mode button.suggested-action:disabled label, headerbar.selection-mode label:disabled selection.suggested-action label, label:disabled headerbar.selection-mode selection.suggested-action label, headerbar.selection-mode button.suggested-action:disabled, headerbar.selection-mode label:disabled selection.suggested-action, label:disabled headerbar.selection-mode selection.suggested-action { color: #858585; }

.selection-mode.titlebar:not(headerbar) button.suggested-action:backdrop, headerbar.selection-mode button.suggested-action:backdrop { border-color: #898989; background-color: #cecece; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); border-color: #0f4278; }

.selection-mode.titlebar:not(headerbar) button.suggested-action:backdrop label, .selection-mode.titlebar:not(headerbar) button.suggested-action:backdrop, headerbar.selection-mode button.suggested-action:backdrop label, headerbar.selection-mode button.suggested-action:backdrop { color: #858585; }

.selection-mode.titlebar:not(headerbar) button.suggested-action:backdrop:disabled, .selection-mode.titlebar:not(headerbar) label:disabled selection:backdrop, label:disabled .selection-mode.titlebar:not(headerbar) selection:backdrop, headerbar.selection-mode button.suggested-action:backdrop:disabled, headerbar.selection-mode label:disabled selection:backdrop, label:disabled headerbar.selection-mode selection:backdrop { border-color: #898989; background-color: #e0e0e0; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); border-color: #0f4278; }

.selection-mode.titlebar:not(headerbar) button.suggested-action:backdrop:disabled label, .selection-mode.titlebar:not(headerbar) label:disabled selection:backdrop label, label:disabled .selection-mode.titlebar:not(headerbar) selection:backdrop label, .selection-mode.titlebar:not(headerbar) button.suggested-action:backdrop:disabled, .selection-mode.titlebar:not(headerbar) label:disabled selection:backdrop, label:disabled .selection-mode.titlebar:not(headerbar) selection:backdrop, headerbar.selection-mode button.suggested-action:backdrop:disabled label, headerbar.selection-mode label:disabled selection:backdrop label, label:disabled headerbar.selection-mode selection:backdrop label, headerbar.selection-mode button.suggested-action:backdrop:disabled, headerbar.selection-mode label:disabled selection:backdrop, label:disabled headerbar.selection-mode selection:backdrop { color: #a8a8a8; }

.selection-mode.titlebar:not(headerbar) .selection-menu, headerbar.selection-mode .selection-menu:backdrop, headerbar.selection-mode .selection-menu { border-color: rgba(57, 142, 231, 0); background-color: rgba(57, 142, 231, 0); background-image: none; box-shadow: none; padding-left: 10px; padding-right: 10px; }

.selection-mode.titlebar:not(headerbar) .selection-menu .arrow, headerbar.selection-mode .selection-menu:backdrop .arrow, headerbar.selection-mode .selection-menu .arrow { -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); color: rgba(255, 255, 255, 0.5); -gtk-icon-shadow: none; }

.tiled .titlebar:not(headerbar), .tiled-top .titlebar:not(headerbar), .tiled-right .titlebar:not(headerbar), .tiled-bottom .titlebar:not(headerbar), .tiled-left .titlebar:not(headerbar), .maximized .titlebar:not(headerbar), .fullscreen .titlebar:not(headerbar), .tiled headerbar, .tiled-top headerbar, .tiled-right headerbar, .tiled-bottom headerbar, .tiled-left headerbar, .maximized headerbar, .fullscreen headerbar { border-radius: 0; }

.default-decoration.titlebar:not(headerbar), headerbar.default-decoration { min-height: 24px; padding: 4px; }

.default-decoration.titlebar:not(headerbar) windowcontrols button, .default-decoration.titlebar:not(headerbar) windowcontrols menubutton, headerbar.default-decoration windowcontrols button, headerbar.default-decoration windowcontrols menubutton { min-height: 22px; min-width: 22px; margin: 0; padding: 0; }

.default-decoration.titlebar:not(headerbar) windowcontrols menubutton button, headerbar.default-decoration windowcontrols menubutton button { min-height: 20px; min-width: 20px; margin: 0; padding: 4px; }

.solid-csd .titlebar:dir(rtl):not(headerbar), .solid-csd .titlebar:dir(ltr):not(headerbar), .solid-csd headerbar:backdrop:dir(rtl), .solid-csd headerbar:backdrop:dir(ltr), .solid-csd headerbar:dir(rtl), .solid-csd headerbar:dir(ltr) { margin-left: -1px; margin-right: -1px; margin-top: -1px; border-radius: 0; box-shadow: none; }

headerbar > windowhandle > box, headerbar > windowhandle > box > box.start, headerbar > windowhandle > box > box.end { border-spacing: 3px; }

headerbar entry, headerbar separator { margin-top: 3px; margin-bottom: 3px; }

headerbar spinbutton, headerbar button { margin-top: 2px; margin-bottom: 2px; padding-top: 0; padding-bottom: 0; }

headerbar button label { min-width: 28px; min-height: 22px; }

headerbar button.titlebutton image { min-width: 22px; min-height: 22px; }

headerbar button:not(.image-button):not(.titlebutton) image { min-width: 22px; min-height: 22px; }

headerbar button.image-button { min-width: 22px; min-height: 22px; padding-left: 2px; padding-right: 2px; }

headerbar .stack-switcher button { min-width: 26px; min-height: 26px; }

headerbar .stack-switcher button:not(.text-button) { min-height: 22px; min-width: 22px; padding-left: 0px; padding-right: 0px; }

headerbar buttonbox { padding: 0px; }

headerbar buttonbox button { min-width: 26px; min-height: 26px; }

headerbar buttonbox button:not(.text-button) { min-width: 22px; padding-left: 0px; padding-right: 0px; }

headerbar switch { margin-top: 5px; margin-bottom: 5px; }

.background:not(.tiled):not(.maximized):not(.solid-csd) .titlebar:backdrop, .background:not(.tiled):not(.maximized):not(.solid-csd) .titlebar, .background:not(.tiled-top):not(.maximized):not(.solid-csd) .titlebar:backdrop, .background:not(.tiled-top):not(.maximized):not(.solid-csd) .titlebar, .background:not(.tiled-left):not(.maximized):not(.solid-csd) .titlebar:backdrop, .background:not(.tiled-left):not(.maximized):not(.solid-csd) .titlebar, .background:not(.tiled-right):not(.maximized):not(.solid-csd) .titlebar:backdrop, .background:not(.tiled-right):not(.maximized):not(.solid-csd) .titlebar, .background:not(.tiled-bottom):not(.maximized):not(.solid-csd) .titlebar:backdrop, .background:not(.tiled-bottom):not(.maximized):not(.solid-csd) .titlebar { border-top-left-radius: 7px; border-top-right-radius: 7px; }

window:not(.tiled):not(.maximized):not(.fullscreen):not(.solid-csd) separator:first-child + headerbar:backdrop, window:not(.tiled):not(.maximized):not(.fullscreen):not(.solid-csd) separator:first-child + headerbar, window:not(.tiled):not(.maximized):not(.fullscreen):not(.solid-csd) headerbar:first-child:backdrop, window:not(.tiled):not(.maximized):not(.fullscreen):not(.solid-csd) headerbar:first-child { border-top-left-radius: 7px; }

window:not(.tiled):not(.maximized):not(.fullscreen):not(.solid-csd) headerbar:last-child:backdrop, window:not(.tiled):not(.maximized):not(.fullscreen):not(.solid-csd) headerbar:last-child { border-top-right-radius: 7px; }

window:not(.tiled):not(.maximized):not(.fullscreen):not(.solid-csd) stack headerbar:first-child:backdrop, window:not(.tiled):not(.maximized):not(.fullscreen):not(.solid-csd) stack headerbar:first-child, window:not(.tiled):not(.maximized):not(.fullscreen):not(.solid-csd) stack headerbar:last-child:backdrop, window:not(.tiled):not(.maximized):not(.fullscreen):not(.solid-csd) stack headerbar:last-child { border-top-left-radius: 7px; border-top-right-radius: 7px; }

window.tiled headerbar, window.tiled headerbar:first-child, window.tiled headerbar:last-child, window.tiled headerbar:only-child, window.tiled headerbar:backdrop, window.tiled headerbar:backdrop:first-child, window.tiled dropdown.linked button:backdrop:nth-child(2):dir(rtl), dropdown.linked window.tiled button:backdrop:nth-child(2):dir(rtl), window.tiled combobox.linked button:backdrop:nth-child(2):dir(rtl), combobox.linked window.tiled button:backdrop:nth-child(2):dir(rtl), window.tiled .linked:not(.vertical) > combobox:first-child > box > button.combo:backdrop, window.tiled .linked.vertical > combobox:first-child > box > button.combo:backdrop, window.tiled headerbar:backdrop:last-child, window.tiled dropdown.linked button:backdrop:nth-child(2):dir(ltr), dropdown.linked window.tiled button:backdrop:nth-child(2):dir(ltr), window.tiled combobox.linked button:backdrop:nth-child(2):dir(ltr), combobox.linked window.tiled button:backdrop:nth-child(2):dir(ltr), window.tiled .linked:not(.vertical) > combobox:last-child > box > button.combo:backdrop, window.tiled .linked.vertical > combobox:last-child > box > button.combo:backdrop, window.tiled headerbar:backdrop:only-child, window.tiled .linked:not(.vertical) > combobox:only-child > box > button.combo:backdrop, window.tiled .linked.vertical > combobox:only-child > box > button.combo:backdrop, window.tiled-top headerbar, window.tiled-top headerbar:first-child, window.tiled-top headerbar:last-child, window.tiled-top headerbar:only-child, window.tiled-top headerbar:backdrop, window.tiled-top headerbar:backdrop:first-child, window.tiled-top dropdown.linked button:backdrop:nth-child(2):dir(rtl), dropdown.linked window.tiled-top button:backdrop:nth-child(2):dir(rtl), window.tiled-top combobox.linked button:backdrop:nth-child(2):dir(rtl), combobox.linked window.tiled-top button:backdrop:nth-child(2):dir(rtl), window.tiled-top .linked:not(.vertical) > combobox:first-child > box > button.combo:backdrop, window.tiled-top .linked.vertical > combobox:first-child > box > button.combo:backdrop, window.tiled-top headerbar:backdrop:last-child, window.tiled-top dropdown.linked button:backdrop:nth-child(2):dir(ltr), dropdown.linked window.tiled-top button:backdrop:nth-child(2):dir(ltr), window.tiled-top combobox.linked button:backdrop:nth-child(2):dir(ltr), combobox.linked window.tiled-top button:backdrop:nth-child(2):dir(ltr), window.tiled-top .linked:not(.vertical) > combobox:last-child > box > button.combo:backdrop, window.tiled-top .linked.vertical > combobox:last-child > box > button.combo:backdrop, window.tiled-top headerbar:backdrop:only-child, window.tiled-top .linked:not(.vertical) > combobox:only-child > box > button.combo:backdrop, window.tiled-top .linked.vertical > combobox:only-child > box > button.combo:backdrop, window.tiled-right headerbar, window.tiled-right headerbar:first-child, window.tiled-right headerbar:last-child, window.tiled-right headerbar:only-child, window.tiled-right headerbar:backdrop, window.tiled-right headerbar:backdrop:first-child, window.tiled-right dropdown.linked button:backdrop:nth-child(2):dir(rtl), dropdown.linked window.tiled-right button:backdrop:nth-child(2):dir(rtl), window.tiled-right combobox.linked button:backdrop:nth-child(2):dir(rtl), combobox.linked window.tiled-right button:backdrop:nth-child(2):dir(rtl), window.tiled-right .linked:not(.vertical) > combobox:first-child > box > button.combo:backdrop, window.tiled-right .linked.vertical > combobox:first-child > box > button.combo:backdrop, window.tiled-right headerbar:backdrop:last-child, window.tiled-right dropdown.linked button:backdrop:nth-child(2):dir(ltr), dropdown.linked window.tiled-right button:backdrop:nth-child(2):dir(ltr), window.tiled-right combobox.linked button:backdrop:nth-child(2):dir(ltr), combobox.linked window.tiled-right button:backdrop:nth-child(2):dir(ltr), window.tiled-right .linked:not(.vertical) > combobox:last-child > box > button.combo:backdrop, window.tiled-right .linked.vertical > combobox:last-child > box > button.combo:backdrop, window.tiled-right headerbar:backdrop:only-child, window.tiled-right .linked:not(.vertical) > combobox:only-child > box > button.combo:backdrop, window.tiled-right .linked.vertical > combobox:only-child > box > button.combo:backdrop, window.tiled-bottom headerbar, window.tiled-bottom headerbar:first-child, window.tiled-bottom headerbar:last-child, window.tiled-bottom headerbar:only-child, window.tiled-bottom headerbar:backdrop, window.tiled-bottom headerbar:backdrop:first-child, window.tiled-bottom dropdown.linked button:backdrop:nth-child(2):dir(rtl), dropdown.linked window.tiled-bottom button:backdrop:nth-child(2):dir(rtl), window.tiled-bottom combobox.linked button:backdrop:nth-child(2):dir(rtl), combobox.linked window.tiled-bottom button:backdrop:nth-child(2):dir(rtl), window.tiled-bottom .linked:not(.vertical) > combobox:first-child > box > button.combo:backdrop, window.tiled-bottom .linked.vertical > combobox:first-child > box > button.combo:backdrop, window.tiled-bottom headerbar:backdrop:last-child, window.tiled-bottom dropdown.linked button:backdrop:nth-child(2):dir(ltr), dropdown.linked window.tiled-bottom button:backdrop:nth-child(2):dir(ltr), window.tiled-bottom combobox.linked button:backdrop:nth-child(2):dir(ltr), combobox.linked window.tiled-bottom button:backdrop:nth-child(2):dir(ltr), window.tiled-bottom .linked:not(.vertical) > combobox:last-child > box > button.combo:backdrop, window.tiled-bottom .linked.vertical > combobox:last-child > box > button.combo:backdrop, window.tiled-bottom headerbar:backdrop:only-child, window.tiled-bottom .linked:not(.vertical) > combobox:only-child > box > button.combo:backdrop, window.tiled-bottom .linked.vertical > combobox:only-child > box > button.combo:backdrop, window.tiled-left headerbar, window.tiled-left headerbar:first-child, window.tiled-left headerbar:last-child, window.tiled-left headerbar:only-child, window.tiled-left headerbar:backdrop, window.tiled-left headerbar:backdrop:first-child, window.tiled-left dropdown.linked button:backdrop:nth-child(2):dir(rtl), dropdown.linked window.tiled-left button:backdrop:nth-child(2):dir(rtl), window.tiled-left combobox.linked button:backdrop:nth-child(2):dir(rtl), combobox.linked window.tiled-left button:backdrop:nth-child(2):dir(rtl), window.tiled-left .linked:not(.vertical) > combobox:first-child > box > button.combo:backdrop, window.tiled-left .linked.vertical > combobox:first-child > box > button.combo:backdrop, window.tiled-left headerbar:backdrop:last-child, window.tiled-left dropdown.linked button:backdrop:nth-child(2):dir(ltr), dropdown.linked window.tiled-left button:backdrop:nth-child(2):dir(ltr), window.tiled-left combobox.linked button:backdrop:nth-child(2):dir(ltr), combobox.linked window.tiled-left button:backdrop:nth-child(2):dir(ltr), window.tiled-left .linked:not(.vertical) > combobox:last-child > box > button.combo:backdrop, window.tiled-left .linked.vertical > combobox:last-child > box > button.combo:backdrop, window.tiled-left headerbar:backdrop:only-child, window.tiled-left .linked:not(.vertical) > combobox:only-child > box > button.combo:backdrop, window.tiled-left .linked.vertical > combobox:only-child > box > button.combo:backdrop, window.maximized headerbar, window.maximized headerbar:first-child, window.maximized headerbar:last-child, window.maximized headerbar:only-child, window.maximized headerbar:backdrop, window.maximized headerbar:backdrop:first-child, window.maximized dropdown.linked button:backdrop:nth-child(2):dir(rtl), dropdown.linked window.maximized button:backdrop:nth-child(2):dir(rtl), window.maximized combobox.linked button:backdrop:nth-child(2):dir(rtl), combobox.linked window.maximized button:backdrop:nth-child(2):dir(rtl), window.maximized .linked:not(.vertical) > combobox:first-child > box > button.combo:backdrop, window.maximized .linked.vertical > combobox:first-child > box > button.combo:backdrop, window.maximized headerbar:backdrop:last-child, window.maximized dropdown.linked button:backdrop:nth-child(2):dir(ltr), dropdown.linked window.maximized button:backdrop:nth-child(2):dir(ltr), window.maximized combobox.linked button:backdrop:nth-child(2):dir(ltr), combobox.linked window.maximized button:backdrop:nth-child(2):dir(ltr), window.maximized .linked:not(.vertical) > combobox:last-child > box > button.combo:backdrop, window.maximized .linked.vertical > combobox:last-child > box > button.combo:backdrop, window.maximized headerbar:backdrop:only-child, window.maximized .linked:not(.vertical) > combobox:only-child > box > button.combo:backdrop, window.maximized .linked.vertical > combobox:only-child > box > button.combo:backdrop, window.fullscreen headerbar, window.fullscreen headerbar:first-child, window.fullscreen headerbar:last-child, window.fullscreen headerbar:only-child, window.fullscreen headerbar:backdrop, window.fullscreen headerbar:backdrop:first-child, window.fullscreen dropdown.linked button:backdrop:nth-child(2):dir(rtl), dropdown.linked window.fullscreen button:backdrop:nth-child(2):dir(rtl), window.fullscreen combobox.linked button:backdrop:nth-child(2):dir(rtl), combobox.linked window.fullscreen button:backdrop:nth-child(2):dir(rtl), window.fullscreen .linked:not(.vertical) > combobox:first-child > box > button.combo:backdrop, window.fullscreen .linked.vertical > combobox:first-child > box > button.combo:backdrop, window.fullscreen headerbar:backdrop:last-child, window.fullscreen dropdown.linked button:backdrop:nth-child(2):dir(ltr), dropdown.linked window.fullscreen button:backdrop:nth-child(2):dir(ltr), window.fullscreen combobox.linked button:backdrop:nth-child(2):dir(ltr), combobox.linked window.fullscreen button:backdrop:nth-child(2):dir(ltr), window.fullscreen .linked:not(.vertical) > combobox:last-child > box > button.combo:backdrop, window.fullscreen .linked.vertical > combobox:last-child > box > button.combo:backdrop, window.fullscreen headerbar:backdrop:only-child, window.fullscreen .linked:not(.vertical) > combobox:only-child > box > button.combo:backdrop, window.fullscreen .linked.vertical > combobox:only-child > box > button.combo:backdrop, window.solid-csd headerbar, window.solid-csd headerbar:first-child, window.solid-csd headerbar:last-child, window.solid-csd headerbar:only-child, window.solid-csd headerbar:backdrop, window.solid-csd headerbar:backdrop:first-child, window.solid-csd dropdown.linked button:backdrop:nth-child(2):dir(rtl), dropdown.linked window.solid-csd button:backdrop:nth-child(2):dir(rtl), window.solid-csd combobox.linked button:backdrop:nth-child(2):dir(rtl), combobox.linked window.solid-csd button:backdrop:nth-child(2):dir(rtl), window.solid-csd .linked:not(.vertical) > combobox:first-child > box > button.combo:backdrop, window.solid-csd .linked.vertical > combobox:first-child > box > button.combo:backdrop, window.solid-csd headerbar:backdrop:last-child, window.solid-csd dropdown.linked button:backdrop:nth-child(2):dir(ltr), dropdown.linked window.solid-csd button:backdrop:nth-child(2):dir(ltr), window.solid-csd combobox.linked button:backdrop:nth-child(2):dir(ltr), combobox.linked window.solid-csd button:backdrop:nth-child(2):dir(ltr), window.solid-csd .linked:not(.vertical) > combobox:last-child > box > button.combo:backdrop, window.solid-csd .linked.vertical > combobox:last-child > box > button.combo:backdrop, window.solid-csd headerbar:backdrop:only-child, window.solid-csd .linked:not(.vertical) > combobox:only-child > box > button.combo:backdrop, window.solid-csd .linked.vertical > combobox:only-child > box > button.combo:backdrop { border-top-left-radius: 0; border-top-right-radius: 0; }

window.csd > .titlebar:not(headerbar) { padding: 0; background-color: transparent; background-image: none; border-style: none; border-color: transparent; box-shadow: none; }

.titlebar:not(headerbar) > separator { background-color: #828282; }

window.devel headerbar.titlebar { background: #cecece cross-fade(10% -gtk-icontheme("system-run-symbolic"), image(transparent)) 90% 0/256px 256px no-repeat, linear-gradient(to right, transparent 65%, rgba(57, 142, 231, 0.2)), linear-gradient(to top, #adadad, #b5b5b5 3px, #c4c4c4); }

window.devel headerbar.titlebar:backdrop { background: #cecece cross-fade(10% -gtk-icontheme("system-run-symbolic"), image(transparent)) 90% 0/256px 256px no-repeat, image(#cecece); /* background-color would flash */ }

.background:not(.csd):not(.ssd):not(.solid-csd) headerbar, .background:not(.csd):not(.ssd):not(.solid-csd) headerbar:not(:last-child), .background:not(.csd):not(.ssd):not(.solid-csd) headerbar:backdrop, .background:not(.csd):not(.ssd):not(.solid-csd) headerbar:backdrop:not(:last-child) { border-radius: 0; border-top-color: transparent; box-shadow: none; }

/************ Pathbars * */
.pathbar > button.text-button, .pathbar > button.image-button, .pathbar > button { padding-left: 4px; padding-right: 4px; }

.pathbar > button.text-button.image-button label { padding-left: 0; padding-right: 0; }

.pathbar > button.text-button.image-button label:last-child, .pathbar > button label:last-child { padding-right: 8px; }

.pathbar > button.text-button.image-button label:first-child, .pathbar > button label:first-child { padding-left: 8px; }

.pathbar > button image { padding-left: 4px; padding-right: 4px; }

.pathbar > button.slider-button { padding-left: 0; padding-right: 0; }

/************** Tree Views * */
columnview.view, treeview.view { border-left-color: #9c9c9c; border-top-color: #cecece; }

*, headerbar.selection-mode .subtitle:link, .selection-mode.titlebar:not(headerbar) .subtitle:link { -GtkTreeView-horizontal-separator: 4; -GtkTreeView-grid-line-width: 1; -GtkTreeView-grid-line-pattern: ''; -GtkTreeView-tree-line-width: 1; -GtkTreeView-tree-line-pattern: ''; -GtkTreeView-expander-size: 16; }

columnview.view:selected:focus-within, columnview.view:selected, treeview.view:selected:focus-within, treeview.view:selected { border-radius: 0; }

columnview.view:selected:backdrop, columnview.view:selected, treeview.view:selected:backdrop, treeview.view:selected { border-left-color: #9cc7f3; border-top-color: rgba(60, 60, 60, 0.1); }

columnview.view:disabled, treeview.view:disabled { color: #858585; }

columnview.view:disabled:selected, treeview.view:disabled:selected { color: #88bbf1; }

columnview.view:disabled:selected:backdrop, treeview.view:disabled:selected:backdrop { color: #4d89c7; }

columnview.view:disabled:backdrop, treeview.view:disabled:backdrop { color: #a8a8a8; }

columnview.view.separator, treeview.view.separator { min-height: 2px; color: #cecece; }

columnview.view.separator:backdrop, treeview.view.separator:backdrop { color: rgba(206, 206, 206, 0.1); }

columnview.view:backdrop, treeview.view:backdrop { border-left-color: #aaaaaa; border-top: #cecece; }

columnview.view:drop(active), treeview.view:drop(active) { border-style: solid none; border-width: 1px; border-color: #0f4278; }

columnview.view:drop(active).after, treeview.view:drop(active).after { border-top-style: none; }

columnview.view:drop(active).before, treeview.view:drop(active).before { border-bottom-style: none; }

columnview.view.expander, treeview.view.expander { min-width: 16px; min-height: 16px; -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); color: #767676; }

columnview.view.expander:dir(rtl), treeview.view.expander:dir(rtl) { -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl"); }

columnview.view.expander:hover, treeview.view.expander:hover { color: #3c3c3c; }

columnview.view.expander:selected, treeview.view.expander:selected { color: #c4ddf8; }

columnview.view.expander:selected:hover, treeview.view.expander:selected:hover { color: #ffffff; }

columnview.view.expander:selected:backdrop, treeview.view.expander:selected:backdrop { color: #68829c; }

columnview.view.expander:checked, treeview.view.expander:checked { -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }

columnview.view.expander:backdrop, treeview.view.expander:backdrop { color: #a8a8a8; }

columnview.view.progressbar, treeview.view.progressbar { color: #fcfcfc; border: 1px solid #0f4278; border-radius: 4px; background-color: #398ee7; background-image: linear-gradient(to bottom, #398ee7, #1a74d3); box-shadow: inset 0 1px rgba(255, 255, 255, 0.3), 0 1px rgba(0, 0, 0, 0.2); }

columnview.view.progressbar:selected:focus-within, columnview.view.progressbar:selected, treeview.view.progressbar:selected:focus-within, treeview.view.progressbar:selected { border-radius: 4px; color: #398ee7; box-shadow: none; background-image: linear-gradient(to bottom, #fcfcfc, #e3e3e3); }

columnview.view.progressbar:selected:focus-within:backdrop, columnview.view.progressbar:selected:backdrop, treeview.view.progressbar:selected:focus-within:backdrop, treeview.view.progressbar:selected:backdrop { color: #398ee7; border-color: #0f4278; background-color: #f9f9f9; }

columnview.view.progressbar:backdrop, treeview.view.progressbar:backdrop { color: #f9f9f9; background-image: none; box-shadow: none; }

columnview.view.trough, treeview.view.trough { background-color: rgba(60, 60, 60, 0.1); border-radius: 4px; }

columnview.view.trough:selected:focus-within, columnview.view.trough:selected, treeview.view.trough:selected:focus-within, treeview.view.trough:selected { background-color: rgba(255, 255, 255, 0.3); border-radius: 4px; border-width: 1px 0; border-style: solid; border-color: #398ee7; }

columnview.view > header > button, treeview.view > header > button { color: #9c9c9c; background-color: #fcfcfc; font-weight: bold; text-shadow: none; box-shadow: none; }

columnview.view > header > button:hover, treeview.view > header > button:hover { color: #6c6c6c; box-shadow: none; transition: none; }

columnview.view > header > button:active, treeview.view > header > button:active { color: #3c3c3c; transition: none; }

columnview.view > header > button sort-indicator, treeview.view > header > button sort-indicator { min-height: 16px; min-width: 16px; }

columnview.view > header > button sort-indicator.ascending, treeview.view > header > button sort-indicator.ascending { -gtk-icon-source: -gtk-icontheme("pan-up-symbolic"); }

columnview.view > header > button sort-indicator.descending, treeview.view > header > button sort-indicator.descending { -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }

columnview.view > header button:last-child:backdrop, columnview.view > header button:last-child, columnview.view > header dropdown.linked button:nth-child(2):dir(ltr), dropdown.linked columnview.view > header button:nth-child(2):dir(ltr), columnview.view > header combobox.linked button:nth-child(2):dir(ltr), combobox.linked columnview.view > header button:nth-child(2):dir(ltr), columnview.view > header .linked:not(.vertical) > combobox:last-child > box > button.combo, columnview.view > header .linked.vertical > combobox:last-child > box > button.combo, treeview.view > header button:last-child:backdrop, treeview.view > header button:last-child, treeview.view > header dropdown.linked button:nth-child(2):dir(ltr), dropdown.linked treeview.view > header button:nth-child(2):dir(ltr), treeview.view > header combobox.linked button:nth-child(2):dir(ltr), combobox.linked treeview.view > header button:nth-child(2):dir(ltr), treeview.view > header .linked:not(.vertical) > combobox:last-child > box > button.combo, treeview.view > header .linked.vertical > combobox:last-child > box > button.combo { border-right-style: none; }

columnview.view button.dnd:active, columnview.view button.dnd:selected, columnview.view headerbar.selection-mode .dnd.subtitle:link, headerbar.selection-mode columnview.view .dnd.subtitle:link, columnview.view .selection-mode.titlebar:not(headerbar) .dnd.subtitle:link, .selection-mode.titlebar:not(headerbar) columnview.view .dnd.subtitle:link, columnview.view button.dnd:hover, columnview.view button.dnd, columnview.view header.button.dnd:active, columnview.view header.button.dnd:selected, columnview.view header.button.dnd:hover, columnview.view header.button.dnd, treeview.view button.dnd:active, treeview.view button.dnd:selected, treeview.view headerbar.selection-mode .dnd.subtitle:link, headerbar.selection-mode treeview.view .dnd.subtitle:link, treeview.view .selection-mode.titlebar:not(headerbar) .dnd.subtitle:link, .selection-mode.titlebar:not(headerbar) treeview.view .dnd.subtitle:link, treeview.view button.dnd:hover, treeview.view button.dnd, treeview.view header.button.dnd:active, treeview.view header.button.dnd:selected, treeview.view header.button.dnd:hover, treeview.view header.button.dnd { padding: 0 6px; color: #fcfcfc; background-image: none; background-color: #398ee7; border-style: none; border-radius: 0; box-shadow: inset 0 0 0 1px #fcfcfc; text-shadow: none; transition: none; }

columnview.view acceleditor > label, treeview.view acceleditor > label { background-color: #398ee7; }

columnview.view > header > button, treeview.view > header > button, columnview.view > header > button:hover, treeview.view > header > button:hover, columnview.view > header > button:active, treeview.view > header > button:active { padding: 0 6px; background-image: none; border-style: none solid solid none; border-color: #cecece; border-radius: 0; text-shadow: none; }

columnview.view > header > button:backdrop, treeview.view > header > button:backdrop { color: #aaaaaa; border-color: #cecece; border-style: none solid solid none; background-image: none; background-color: #f9f9f9; }

/********* Menus * */
menubar, .menubar { -GtkWidget-window-dragging: true; padding: 0px; }

menubar:backdrop, .menubar:backdrop { background-color: #cecece; }

menubar > item, menubar > menuitem, .menubar > item, .menubar > menuitem { min-height: 16px; padding: 3px 8px; border: 1px solid transparent; }

menubar > item:hover, menubar > menuitem:hover, .menubar > item:hover, .menubar > menuitem:hover { background-image: linear-gradient(to bottom, shade(#398ee7, 1.2), shade(#398ee7, 1)); color: #ffffff; border-color: shade(#398ee7, 1.1); }

menubar > item:disabled, menubar > menuitem:disabled, .menubar > item:disabled, .menubar > menuitem:disabled { color: #858585; box-shadow: none; }

menu, .menu, .context-menu { margin: 4px; padding: 2px 0px; background-color: #fcfcfc; border: 1px solid #828282; }

.csd menu, .csd .menu, .csd .context-menu { border: none; }

menu:backdrop, .menu:backdrop, .context-menu:backdrop { background-color: #f9f9f9; }

menu menuitem, .menu menuitem, .context-menu menuitem { min-height: 16px; min-width: 40px; padding: 4px 6px; text-shadow: none; }

menu menuitem:hover, .menu menuitem:hover, .context-menu menuitem:hover { color: #ffffff; background-image: linear-gradient(to bottom, shade(#398ee7, 1.2), shade(#398ee7, 1)); box-shadow: inset 1px 1px shade(#398ee7, 0.8), inset -1px -1px shade(#398ee7, 0.8); }

menu menuitem:disabled, .menu menuitem:disabled, .context-menu menuitem:disabled { color: #858585; }

menu menuitem:disabled:backdrop, .menu menuitem:disabled:backdrop, .context-menu menuitem:disabled:backdrop { color: #a8a8a8; }

menu menuitem:backdrop, menu menuitem:backdrop:hover, .menu menuitem:backdrop, .menu menuitem:backdrop:hover, .context-menu menuitem:backdrop, .context-menu menuitem:backdrop:hover { color: #858585; background-color: transparent; }

menu menuitem arrow, .menu menuitem arrow, .context-menu menuitem arrow { min-height: 16px; min-width: 16px; }

menu menuitem arrow:dir(ltr), .menu menuitem arrow:dir(ltr), .context-menu menuitem arrow:dir(ltr) { -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); margin-left: 10px; }

menu menuitem arrow:dir(rtl), .menu menuitem arrow:dir(rtl), .context-menu menuitem arrow:dir(rtl) { -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl"); margin-right: 10px; }

menu menuitem label:dir(rtl), menu menuitem label:dir(ltr), .menu menuitem label:dir(rtl), .menu menuitem label:dir(ltr), .context-menu menuitem label:dir(rtl), .context-menu menuitem label:dir(ltr) { color: inherit; }

menu > arrow, .menu > arrow, .context-menu > arrow { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; min-height: 16px; min-width: 16px; padding: 4px; background-color: #fcfcfc; border-radius: 0; }

menu > arrow.top, .menu > arrow.top, .context-menu > arrow.top { margin-top: -6px; border-bottom: 1px solid #e9e9e9; -gtk-icon-source: -gtk-icontheme("pan-up-symbolic"); }

menu > arrow.bottom, .menu > arrow.bottom, .context-menu > arrow.bottom { margin-bottom: -6px; border-top: 1px solid #e9e9e9; -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }

menu > arrow:hover, .menu > arrow:hover, .context-menu > arrow:hover { background-color: #e9e9e9; }

menu > arrow:backdrop, .menu > arrow:backdrop, .context-menu > arrow:backdrop { background-color: #f9f9f9; }

menu > arrow:disabled, .menu > arrow:disabled, .context-menu > arrow:disabled { color: transparent; background-color: transparent; border-color: transparent; }

menuitem accelerator { color: alpha(currentColor,0.55); }

menuitem check, menuitem radio { min-height: 16px; min-width: 16px; }

menuitem check:dir(ltr), menuitem radio:dir(ltr) { margin-right: 7px; }

menuitem check:dir(rtl), menuitem radio:dir(rtl) { margin-left: 7px; }

/*************** Popovers   * */
popover.background { padding: 2px; border-radius: 5px; background-color: #fcfcfc; box-shadow: 0 1px 2px rgba(0, 0, 0, 0.3); }

popover.background modelbutton:hover, popover.background checkbutton:hover, popover.background radiobutton:hover { color: #ffffff; }

.csd popover.background, popover.background { border: 1px solid #828282; }

popover.background:backdrop { background-color: #cecece; box-shadow: none; }

popover.background > list, popover.background > .view, popover.background > iconview, popover.background > toolbar { border-style: none; background-color: transparent; }

.csd popover.background.touch-selection, .csd popover.background.magnifier, popover.background.touch-selection, popover.background.magnifier { border: 1px solid rgba(255, 255, 255, 0.1); }

popover.background separator { margin: 3px; }

popover.background list separator { margin: 0px; }

/************* Notebooks * */
notebook.frame { border-style: none; }

notebook.frame > header { margin-left: 0; }

notebook.frame > stack:not(:only-child) { border: 1px solid shade(#cecece, 0.9); }

notebook > header { padding: 1px; background-color: #cecece; }

notebook > header:backdrop { border-color: #898989; background-color: #cecece; }

notebook > header tabs { margin: -1px; }

notebook > header.top > stack { border-top-style: none; }

notebook > header.top > tabs > tab { border-radius: 3px 3px 0 0; border: 1px solid shade(#cecece, 0.9); }

notebook > header.top > tabs > tab:backdrop { box-shadow: none; }

notebook > header.top > tabs > tab:checked { border-width: 1px 1px 0 1px; }

notebook > header.bottom > stack { border-bottom-style: none; }

notebook > header.bottom > tabs > tab { border-radius: 0 0 3px 3px; }

notebook > header.bottom > tabs > tab:backdrop { box-shadow: none; }

notebook > header.bottom > tabs > tab:checked { border-width: 0 1px 1px 1px; }

notebook > header.left > stack { border-left-style: none; }

notebook > header.left > tabs > tab { border-radius: 3px 0 0 3px; }

notebook > header.left > tabs > tab:backdrop { box-shadow: none; }

notebook > header.left > tabs > tab:checked { border-width: 1px 0 1px 1px; }

notebook > header.right > stack { border-right-style: none; }

notebook > header.right > tabs > tab { border-radius: 0 3px 3px 0; }

notebook > header.right > tabs > tab:backdrop { box-shadow: none; }

notebook > header.right > tabs > tab:checked { border-width: 1px 1px 1px 0; }

notebook > header.top > tabs > arrow { border-top-style: none; }

notebook > header.bottom > tabs > arrow { border-bottom-style: none; }

notebook > header.top > tabs > arrow, notebook > header.bottom > tabs > arrow { margin-left: -5px; margin-right: -5px; padding-left: 4px; padding-right: 4px; }

notebook > header.top > tabs > arrow.down, notebook > header.bottom > tabs > arrow.down { -gtk-icon-source: -gtk-icontheme("pan-start-symbolic"); }

notebook > header.top > tabs > arrow.up, notebook > header.bottom > tabs > arrow.up { -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); }

notebook > header.left > tabs > arrow { border-left-style: none; }

notebook > header.right > tabs > arrow { border-right-style: none; }

notebook > header.left > tabs > arrow, notebook > header.right > tabs > arrow { margin-top: -5px; margin-bottom: -5px; padding-top: 4px; padding-bottom: 4px; }

notebook > header.left > tabs > arrow.down, notebook > header.right > tabs > arrow.down { -gtk-icon-source: -gtk-icontheme("pan-up-symbolic"); }

notebook > header.left > tabs > arrow.up, notebook > header.right > tabs > arrow.up { -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }

notebook > header > tabs > arrow { min-height: 16px; min-width: 16px; border-radius: 0; }

notebook > header > tabs > arrow:hover:not(:active):not(:backdrop) { background-clip: padding-box; background-image: none; background-color: rgba(255, 255, 255, 0.3); border-color: transparent; box-shadow: none; }

notebook > header > tabs > arrow:disabled { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; }

notebook > header > tabs > tab { min-height: 20px; min-width: 24px; padding: 3px 12px; outline-offset: -5px; color: #858585; background-color: #cecece; border-width: 1px; border-radius: 3px; border-color: shade(#cecece, 0.9); border-style: solid; }

notebook > header > tabs > tab:hover { color: #616161; }

notebook > header > tabs > tab:hover.reorderable-page { border-color: rgba(130, 130, 130, 0.3); background-color: rgba(206, 206, 206, 0.2); }

notebook > header > tabs > tab:backdrop { color: #a2a2a2; }

notebook > header > tabs > tab:backdrop.reorderable-page { border-color: transparent; background-color: transparent; }

notebook > header > tabs > tab:checked { color: #3c3c3c; background-color: shade(#cecece, 1.05); border-width: 1px 1px 0 1px; }

notebook > header > tabs > tab:checked:backdrop { background-color: #cecece; }

notebook > header > tabs > tab:checked.reorderable-page { border-color: rgba(130, 130, 130, 0.5); background-color: shade(#cecece, 1.05); }

notebook > header > tabs > tab:backdrop:checked { color: #858585; }

notebook > header > tabs > tab:backdrop:checked.reorderable-page { border-color: #898989; background-color: #cecece; }

notebook > header > tabs > tab button.flat, notebook > header > tabs > tab button.sidebar-button { padding: 0; margin-top: 1px; margin-bottom: 1px; min-width: 16px; min-height: 16px; }

notebook > header > tabs > tab button.flat:hover, notebook > header > tabs > tab button.sidebar-button:hover { color: currentColor; }

notebook > header > tabs > tab button.flat, notebook > header > tabs > tab button.sidebar-button, notebook > header > tabs > tab button.flat:backdrop { color: alpha(currentColor,0.3); }

notebook > header > tabs > tab button.flat:last-child, notebook > header > tabs > tab button.sidebar-button:last-child { margin-left: 1px; margin-right: -1px; }

notebook > header > tabs > tab button.flat:first-child, notebook > header > tabs > tab button.sidebar-button:first-child { margin-left: -1px; margin-right: 1px; }

notebook > header.top tabs, notebook > header.bottom tabs { padding: 0; }

notebook > header.top tabs:not(:only-child), notebook > header.bottom tabs:not(:only-child) { margin-left: 2px; margin-right: 2px; }

notebook > header.top tabs:first-child, notebook > header.bottom tabs:first-child { margin-left: -3px; }

notebook > header.top tabs:last-child, notebook > header.bottom tabs:last-child { margin-right: -3px; }

notebook > header.top tabs tab, notebook > header.bottom tabs tab { margin-left: 2px; margin-right: 2px; }

notebook > header.left tabs, notebook > header.right tabs { padding: 0; }

notebook > header.left tabs:not(:only-child), notebook > header.right tabs:not(:only-child) { margin-top: 2px; margin-bottom: 2px; }

notebook > header.left tabs:first-child, notebook > header.right tabs:first-child { margin-top: -3px; }

notebook > header.left tabs:last-child, notebook > header.right tabs:last-child { margin-bottom: -3px; }

notebook > header.left tabs tab, notebook > header.right tabs tab { margin-top: 2px; margin-bottom: 2px; }

notebook > header.top tab { padding-bottom: 4px; }

notebook > header.bottom tab { padding-top: 4px; }

notebook > header.top > tabs { margin-bottom: -2px; }

notebook > header.bottom > tabs { margin-top: -2px; }

notebook > header.left > tabs { margin-right: -2px; }

notebook > header.right > tabs { margin-left: -2px; }

notebook > header { margin-left: 6px; }

notebook > stack:not(:only-child) { background-color: shade(#cecece, 1.05); border-width: 1px; border-color: shade(#cecece, 0.9); border-style: solid; }

notebook > stack:not(:only-child):backdrop { background-color: #cecece; }

/************** Scrollbars * */
scrollbar { transition: 300ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

*, headerbar.selection-mode .subtitle:link, .selection-mode.titlebar:not(headerbar) .subtitle:link { -GtkScrollbar-has-backward-stepper: false; -GtkScrollbar-has-forward-stepper: false; }

scrollbar.vertical { background-image: linear-gradient(to right, #e8e8e8, white); }

scrollbar.vertical slider { background-image: linear-gradient(to right, #dbdbdb, #d1d1d1); }

scrollbar.vertical slider:hover { background-image: linear-gradient(to right, #c1c1c1, #cbcbcb); }

scrollbar.horizontal { background-image: linear-gradient(to bottom, #e8e8e8, white); }

scrollbar.horizontal slider { background-image: linear-gradient(to bottom, #dbdbdb, #d1d1d1); }

scrollbar.horizontal slider:hover { background-image: linear-gradient(to bottom, #c1c1c1, #cbcbcb); }

scrollbar.top { border-bottom: 1px solid #dbdbdb; }

scrollbar.bottom { border-top: 1px solid #dbdbdb; }

scrollbar.left { border-right: 1px solid #dbdbdb; }

scrollbar.right { border-left: 1px solid #dbdbdb; }

scrollbar:backdrop { background-color: #c6c6c6; border-color: #dbdbdb; transition: 200ms ease-out; }

scrollbar slider { min-width: 7px; min-height: 7px; margin: 3px; border: 1px solid #828282; border-radius: 10px; background-clip: padding-box; }

scrollbar slider:hover:active { background-color: #1a74d3; }

scrollbar slider:backdrop { background-color: white; }

scrollbar slider:disabled { background-color: transparent; }

scrollbar.fine-tune slider { min-width: 4px; min-height: 4px; }

scrollbar.fine-tune.horizontal slider { border-width: 5px 4px; }

scrollbar.fine-tune.vertical slider { border-width: 4px 5px; }

scrollbar.overlay-indicator:not(.dragging):not(.hovering) { border-color: transparent; opacity: 0.4; background-color: transparent; }

scrollbar.overlay-indicator:not(.dragging):not(.hovering) slider { margin: 0; min-width: 6px; min-height: 6px; background-color: shade(#3c3c3c, 0.9); background-image: none; border: 1px solid white; }

scrollbar.overlay-indicator:not(.dragging):not(.hovering) button { min-width: 5px; min-height: 5px; background-color: shade(#3c3c3c, 0.9); background-image: none; background-clip: padding-box; border-radius: 100%; border: 1px solid white; -gtk-icon-source: none; }

scrollbar.overlay-indicator:not(.dragging):not(.hovering).horizontal slider { margin: 0 2px; min-width: 40px; }

scrollbar.overlay-indicator:not(.dragging):not(.hovering).horizontal button { margin: 1px 2px; min-width: 5px; }

scrollbar.overlay-indicator:not(.dragging):not(.hovering).vertical slider { margin: 2px 0; min-height: 40px; }

scrollbar.overlay-indicator:not(.dragging):not(.hovering).vertical button { margin: 2px 1px; min-height: 5px; }

scrollbar.overlay-indicator.dragging, scrollbar.overlay-indicator.hovering { opacity: 0.8; }

scrollbar.horizontal slider { min-width: 40px; }

scrollbar.vertical slider { min-height: 40px; }

scrollbar button { padding: 0; min-width: 12px; min-height: 12px; border-style: none; border-radius: 0; transition-property: min-height, min-width, color; border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: #cecece; }

scrollbar button:hover { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: #595959; }

scrollbar button:active, scrollbar button:checked { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: #1a74d3; }

scrollbar button:disabled { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: rgba(206, 206, 206, 0.2); }

scrollbar button:backdrop { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: white; }

scrollbar button:backdrop:disabled, scrollbar label:disabled selection:backdrop, label:disabled scrollbar selection:backdrop { border-color: transparent; background-color: transparent; background-image: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); text-shadow: none; -gtk-icon-shadow: none; color: rgba(255, 255, 255, 0.2); }

scrollbar.vertical button.down { -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }

scrollbar.vertical button.up { -gtk-icon-source: -gtk-icontheme("pan-up-symbolic"); }

scrollbar.horizontal button.down { -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); }

scrollbar.horizontal button.up { -gtk-icon-source: -gtk-icontheme("pan-start-symbolic"); }

treeview ~ scrollbar.vertical { border-top: 1px solid #828282; margin-top: -1px; }

/********** Switch * */
switch { font-size: 0; outline-offset: -4px; box-shadow: inset 0 1px rgba(0, 0, 0, 0.1), 0 1px transparent; border: 1px solid alpha(black,0.25); border-radius: 10px; background-color: #afafaf; text-shadow: 0 1px rgba(0, 0, 0, 0.1); min-height: 20px; min-width: 20px; transition: all 200ms ease-in; /* only show i / o for the accessible theme */ }

switch:checked { box-shadow: inset 0 1px rgba(0, 0, 0, 0.1), 0 1px transparent; border-color: shade(#0f4278, 1.1); background-image: linear-gradient(to bottom, shade(#398ee7, 1.1), #398ee7); text-shadow: 0 1px rgba(15, 66, 120, 0.5), 0 0 2px rgba(255, 255, 255, 0.6); }

switch:disabled { border-color: #828282; background-color: #e0e0e0; box-shadow: 0 1px transparent; text-shadow: none; }

switch:backdrop { border-color: #898989; background-color: #b6b6b6; box-shadow: none; text-shadow: none; transition: 200ms ease-out; }

switch:backdrop:checked { color: #cecece; border-color: rgba(15, 66, 120, 0.7); background-color: rgba(57, 142, 231, 0.7); background-image: none; box-shadow: none; }

switch:disabled { border-color: #898989; background-image: none; background-color: #e0e0e0; }

switch slider { margin: -1px; border: 1px solid alpha(black,0.2); border-radius: 10px; min-width: 20px; min-height: 20px; transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); color: #3c3c3c; outline-color: rgba(60, 60, 60, 0.3); border-color: #828282; background-image: linear-gradient(to bottom, #dbdbdb 20%, #cecece 90%); box-shadow: inset 0 1px rgba(255, 255, 255, 0.6), inset 0 -2px lightgray, inset 0 -1px #afafaf, 0 1px rgba(0, 0, 0, 0.1); }

switch image { color: transparent; }

switch:hover slider { color: #3c3c3c; outline-color: rgba(60, 60, 60, 0.3); border-color: #828282; background-image: linear-gradient(to bottom, #e5e5e5 10%, #d8d8d8 90%); box-shadow: inset 0 1px rgba(255, 255, 255, 0.6), inset 0 -2px #dbdbdb, inset 0 -1px #b5b5b5, 0 1px rgba(0, 0, 0, 0.1); }

switch:checked slider { border: 1px solid alpha(#0f4278,0.8); }

switch:disabled slider { border-color: #828282; background-color: #e0e0e0; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

switch:disabled slider label, switch:disabled slider { color: #858585; }

switch:backdrop slider { transition: 200ms ease-out; border-color: #898989; background-color: #cecece; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

switch:backdrop slider label, switch:backdrop slider { color: #858585; }

switch:backdrop:checked slider { border-color: rgba(15, 66, 120, 0.7); }

switch:backdrop:disabled slider, label:disabled selection:backdrop slider { border-color: #898989; background-color: #e0e0e0; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

switch:backdrop:disabled slider label, label:disabled selection:backdrop slider label, switch:backdrop:disabled slider, label:disabled selection:backdrop slider { color: #a8a8a8; }

row:selected switch, headerbar.selection-mode row.subtitle:link switch, .selection-mode.titlebar:not(headerbar) row.subtitle:link switch { box-shadow: none; border-color: #0f4278; }

row:selected switch:backdrop, headerbar.selection-mode row.subtitle:link switch:backdrop, .selection-mode.titlebar:not(headerbar) row.subtitle:link switch:backdrop { border-color: #0f4278; }

row:selected switch.slider:dir(rtl), headerbar.selection-mode row.subtitle:link switch.slider:dir(rtl), .selection-mode.titlebar:not(headerbar) row.subtitle:link switch.slider:dir(rtl) { border-left-color: #828282; }

row:selected switch.slider:dir(ltr), headerbar.selection-mode row.subtitle:link switch.slider:dir(ltr), .selection-mode.titlebar:not(headerbar) row.subtitle:link switch.slider:dir(ltr) { border-right-color: #828282; }

row:selected switch.slider:checked, row:selected switch.slider, headerbar.selection-mode row.subtitle:link switch.slider, .selection-mode.titlebar:not(headerbar) row.subtitle:link switch.slider { border-color: #0f4278; }

/************************* Check and Radio items * */
.view.content-view.check:not(list), iconview.content-view.check:not(list) { -gtk-icon-shadow: none; -gtk-icon-source: -gtk-scaled(url("assets/checkbox-selectionmode.png"), url("assets/checkbox-selectionmode@2.png")); background-color: transparent; }

.view.content-view.check:hover:not(list), iconview.content-view.check:hover:not(list) { -gtk-icon-shadow: none; -gtk-icon-source: -gtk-scaled(url("assets/checkbox-hover-selectionmode.png"), url("assets/checkbox-hover-selectionmode@2.png")); background-color: transparent; }

.view.content-view.check:active:not(list), iconview.content-view.check:active:not(list) { -gtk-icon-shadow: none; -gtk-icon-source: -gtk-scaled(url("assets/checkbox-active-selectionmode.png"), url("assets/checkbox-active-selectionmode@2.png")); background-color: transparent; }

.view.content-view.check:backdrop:not(list), iconview.content-view.check:backdrop:not(list) { -gtk-icon-shadow: none; -gtk-icon-source: -gtk-scaled(url("assets/checkbox-backdrop-selectionmode.png"), url("assets/checkbox-backdrop-selectionmode@2.png")); background-color: transparent; }

.view.content-view.check:checked:not(list), iconview.content-view.check:checked:not(list) { -gtk-icon-shadow: none; -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-selectionmode.png"), url("assets/checkbox-checked-selectionmode@2.png")); background-color: transparent; }

.view.content-view.check:checked:hover:not(list), iconview.content-view.check:checked:hover:not(list) { -gtk-icon-shadow: none; -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-hover-selectionmode.png"), url("assets/checkbox-checked-hover-selectionmode@2.png")); background-color: transparent; }

.view.content-view.check:checked:active:not(list), iconview.content-view.check:checked:active:not(list) { -gtk-icon-shadow: none; -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-active-selectionmode.png"), url("assets/checkbox-checked-active-selectionmode@2.png")); background-color: transparent; }

.view.content-view.check:backdrop:checked:not(list), iconview.content-view.check:backdrop:checked:not(list) { -gtk-icon-shadow: none; -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-backdrop-selectionmode.png"), url("assets/checkbox-checked-backdrop-selectionmode@2.png")); background-color: transparent; }

checkbutton.text-button, radiobutton.text-button { padding: 2px 0; outline-offset: 0; }

checkbutton.text-button label:not(:only-child):first-child, radiobutton.text-button label:not(:only-child):first-child { margin-left: 4px; }

checkbutton.text-button label:not(:only-child):last-child, radiobutton.text-button label:not(:only-child):last-child { margin-right: 4px; }

check, radio { margin: 0 4px; min-height: 14px; min-width: 14px; border: 1px solid; -gtk-icon-source: none; color: #3c3c3c; outline-color: rgba(60, 60, 60, 0.3); border-color: #9b9b9b; background-image: linear-gradient(to bottom, #e8e8e8 20%, #dbdbdb 90%); box-shadow: inset 0 1px rgba(255, 255, 255, 0.8), inset 0 -2px #e0e0e0, inset 0 -1px #bcbcbc, 0 1px rgba(0, 0, 0, 0.1); }

check:only-child, radio:only-child { margin: 0; }

check:hover, radio:hover { color: #3c3c3c; outline-color: rgba(60, 60, 60, 0.3); border-color: #828282; background-image: linear-gradient(to bottom, #e5e5e5 10%, #d8d8d8 90%); box-shadow: inset 0 1px rgba(255, 255, 255, 0.6), inset 0 -2px #dbdbdb, inset 0 -1px #b5b5b5, 0 1px rgba(0, 0, 0, 0.1); }

check:active, radio:active { color: #3c3c3c; outline-color: rgba(60, 60, 60, 0.3); border-color: #828282; background-image: linear-gradient(to bottom, shade(shade(#cecece, 0.85), 1.05), shade(shade(#cecece, 0.85), 0.97)); box-shadow: inset 0 2px 1px -2px rgba(0, 0, 0, 0.6); }

check:disabled, radio:disabled { border-color: #828282; background-color: #e0e0e0; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

check:disabled label, check:disabled, radio:disabled label, radio:disabled { color: #858585; }

check:backdrop, radio:backdrop { border-color: #898989; background-color: #cecece; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); transition: 200ms ease-out; }

check:backdrop label, check:backdrop, radio:backdrop label, radio:backdrop { color: #858585; }

check:backdrop:disabled, label:disabled selection:backdrop, radio:backdrop:disabled { border-color: #898989; background-color: #e0e0e0; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

check:backdrop:disabled label, label:disabled selection:backdrop label, check:backdrop:disabled, label:disabled selection:backdrop, radio:backdrop:disabled label, radio:backdrop:disabled { color: #a8a8a8; }

row:selected check, headerbar.selection-mode row.subtitle:link check, .selection-mode.titlebar:not(headerbar) row.subtitle:link check, row:selected radio, headerbar.selection-mode row.subtitle:link radio, .selection-mode.titlebar:not(headerbar) row.subtitle:link radio { border-color: #0f4278; }

.osd check, .osd radio { color: #eeeeee; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 238, 0.3); }

.osd check:hover, .osd radio:hover { color: #eeeeee; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 238, 0.3); }

.osd check:active, .osd radio:active { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(0, 0, 0, 0.7); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; outline-color: rgba(238, 238, 238, 0.3); }

.osd check:backdrop, .osd radio:backdrop { color: #eeeeee; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

.osd check:disabled, .osd radio:disabled { color: #888888; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

menu menuitem check, menu menuitem radio { margin: 0; }

menu menuitem check, menu menuitem check:hover, menu menuitem check:disabled, menu menuitem radio, menu menuitem radio:hover, menu menuitem radio:disabled { min-height: 14px; min-width: 14px; background-image: none; background-color: transparent; box-shadow: none; -gtk-icon-shadow: none; color: inherit; border-color: currentColor; animation: none; }

check { border-radius: 3px; }

check:checked { -gtk-icon-source: image(-gtk-recolor(url("assets/check-symbolic.svg")), -gtk-recolor(url("assets/check-symbolic.symbolic.png"))); }

check:indeterminate { -gtk-icon-source: image(-gtk-recolor(url("assets/dash-symbolic.svg")), -gtk-recolor(url("assets/dash-symbolic.symbolic.png"))); }

treeview.view radio:selected:focus-within, treeview.view radio:selected, treeview.view headerbar.selection-mode radio.subtitle:link, headerbar.selection-mode treeview.view radio.subtitle:link, treeview.view .selection-mode.titlebar:not(headerbar) radio.subtitle:link, .selection-mode.titlebar:not(headerbar) treeview.view radio.subtitle:link, radio { border-radius: 100%; }

treeview.view radio:checked:selected, treeview.view headerbar.selection-mode radio.subtitle:checked:link, headerbar.selection-mode treeview.view radio.subtitle:checked:link, treeview.view .selection-mode.titlebar:not(headerbar) radio.subtitle:checked:link, .selection-mode.titlebar:not(headerbar) treeview.view radio.subtitle:checked:link, radio:checked { -gtk-icon-source: image(-gtk-recolor(url("assets/bullet-symbolic.svg")), -gtk-recolor(url("assets/bullet-symbolic.symbolic.png"))); }

treeview.view radio:indeterminate:selected, treeview.view headerbar.selection-mode radio.subtitle:indeterminate:link, headerbar.selection-mode treeview.view radio.subtitle:indeterminate:link, treeview.view .selection-mode.titlebar:not(headerbar) radio.subtitle:indeterminate:link, .selection-mode.titlebar:not(headerbar) treeview.view radio.subtitle:indeterminate:link, radio:indeterminate { -gtk-icon-source: image(-gtk-recolor(url("assets/dash-symbolic.svg")), -gtk-recolor(url("assets/dash-symbolic.symbolic.png"))); }

@keyframes check_check { from { -gtk-icon-transform: translate(6px, -3px) rotate(-45deg) scaleY(0.2) rotate(45deg) scaleX(0); }
  to { -gtk-icon-transform: unset; } }

@keyframes check_radio { from { -gtk-icon-transform: scale(0); }
  to { -gtk-icon-transform: unset; } }

@keyframes check_indeterminate { from { -gtk-icon-transform: scale(0, 1); }
  to { -gtk-icon-transform: unset; } }

check:not(:indeterminate):checked { animation: check_check 400ms; }

radio:not(:indeterminate):checked { animation: check_radio 400ms; }

check:indeterminate:checked, radio:indeterminate:checked { animation: check_indeterminate 400ms; }

menu menuitem check:not(:indeterminate):checked, menu menuitem radio:not(:indeterminate):checked, menu menuitem check:indeterminate:checked:active, menu menuitem radio:indeterminate:checked { animation: none; }

treeview.view check:selected:focus-within, treeview.view check:selected, treeview.view headerbar.selection-mode check.subtitle:link, headerbar.selection-mode treeview.view check.subtitle:link, treeview.view .selection-mode.titlebar:not(headerbar) check.subtitle:link, .selection-mode.titlebar:not(headerbar) treeview.view check.subtitle:link, treeview.view radio:selected:focus-within, treeview.view radio:selected, treeview.view headerbar.selection-mode radio.subtitle:link, headerbar.selection-mode treeview.view radio.subtitle:link, treeview.view .selection-mode.titlebar:not(headerbar) radio.subtitle:link, .selection-mode.titlebar:not(headerbar) treeview.view radio.subtitle:link { color: #3c3c3c; border-color: #0f4278; }

treeview.view check:selected:disabled, treeview.view radio:selected:disabled { color: #858585; }

treeview.view check:selected:disabled:backdrop, treeview.view radio:selected:disabled:backdrop { color: #a8a8a8; }

treeview.view check:backdrop:selected, treeview.view headerbar.selection-mode .subtitle:backdrop:link, headerbar.selection-mode treeview.view .subtitle:backdrop:link, treeview.view .selection-mode.titlebar:not(headerbar) .subtitle:backdrop:link, .selection-mode.titlebar:not(headerbar) treeview.view .subtitle:backdrop:link, treeview.view check:backdrop, treeview.view radio:backdrop:selected, treeview.view radio:backdrop { color: #858585; }

/************ GtkScale * */
progressbar trough, scale fill, scale trough { border: 1px solid #828282; border-radius: 3px; background-color: #b3b3b3; box-shadow: inset 1px 1px rgba(0, 0, 0, 0.1); }

progressbar trough:disabled, scale fill:disabled, scale trough:disabled { background-color: #e0e0e0; box-shadow: none; }

progressbar trough:backdrop, scale fill:backdrop, scale trough:backdrop { background-color: #b6b6b6; border-color: #898989; box-shadow: none; transition: 200ms ease-out; }

progressbar trough:backdrop:disabled, scale fill:backdrop:disabled, scale trough:backdrop:disabled, label:disabled selection:backdrop { background-color: #e0e0e0; }

row:selected progressbar trough, progressbar row:selected trough, row:selected scale fill, scale row:selected fill, row:selected scale trough, scale row:selected trough, headerbar.selection-mode row.subtitle:link progressbar trough, progressbar headerbar.selection-mode row.subtitle:link trough, headerbar.selection-mode row.subtitle:link scale fill, scale headerbar.selection-mode row.subtitle:link fill, headerbar.selection-mode row.subtitle:link scale trough, scale headerbar.selection-mode row.subtitle:link trough, .selection-mode.titlebar:not(headerbar) row.subtitle:link progressbar trough, progressbar .selection-mode.titlebar:not(headerbar) row.subtitle:link trough, .selection-mode.titlebar:not(headerbar) row.subtitle:link scale fill, scale .selection-mode.titlebar:not(headerbar) row.subtitle:link fill, .selection-mode.titlebar:not(headerbar) row.subtitle:link scale trough, scale .selection-mode.titlebar:not(headerbar) row.subtitle:link trough { box-shadow: none; }

row:selected progressbar trough, progressbar row:selected trough, row:selected scale fill, scale row:selected fill, row:selected scale trough, scale row:selected trough, headerbar.selection-mode row.subtitle:link progressbar trough, progressbar headerbar.selection-mode row.subtitle:link trough, headerbar.selection-mode row.subtitle:link scale fill, scale headerbar.selection-mode row.subtitle:link fill, headerbar.selection-mode row.subtitle:link scale trough, scale headerbar.selection-mode row.subtitle:link trough, .selection-mode.titlebar:not(headerbar) row.subtitle:link progressbar trough, progressbar .selection-mode.titlebar:not(headerbar) row.subtitle:link trough, .selection-mode.titlebar:not(headerbar) row.subtitle:link scale fill, scale .selection-mode.titlebar:not(headerbar) row.subtitle:link fill, .selection-mode.titlebar:not(headerbar) row.subtitle:link scale trough, scale .selection-mode.titlebar:not(headerbar) row.subtitle:link trough { border-color: #0f4278; }

.osd progressbar trough, progressbar .osd trough, .osd scale fill, scale .osd fill, .osd scale trough, scale .osd trough { border-color: rgba(0, 0, 0, 0.7); background-color: rgba(0, 0, 0, 0.5); box-shadow: none; outline-color: rgba(238, 238, 238, 0.2); }

.osd progressbar trough:disabled, progressbar .osd trough:disabled, .osd scale fill:disabled, scale .osd fill:disabled, .osd scale trough:disabled, scale .osd trough:disabled { background-color: rgba(34, 34, 34, 0.8); }

progressbar progress, scale highlight { border: 1px solid shade(#398ee7, 0.7); border-radius: 3px; background-image: linear-gradient(to bottom, shade(#398ee7, 1.1), shade(#398ee7, 0.9)); }

progressbar progress:disabled, scale highlight:disabled { background-color: transparent; border-color: transparent; }

progressbar progress:backdrop, scale highlight:backdrop { border-color: rgba(15, 66, 120, 0.7); background-color: rgba(57, 142, 231, 0.7); background-image: none; }

progressbar progress:backdrop:disabled, scale highlight:backdrop:disabled, label:disabled selection:backdrop { background-color: transparent; border-color: transparent; }

row:selected progressbar progress, progressbar row:selected progress, row:selected scale highlight, scale row:selected highlight, headerbar.selection-mode row.subtitle:link progressbar progress, progressbar headerbar.selection-mode row.subtitle:link progress, headerbar.selection-mode row.subtitle:link scale highlight, scale headerbar.selection-mode row.subtitle:link highlight, .selection-mode.titlebar:not(headerbar) row.subtitle:link progressbar progress, progressbar .selection-mode.titlebar:not(headerbar) row.subtitle:link progress, .selection-mode.titlebar:not(headerbar) row.subtitle:link scale highlight, scale .selection-mode.titlebar:not(headerbar) row.subtitle:link highlight { border-color: #0f4278; }

.osd progressbar progress, progressbar .osd progress, .osd scale highlight, scale .osd highlight { border-color: rgba(0, 0, 0, 0.7); }

.osd progressbar progress:disabled, progressbar .osd progress:disabled, .osd scale highlight:disabled, scale .osd highlight:disabled { border-color: transparent; }

scale { min-height: 10px; min-width: 10px; padding: 12px; }

scale fill, scale highlight { margin: -2px; }

scale slider { min-height: 13px; min-width: 13px; margin: -7px; }

scale.fine-tune.horizontal { padding-top: 9px; padding-bottom: 9px; min-height: 16px; }

scale.fine-tune.vertical { padding-left: 9px; padding-right: 9px; min-width: 16px; }

scale.fine-tune slider { margin: -6px; }

scale.fine-tune fill, scale.fine-tune highlight, scale.fine-tune trough { border-radius: 5px; -gtk-outline-radius: 7px; }

scale trough { padding: 1px; outline-offset: 2px; -gtk-outline-radius: 5px; }

scale fill, scale fill:backdrop { background-color: #828282; box-shadow: none; }

scale fill:disabled, scale fill:disabled:backdrop { border-color: transparent; background-color: transparent; }

.osd scale fill { background-color: rgba(91, 91, 91, 0.775); }

.osd scale fill:disabled, .osd scale fill:disabled:backdrop { border-color: transparent; background-color: transparent; }

scale slider { color: #3c3c3c; outline-color: rgba(60, 60, 60, 0.3); border-top-color: shade(#cecece, 0.8); border-right-color: shade(#cecece, 0.72); border-left-color: shade(#cecece, 0.72); border-bottom-color: shade(#cecece, 0.7); background-image: linear-gradient(to bottom, shade(shade(#cecece, 1.02), 1.05), shade(shade(#cecece, 1.02), 0.97)); box-shadow: inset 0 1px rgba(255, 255, 255, 0.6); background-image: linear-gradient(to bottom, shade(#cecece, 1.45), shade(#cecece, 1.15)); border: 1px solid #7a7a7a; border-radius: 100%; transition: all 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); transition-property: background, border, box-shadow; }

scale slider:hover { color: #3c3c3c; outline-color: rgba(60, 60, 60, 0.3); border-color: #828282; background-image: linear-gradient(to bottom, #e5e5e5 10%, #d8d8d8 90%); box-shadow: inset 0 1px rgba(255, 255, 255, 0.6), inset 0 -2px #dbdbdb, inset 0 -1px #b5b5b5, 0 1px rgba(0, 0, 0, 0.1); }

scale slider:active { border-color: #0f4278; }

scale slider:disabled { border-color: #828282; background-color: #e0e0e0; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

scale slider:disabled label, scale slider:disabled { color: #858585; }

scale slider:backdrop { transition: 200ms ease-out; border-color: #898989; background-color: #cecece; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

scale slider:backdrop label, scale slider:backdrop { color: #858585; }

scale slider:backdrop:disabled, scale label:disabled selection:backdrop, label:disabled scale selection:backdrop { border-color: #898989; background-color: #e0e0e0; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

scale slider:backdrop:disabled label, scale label:disabled selection:backdrop label, label:disabled scale selection:backdrop label, scale slider:backdrop:disabled, scale label:disabled selection:backdrop, label:disabled scale selection:backdrop { color: #a8a8a8; }

row:selected scale slider, headerbar.selection-mode row.subtitle:link scale slider, .selection-mode.titlebar:not(headerbar) row.subtitle:link scale slider, row:selected scale slider:disabled, headerbar.selection-mode row.subtitle:link scale slider:disabled { border-color: #0f4278; }

.osd scale slider { color: #eeeeee; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 238, 0.3); border-color: rgba(0, 0, 0, 0.7); background-color: #222222; }

.osd scale slider:hover { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(65, 65, 65, 0.8); background-clip: padding-box; box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); text-shadow: 0 1px black; -gtk-icon-shadow: 0 1px black; outline-color: rgba(238, 238, 238, 0.3); }

.osd scale slider:active { color: white; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(0, 0, 0, 0.7); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; outline-color: rgba(238, 238, 238, 0.3); }

.osd scale slider:disabled { color: #888888; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

.osd scale slider:backdrop { color: #eeeeee; border-color: rgba(0, 0, 0, 0.7); background-color: rgba(34, 34, 34, 0.8); background-clip: padding-box; box-shadow: none; text-shadow: none; -gtk-icon-shadow: none; }

scale value { color: alpha(currentColor,0.6); }

scale marks { color: alpha(currentColor,0.4); }

scale marks.top { margin-bottom: 6px; margin-top: -12px; }

scale marks.bottom { margin-top: 6px; margin-bottom: -12px; }

scale marks.top { margin-right: 6px; margin-left: -12px; }

scale marks.bottom { margin-left: 6px; margin-right: -12px; }

scale.fine-tune marks.top { margin-bottom: 6px; margin-top: -9px; }

scale.fine-tune marks.bottom { margin-top: 6px; margin-bottom: -9px; }

scale.fine-tune marks.top { margin-right: 6px; margin-left: -9px; }

scale.fine-tune marks.bottom { margin-left: 6px; margin-right: -9px; }

scale.horizontal indicator { min-height: 6px; min-width: 1px; }

scale.horizontal.fine-tune indicator { min-height: 3px; }

scale.vertical indicator { min-height: 1px; min-width: 6px; }

scale.vertical.fine-tune indicator { min-width: 3px; }

scale.color { min-height: 0; min-width: 0; }

scale.color trough { background-image: image(#828282); background-repeat: no-repeat; }

scale.color.horizontal { padding: 0 0 15px 0; }

scale.color.horizontal trough { padding-bottom: 4px; background-position: 0 -3px; border-top-left-radius: 0; border-top-right-radius: 0; }

scale.color.horizontal slider:dir(ltr):hover, scale.color.horizontal slider:dir(ltr):backdrop, scale.color.horizontal slider:dir(ltr):disabled, scale.color.horizontal label:disabled selection:dir(ltr), label:disabled scale.color.horizontal selection:dir(ltr), scale.color.horizontal slider:dir(ltr):backdrop:disabled, scale.color.horizontal label:disabled selection:backdrop, label:disabled scale.color.horizontal selection:backdrop, scale.color.horizontal slider:dir(ltr), scale.color.horizontal slider:dir(rtl):hover, scale.color.horizontal slider:dir(rtl):backdrop, scale.color.horizontal slider:dir(rtl):disabled, scale.color.horizontal label:disabled selection:dir(rtl), label:disabled scale.color.horizontal selection:dir(rtl), scale.color.horizontal slider:dir(rtl):backdrop:disabled, scale.color.horizontal slider:dir(rtl) { margin-bottom: -15px; margin-top: 6px; }

scale.color.vertical:dir(ltr) { padding: 0 0 0 15px; }

scale.color.vertical:dir(ltr) trough { padding-left: 4px; background-position: 3px 0; border-bottom-right-radius: 0; border-top-right-radius: 0; }

scale.color.vertical:dir(ltr) slider:hover, scale.color.vertical:dir(ltr) slider:backdrop, scale.color.vertical:dir(ltr) slider:disabled, scale.color.vertical:dir(ltr) slider:backdrop:disabled, scale.color.vertical:dir(ltr) label:disabled selection:backdrop, label:disabled scale.color.vertical:dir(ltr) selection:backdrop, scale.color.vertical:dir(ltr) slider { margin-left: -15px; margin-right: 6px; }

scale.color.vertical:dir(rtl) { padding: 0 15px 0 0; }

scale.color.vertical:dir(rtl) trough { padding-right: 4px; background-position: -3px 0; border-bottom-left-radius: 0; border-top-left-radius: 0; }

scale.color.vertical:dir(rtl) slider:hover, scale.color.vertical:dir(rtl) slider:backdrop, scale.color.vertical:dir(rtl) slider:disabled, scale.color.vertical:dir(rtl) slider:backdrop:disabled, scale.color.vertical:dir(rtl) label:disabled selection:backdrop, label:disabled scale.color.vertical:dir(rtl) selection:backdrop, scale.color.vertical:dir(rtl) slider { margin-right: -15px; margin-left: 6px; }

scale.color.fine-tune.horizontal:dir(ltr), scale.color.fine-tune.horizontal:dir(rtl) { padding: 0 0 12px 0; }

scale.color.fine-tune.horizontal:dir(ltr) trough, scale.color.fine-tune.horizontal:dir(rtl) trough { padding-bottom: 7px; background-position: 0 -6px; }

scale.color.fine-tune.horizontal:dir(ltr) slider, scale.color.fine-tune.horizontal:dir(rtl) slider { margin-bottom: -15px; margin-top: 6px; }

scale.color.fine-tune.vertical:dir(ltr) { padding: 0 0 0 12px; }

scale.color.fine-tune.vertical:dir(ltr) trough { padding-left: 7px; background-position: 6px 0; }

scale.color.fine-tune.vertical:dir(ltr) slider { margin-left: -15px; margin-right: 6px; }

scale.color.fine-tune.vertical:dir(rtl) { padding: 0 12px 0 0; }

scale.color.fine-tune.vertical:dir(rtl) trough { padding-right: 7px; background-position: -6px 0; }

scale.color.fine-tune.vertical:dir(rtl) slider { margin-right: -15px; margin-left: 6px; }

/***************** Progress bars * */
progressbar { font-size: smaller; color: rgba(60, 60, 60, 0.4); font-feature-settings: "tnum"; }

progressbar.horizontal trough { min-height: 6px; padding: 1px 0; }

progressbar.horizontal progress { min-height: 8px; }

progressbar.vertical trough { min-width: 6px; padding: 0 1px; }

progressbar.vertical progress { min-width: 8px; }

progressbar.horizontal progress, progressbar.vertical progress { margin: 0; }

progressbar:backdrop { box-shadow: none; transition: 200ms ease-out; }

progressbar progress { border: 1px solid shade(#398ee7, 0.7); border-radius: 3px; }

progressbar progress.left { border-top-left-radius: 3px; border-bottom-left-radius: 3px; }

progressbar progress.right { border-top-right-radius: 3px; border-bottom-right-radius: 3px; }

progressbar progress.top { border-top-right-radius: 3px; border-top-left-radius: 3px; }

progressbar progress.bottom { border-bottom-right-radius: 3px; border-bottom-left-radius: 3px; }

progressbar.osd { min-width: 3px; min-height: 3px; background-color: transparent; }

progressbar.osd trough { border-style: none; border-radius: 0; background-color: transparent; box-shadow: none; }

progressbar.osd progress { border-style: none; border-radius: 0; }

progressbar trough.empty progress { all: unset; }

/************* Level Bar * */
levelbar block { min-width: 32px; min-height: 1px; }

levelbar.vertical block { min-width: 1px; min-height: 32px; }

levelbar:backdrop { transition: 200ms ease-out; }

levelbar trough { border: 1px solid; padding: 2px; border-radius: 3px; color: #212121; border-color: #828282; background-color: #fcfcfc; box-shadow: inset 0 0 0 1px rgba(57, 142, 231, 0); }

levelbar trough:backdrop { color: #4c4c4c; border-color: #898989; background-color: #f9f9f9; box-shadow: none; }

levelbar.horizontal.discrete block { margin: 0 1px; }

levelbar.vertical.discrete block { margin: 1px 0; }

levelbar block { border: 1px solid; border-radius: 1px; box-shadow: 0 1px rgba(0, 0, 0, 0.2); }

levelbar block:backdrop { box-shadow: none; }

levelbar block.low { border-color: #8f4700; background-color: #f57900; }

levelbar block.low:backdrop { border-color: #f57900; }

levelbar block.high, levelbar block:not(.empty) { border-color: #145ba6; background-color: #398ee7; }

levelbar block.high:backdrop, levelbar block:not(.empty):backdrop { border-color: #398ee7; }

levelbar block.full { border-color: #1c3802; background-color: #4e9a06; }

levelbar block.full:backdrop { border-color: #4e9a06; }

levelbar block.empty { background-color: transparent; border-color: rgba(60, 60, 60, 0.2); box-shadow: none; }

levelbar block.empty:backdrop { border-color: rgba(133, 133, 133, 0.15); }

/**************** Print dialog * */
printdialog paper { color: #3c3c3c; border: 1px solid #828282; background: white; padding: 0; }

printdialog paper:backdrop { color: #858585; border-color: #898989; }

printdialog .dialog-vbox { background-color: #cecece; }

printdialog .dialog-vbox:backdrop { background-color: #cecece; }

printdialog .dialog-action-box { margin: 12px; }

/********** Frames * */
frame > border, .frame { box-shadow: none; margin: 0; padding: 0; border-radius: 0; border: 1px solid #828282; }

frame > border.flat, .frame.flat, button.frame.sidebar-button, popover.background checkbutton.frame, popover.background radiobutton.frame { border-style: none; }

frame > border:backdrop, .frame:backdrop { border-color: #898989; }

actionbar > revealer > box { padding: 6px; border-top: 1px solid #828282; }

actionbar > revealer > box:backdrop { border-color: #898989; }

scrolledwindow viewport.frame { border-style: none; }

scrolledwindow overshoot.top { background-image: -gtk-gradient(radial, center top, 0, center top, 0.5, to(#686868), to(rgba(104, 104, 104, 0))), -gtk-gradient(radial, center top, 0, center top, 0.6, from(rgba(60, 60, 60, 0.07)), to(rgba(60, 60, 60, 0))); background-size: 100% 5%, 100% 100%; background-repeat: no-repeat; background-position: center top; background-color: transparent; border: none; box-shadow: none; }

scrolledwindow overshoot.top:backdrop { background-image: -gtk-gradient(radial, center top, 0, center top, 0.5, to(#898989), to(rgba(137, 137, 137, 0))); background-size: 100% 5%; background-repeat: no-repeat; background-position: center top; background-color: transparent; border: none; box-shadow: none; }

scrolledwindow overshoot.bottom { background-image: -gtk-gradient(radial, center bottom, 0, center bottom, 0.5, to(#686868), to(rgba(104, 104, 104, 0))), -gtk-gradient(radial, center bottom, 0, center bottom, 0.6, from(rgba(60, 60, 60, 0.07)), to(rgba(60, 60, 60, 0))); background-size: 100% 5%, 100% 100%; background-repeat: no-repeat; background-position: center bottom; background-color: transparent; border: none; box-shadow: none; }

scrolledwindow overshoot.bottom:backdrop { background-image: -gtk-gradient(radial, center bottom, 0, center bottom, 0.5, to(#898989), to(rgba(137, 137, 137, 0))); background-size: 100% 5%; background-repeat: no-repeat; background-position: center bottom; background-color: transparent; border: none; box-shadow: none; }

scrolledwindow overshoot.left { background-image: -gtk-gradient(radial, left center, 0, left center, 0.5, to(#686868), to(rgba(104, 104, 104, 0))), -gtk-gradient(radial, left center, 0, left center, 0.6, from(rgba(60, 60, 60, 0.07)), to(rgba(60, 60, 60, 0))); background-size: 5% 100%, 100% 100%; background-repeat: no-repeat; background-position: left center; background-color: transparent; border: none; box-shadow: none; }

scrolledwindow overshoot.left:backdrop { background-image: -gtk-gradient(radial, left center, 0, left center, 0.5, to(#898989), to(rgba(137, 137, 137, 0))); background-size: 5% 100%; background-repeat: no-repeat; background-position: left center; background-color: transparent; border: none; box-shadow: none; }

scrolledwindow overshoot.right { background-image: -gtk-gradient(radial, right center, 0, right center, 0.5, to(#686868), to(rgba(104, 104, 104, 0))), -gtk-gradient(radial, right center, 0, right center, 0.6, from(rgba(60, 60, 60, 0.07)), to(rgba(60, 60, 60, 0))); background-size: 5% 100%, 100% 100%; background-repeat: no-repeat; background-position: right center; background-color: transparent; border: none; box-shadow: none; }

scrolledwindow overshoot.right:backdrop { background-image: -gtk-gradient(radial, right center, 0, right center, 0.5, to(#898989), to(rgba(137, 137, 137, 0))); background-size: 5% 100%; background-repeat: no-repeat; background-position: right center; background-color: transparent; border: none; box-shadow: none; }

scrolledwindow undershoot.top { background-color: transparent; background-image: linear-gradient(to left, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%); padding-top: 1px; background-size: 10px 1px; background-repeat: repeat-x; background-origin: content-box; background-position: center top; border: none; box-shadow: none; }

scrolledwindow undershoot.bottom { background-color: transparent; background-image: linear-gradient(to left, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%); padding-bottom: 1px; background-size: 10px 1px; background-repeat: repeat-x; background-origin: content-box; background-position: center bottom; border: none; box-shadow: none; }

scrolledwindow undershoot.left { background-color: transparent; background-image: linear-gradient(to top, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%); padding-left: 1px; background-size: 1px 10px; background-repeat: repeat-y; background-origin: content-box; background-position: left center; border: none; box-shadow: none; }

scrolledwindow undershoot.right { background-color: transparent; background-image: linear-gradient(to top, rgba(255, 255, 255, 0.2) 50%, rgba(0, 0, 0, 0.2) 50%); padding-right: 1px; background-size: 1px 10px; background-repeat: repeat-y; background-origin: content-box; background-position: right center; border: none; box-shadow: none; }

scrolledwindow junction { border-color: transparent; border-image: linear-gradient(to bottom, #828282 1px, transparent 1px) 0 0 0 1/0 1px stretch; background-color: #b1b1b1; }

scrolledwindow junction:dir(rtl) { border-image-slice: 0 1 0 0; }

scrolledwindow junction:backdrop { border-image-source: linear-gradient(to bottom, #898989 1px, transparent 1px); background-color: #c6c6c6; transition: 200ms ease-out; }

separator { background: rgba(0, 0, 0, 0.1); min-width: 1px; min-height: 1px; }

/********* Lists * */
list { color: #212121; background-color: #fcfcfc; border-color: #828282; }

list:backdrop { color: #4c4c4c; background-color: #f9f9f9; border-color: #898989; }

list row { padding: 2px; }

list row.expander { padding: 0px; }

list row.expander .row-header { padding: 2px; }

list.separators row:not(:first-child) { border-top: 1px solid #828282; }

row { transition: all 150ms cubic-bezier(0.25, 0.46, 0.45, 0.94); }

row:hover { transition: none; }

row:backdrop { transition: 200ms ease-out; }

row.activatable.has-open-popup, row.activatable:hover { background-color: rgba(60, 60, 60, 0.05); }

row.activatable:active { box-shadow: inset 0 2px 2px -2px rgba(0, 0, 0, 0.2); }

row.activatable:backdrop:hover { background-color: transparent; }

row.activatable:selected:active, headerbar.selection-mode .activatable.subtitle:active:link, .selection-mode.titlebar:not(headerbar) .activatable.subtitle:active:link { box-shadow: inset 0 2px 3px -1px rgba(0, 0, 0, 0.5); }

row.activatable:selected.has-open-popup, headerbar.selection-mode .activatable.has-open-popup.subtitle:link, .selection-mode.titlebar:not(headerbar) .activatable.has-open-popup.subtitle:link, row.activatable:selected:hover, headerbar.selection-mode .activatable.subtitle:hover:link, .selection-mode.titlebar:not(headerbar) .activatable.subtitle:hover:link { background-color: #3986d6; }

/********************* App Notifications * */
.app-notification, .app-notification.frame { padding: 10px; border-radius: 0 0 5px 5px; background-color: rgba(34, 34, 34, 0.8); background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.2), transparent 2px); background-clip: padding-box; }

.app-notification:backdrop, .app-notification.frame:backdrop { background-image: none; transition: 200ms ease-out; }

.app-notification border, .app-notification.frame border { border: none; }

/************* Expanders * */
expander title > arrow { min-width: 16px; min-height: 16px; -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); }

expander title > arrow:dir(rtl) { -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl"); }

expander title > arrow:hover { color: #898989; }

expander title > arrow:disabled { color: #858585; }

expander title > arrow:disabled:backdrop { color: #a8a8a8; }

expander title > arrow:checked { -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }

/************ Calendar * */
calendar { color: #212121; border: 1px solid #828282; }

calendar:selected, headerbar.selection-mode calendar.subtitle:link, .selection-mode.titlebar:not(headerbar) calendar.subtitle:link { border-radius: 3px; }

calendar.header { border-bottom-color: rgba(0, 0, 0, 0.1); }

calendar.header:backdrop { border-bottom-color: rgba(0, 0, 0, 0.1); }

calendar.button { color: rgba(60, 60, 60, 0.45); }

calendar.button:hover { color: #3c3c3c; }

calendar.button:backdrop { color: rgba(133, 133, 133, 0.45); }

calendar.button:disabled, label:disabled selection.button { color: rgba(133, 133, 133, 0.45); }

calendar.highlight { color: #858585; }

calendar.highlight:backdrop { color: #a8a8a8; }

calendar:backdrop { color: #4c4c4c; border-color: #898989; }

calendar:indeterminate { color: alpha(currentColor,0.1); }

/*********** Dialogs * */
window.dialog.message .titlebar { min-height: 20px; background-image: none; background-color: #cecece; border-style: none; border-top-left-radius: 7px; border-top-right-radius: 7px; }

window.dialog.message.csd.background { border-bottom-left-radius: 9px; border-bottom-right-radius: 9px; }

window.dialog.message.csd .dialog-action-area { padding: 0px; }

window.dialog.message.csd .dialog-action-area button { padding: 3px; border-radius: 0px; border-left-style: solid; border-right-style: none; border-bottom-style: none; }

window.dialog.message.csd .dialog-action-area button:first-child, window.dialog.message.csd .dialog-action-area dropdown.linked button:nth-child(2):dir(rtl), dropdown.linked window.dialog.message.csd .dialog-action-area button:nth-child(2):dir(rtl), window.dialog.message.csd .dialog-action-area combobox.linked button:nth-child(2):dir(rtl), combobox.linked window.dialog.message.csd .dialog-action-area button:nth-child(2):dir(rtl), window.dialog.message.csd .dialog-action-area .linked:not(.vertical) > combobox:first-child > box > button.combo, window.dialog.message.csd .dialog-action-area .linked.vertical > combobox:first-child > box > button.combo { border-left-style: none; border-bottom-left-radius: 7px; -gtk-outline-bottom-left-radius: 5px; }

window.dialog.message.csd .dialog-action-area button:last-child, window.dialog.message.csd .dialog-action-area dropdown.linked button:nth-child(2):dir(ltr), dropdown.linked window.dialog.message.csd .dialog-action-area button:nth-child(2):dir(ltr), window.dialog.message.csd .dialog-action-area combobox.linked button:nth-child(2):dir(ltr), combobox.linked window.dialog.message.csd .dialog-action-area button:nth-child(2):dir(ltr), window.dialog.message.csd .dialog-action-area .linked:not(.vertical) > combobox:last-child > box > button.combo, window.dialog.message.csd .dialog-action-area .linked.vertical > combobox:last-child > box > button.combo { border-bottom-right-radius: 7px; -gtk-outline-bottom-right-radius: 5px; }

filechooser .dialog-action-box { border-top: 1px solid #828282; }

filechooser .dialog-action-box:backdrop { border-top-color: #898989; }

filechooser #pathbarbox { border-bottom: 1px solid #cecece; }

filechooser #pathbarbox stack { background-color: #cecece; }

filechooserbutton:drop(active) { box-shadow: none; border-color: transparent; }

/*********** Sidebar * */
.sidebar { border-style: none; background-color: #dae0e6; }

.sidebar row, .sidebar treeview, .sidebar listview { border-top: 1px solid transparent; border-bottom: 1px solid transparent; background-color: #dae0e6; }

.sidebar row:selected, .sidebar headerbar.selection-mode row.subtitle:link, headerbar.selection-mode .sidebar row.subtitle:link, .sidebar .selection-mode.titlebar:not(headerbar) row.subtitle:link, .selection-mode.titlebar:not(headerbar) .sidebar row.subtitle:link, .sidebar row:selected:focus-within, .sidebar treeview:selected, .sidebar headerbar.selection-mode treeview.subtitle:link, headerbar.selection-mode .sidebar treeview.subtitle:link, .sidebar .selection-mode.titlebar:not(headerbar) treeview.subtitle:link, .selection-mode.titlebar:not(headerbar) .sidebar treeview.subtitle:link, .sidebar treeview:selected:focus-within, .sidebar listview:selected, .sidebar headerbar.selection-mode listview.subtitle:link, headerbar.selection-mode .sidebar listview.subtitle:link, .sidebar .selection-mode.titlebar:not(headerbar) listview.subtitle:link, .selection-mode.titlebar:not(headerbar) .sidebar listview.subtitle:link, .sidebar listview:selected:focus-within { background-image: linear-gradient(to bottom, shade(#dae0e6, 0.87), shade(#dae0e6, 0.95) 10%, shade(#dae0e6, 0.99) 92%, shade(#dae0e6, 0.92)); border-top: 1px solid shade(#cecece, 0.85); border-bottom: 1px solid shade(#cecece, 1.12); }

.sidebar row:selected label, .sidebar headerbar.selection-mode row.subtitle:link label, headerbar.selection-mode .sidebar row.subtitle:link label, .sidebar .selection-mode.titlebar:not(headerbar) row.subtitle:link label, .selection-mode.titlebar:not(headerbar) .sidebar row.subtitle:link label, .sidebar row:selected:focus-within label, .sidebar treeview:selected label, .sidebar headerbar.selection-mode treeview.subtitle:link label, headerbar.selection-mode .sidebar treeview.subtitle:link label, .sidebar .selection-mode.titlebar:not(headerbar) treeview.subtitle:link label, .selection-mode.titlebar:not(headerbar) .sidebar treeview.subtitle:link label, .sidebar treeview:selected:focus-within label, .sidebar listview:selected label, .sidebar headerbar.selection-mode listview.subtitle:link label, headerbar.selection-mode .sidebar listview.subtitle:link label, .sidebar .selection-mode.titlebar:not(headerbar) listview.subtitle:link label, .selection-mode.titlebar:not(headerbar) .sidebar listview.subtitle:link label, .sidebar listview:selected:focus-within label { color: #3c3c3c; }

.sidebar row:selected label:backdrop, .sidebar headerbar.selection-mode row.subtitle:link label:backdrop, headerbar.selection-mode .sidebar row.subtitle:link label:backdrop, .sidebar .selection-mode.titlebar:not(headerbar) row.subtitle:link label:backdrop, .selection-mode.titlebar:not(headerbar) .sidebar row.subtitle:link label:backdrop, .sidebar row:selected:focus-within label:backdrop, .sidebar treeview:selected label:backdrop, .sidebar headerbar.selection-mode treeview.subtitle:link label:backdrop, headerbar.selection-mode .sidebar treeview.subtitle:link label:backdrop, .sidebar .selection-mode.titlebar:not(headerbar) treeview.subtitle:link label:backdrop, .selection-mode.titlebar:not(headerbar) .sidebar treeview.subtitle:link label:backdrop, .sidebar treeview:selected:focus-within label:backdrop, .sidebar listview:selected label:backdrop, .sidebar headerbar.selection-mode listview.subtitle:link label:backdrop, headerbar.selection-mode .sidebar listview.subtitle:link label:backdrop, .sidebar .selection-mode.titlebar:not(headerbar) listview.subtitle:link label:backdrop, .selection-mode.titlebar:not(headerbar) .sidebar listview.subtitle:link label:backdrop, .sidebar listview:selected:focus-within label:backdrop { color: #858585; }

.sidebar row:selected:backdrop, .sidebar headerbar.selection-mode row.subtitle:backdrop:link, headerbar.selection-mode .sidebar row.subtitle:backdrop:link, .sidebar .selection-mode.titlebar:not(headerbar) row.subtitle:backdrop:link, .selection-mode.titlebar:not(headerbar) .sidebar row.subtitle:backdrop:link, .sidebar row:selected:focus-within:backdrop, .sidebar treeview:selected:backdrop, .sidebar headerbar.selection-mode treeview.subtitle:backdrop:link, headerbar.selection-mode .sidebar treeview.subtitle:backdrop:link, .sidebar .selection-mode.titlebar:not(headerbar) treeview.subtitle:backdrop:link, .selection-mode.titlebar:not(headerbar) .sidebar treeview.subtitle:backdrop:link, .sidebar treeview:selected:focus-within:backdrop, .sidebar listview:selected:backdrop, .sidebar headerbar.selection-mode listview.subtitle:backdrop:link, headerbar.selection-mode .sidebar listview.subtitle:backdrop:link, .sidebar .selection-mode.titlebar:not(headerbar) listview.subtitle:backdrop:link, .selection-mode.titlebar:not(headerbar) .sidebar listview.subtitle:backdrop:link, .sidebar listview:selected:focus-within:backdrop { background-image: none; background-color: #cecece; color: #3c3c3c; border-top: 1px solid shade(#cecece, 0.9); border-bottom: 1px solid shade(#cecece, 0.9); }

.sidebar row .view:selected, .sidebar row iconview:selected, .sidebar row headerbar.selection-mode .view.subtitle:link, headerbar.selection-mode .sidebar row .view.subtitle:link, .sidebar row headerbar.selection-mode iconview.subtitle:link, headerbar.selection-mode .sidebar row iconview.subtitle:link, .sidebar row .selection-mode.titlebar:not(headerbar) .view.subtitle:link, .selection-mode.titlebar:not(headerbar) .sidebar row .view.subtitle:link, .sidebar row .selection-mode.titlebar:not(headerbar) iconview.subtitle:link, .selection-mode.titlebar:not(headerbar) .sidebar row iconview.subtitle:link, .sidebar row .view:selected:focus-within, .sidebar treeview .view:selected, .sidebar treeview iconview:selected, .sidebar treeview headerbar.selection-mode .view.subtitle:link, headerbar.selection-mode .sidebar treeview .view.subtitle:link, .sidebar treeview headerbar.selection-mode iconview.subtitle:link, headerbar.selection-mode .sidebar treeview iconview.subtitle:link, .sidebar treeview .selection-mode.titlebar:not(headerbar) .view.subtitle:link, .selection-mode.titlebar:not(headerbar) .sidebar treeview .view.subtitle:link, .sidebar treeview .selection-mode.titlebar:not(headerbar) iconview.subtitle:link, .selection-mode.titlebar:not(headerbar) .sidebar treeview iconview.subtitle:link, .sidebar treeview .view:selected:focus-within, .sidebar listview .view:selected, .sidebar listview iconview:selected, .sidebar listview headerbar.selection-mode .view.subtitle:link, headerbar.selection-mode .sidebar listview .view.subtitle:link, .sidebar listview headerbar.selection-mode iconview.subtitle:link, headerbar.selection-mode .sidebar listview iconview.subtitle:link, .sidebar listview .selection-mode.titlebar:not(headerbar) .view.subtitle:link, .selection-mode.titlebar:not(headerbar) .sidebar listview .view.subtitle:link, .sidebar listview .selection-mode.titlebar:not(headerbar) iconview.subtitle:link, .selection-mode.titlebar:not(headerbar) .sidebar listview iconview.subtitle:link, .sidebar listview .view:selected:focus-within { color: #3c3c3c; }

.sidebar row:backdrop, .sidebar treeview:backdrop, .sidebar listview:backdrop { background-color: transparent; }

stacksidebar.sidebar:dir(ltr) list, stacksidebar.sidebar.left list, stacksidebar.sidebar.left:dir(rtl) list, .sidebar:dir(ltr), .sidebar.left { border-right: 1px solid #828282; border-left-style: none; border-top-style: none; border-bottom-style: none; }

stacksidebar.sidebar:dir(rtl) list .sidebar:dir(rtl), stacksidebar.sidebar.right list .sidebar:dir(rtl), .sidebar.right { border-left: 1px solid #828282; border-right-style: none; border-top-style: none; border-bottom-style: none; }

.sidebar:backdrop { background-color: #e4e4e4; border-color: #898989; transition: 200ms ease-out; }

.sidebar list, .sidebar treeview { background-color: transparent; }

.sidebar list:backdrop, .sidebar treeview:backdrop { background-color: transparent; }

paned .sidebar.left, paned .sidebar.right, paned .sidebar.left:dir(rtl), paned .sidebar:dir(rtl), paned .sidebar:dir(ltr), paned .sidebar { border-style: none; }

stacksidebar row { padding: 10px 4px; }

stacksidebar row > label { padding-left: 6px; padding-right: 6px; }

stacksidebar row.needs-attention > label { background-size: 6px 6px, 0 0; }

/**************** File chooser * */
placessidebar > viewport.frame { border-style: none; }

placessidebar row { min-height: 24px; padding: 0px; }

placessidebar row > revealer { padding: 0 14px; }

placessidebar row:selected, placessidebar headerbar.selection-mode row.subtitle:link, headerbar.selection-mode placessidebar row.subtitle:link, placessidebar .selection-mode.titlebar:not(headerbar) row.subtitle:link, .selection-mode.titlebar:not(headerbar) placessidebar row.subtitle:link { color: #3c3c3c; }

placessidebar row:disabled { color: #858585; }

placessidebar row:backdrop { color: #858585; background-color: #cecece; }

placessidebar row:backdrop:selected, placessidebar headerbar.selection-mode .subtitle:backdrop:link, headerbar.selection-mode placessidebar .subtitle:backdrop:link, placessidebar .selection-mode.titlebar:not(headerbar) .subtitle:backdrop:link, .selection-mode.titlebar:not(headerbar) placessidebar .subtitle:backdrop:link { color: #858585; }

placessidebar row:backdrop:disabled, placessidebar label:disabled selection:backdrop, label:disabled placessidebar selection:backdrop { color: #a8a8a8; }

placessidebar row image.sidebar-icon:dir(ltr) { padding-right: 8px; }

placessidebar row image.sidebar-icon:dir(rtl) { padding-left: 8px; }

placessidebar row label.sidebar-label:dir(ltr) { padding-right: 2px; }

placessidebar row label.sidebar-label:dir(rtl) { padding-left: 2px; }

button.sidebar-button { min-height: 26px; min-width: 26px; margin-top: 3px; margin-bottom: 3px; padding: 0; border-radius: 100%; -gtk-outline-radius: 100%; }

button.sidebar-button:not(:hover):not(:active) > image, button.sidebar-button:backdrop > image { opacity: 0.7; }

placessidebar row:selected:active, placessidebar headerbar.selection-mode row.subtitle:active:link, headerbar.selection-mode placessidebar row.subtitle:active:link, placessidebar .selection-mode.titlebar:not(headerbar) row.subtitle:active:link, .selection-mode.titlebar:not(headerbar) placessidebar row.subtitle:active:link { box-shadow: none; }

placessidebar row.sidebar-placeholder-row { padding: 0 8px; min-height: 2px; background-image: image(#4e9a06); background-clip: content-box; }

placessidebar row.sidebar-new-bookmark-row { color: #398ee7; }

placessidebar row:drop(active):not(:disabled) { color: #4e9a06; box-shadow: inset 0 1px #4e9a06, inset 0 -1px #4e9a06; }

placessidebar row:drop(active):not(:disabled):selected { color: #ffffff; background-image: linear-gradient(to bottom, #9dc8f2, #c1dcf7 10%, #d3e6f9 92%, #b4d5f5); }

placesview .server-list-button > image { transition: 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); -gtk-icon-transform: rotate(0turn); }

placesview .server-list-button:checked > image { transition: 200ms cubic-bezier(0.25, 0.46, 0.45, 0.94); -gtk-icon-transform: rotate(-0.5turn); }

placesview row.activatable:hover { background-color: transparent; }

placesview > actionbar > revealer > box > label { padding-left: 8px; padding-right: 8px; }

/********* Paned * */
paned > separator { min-width: 1px; min-height: 1px; -gtk-icon-source: none; border-style: none; background-color: transparent; background-image: image(#828282); background-size: 1px 1px; }

paned > separator:selected, headerbar.selection-mode paned > separator.subtitle:link, .selection-mode.titlebar:not(headerbar) paned > separator.subtitle:link { background-image: image(#398ee7); }

paned > separator:backdrop { background-image: image(#898989); }

paned > separator.wide { min-width: 5px; min-height: 5px; background-color: #cecece; background-image: image(#828282), image(#828282); background-size: 1px 1px, 1px 1px; }

paned > separator.wide:backdrop { background-color: #cecece; background-image: image(#898989), image(#898989); }

paned.horizontal > separator { background-repeat: repeat-y; }

paned.horizontal > separator:dir(ltr) { margin: 0 -8px 0 0; padding: 0 8px 0 0; background-position: left; }

paned.horizontal > separator:dir(rtl) { margin: 0 0 0 -8px; padding: 0 0 0 8px; background-position: right; }

paned.horizontal > separator.wide { margin: 0; padding: 0; background-repeat: repeat-y, repeat-y; background-position: left, right; }

paned.vertical > separator { margin: 0 0 -8px 0; padding: 0 0 8px 0; background-repeat: repeat-x; background-position: top; }

paned.vertical > separator.wide { margin: 0; padding: 0; background-repeat: repeat-x, repeat-x; background-position: bottom, top; }

/************** GtkInfoBar * */
infobar { border-style: none; }

.info, .question, .warning, .error { text-shadow: 0 1px #1a74d3; }

.info:backdrop, .info, .question:backdrop, .question, .warning:backdrop, .warning, .error:backdrop, .error { background-color: #398ee7; border-color: #1a74d3; }

.info:backdrop label, .info:backdrop, .info label, .info, .question:backdrop label, .question:backdrop, .question label, .question, .warning:backdrop label, .warning:backdrop, .warning label, .warning, .error:backdrop label, .error:backdrop, .error label, .error { color: #ffffff; }

.info:backdrop, .question:backdrop, .warning:backdrop, .error:backdrop { text-shadow: none; }

.info button, .question button, .warning button, .error button { color: #ffffff; outline-color: rgba(255, 255, 255, 0.3); border-top-color: shade(#cecece, 0.8); border-right-color: shade(#cecece, 0.72); border-left-color: shade(#cecece, 0.72); border-bottom-color: shade(#cecece, 0.7); background-image: linear-gradient(to bottom, shade(shade(#398ee7, 1.02), 1.05), shade(shade(#398ee7, 1.02), 0.97)); box-shadow: inset 0 1px rgba(255, 255, 255, 0.4); border-color: #145ba6; }

.info button:hover, .question button:hover, .warning button:hover, .error button:hover { color: #ffffff; outline-color: rgba(255, 255, 255, 0.3); border-color: #114f8f; background-image: linear-gradient(to bottom, shade(#398ee7, 1.15), shade(#398ee7, 1.07)); box-shadow: inset 0 1px rgba(255, 255, 255, 0.4); }

.info button:active, .info button:checked, .question button:active, .question button:checked, .warning button:active, .warning button:checked, .error button:active, .error button:checked { color: #ffffff; outline-color: rgba(255, 255, 255, 0.3); border-color: #114f8f; background-image: linear-gradient(to bottom, shade(shade(#398ee7, 0.85), 1.05), shade(shade(#398ee7, 0.85), 0.97)); box-shadow: inset 0 2px 1px -2px rgba(0, 0, 0, 0.6); }

.info button:disabled, .question button:disabled, .warning button:disabled, .error button:disabled { border-color: #114f8f; background-color: #569fea; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

.info button:disabled label, .info button:disabled, .question button:disabled label, .question button:disabled, .warning button:disabled label, .warning button:disabled, .error button:disabled label, .error button:disabled { color: #abcff5; }

.info button:backdrop, .question button:backdrop, .warning button:backdrop, .error button:backdrop { border-color: #398ee7; background-color: #398ee7; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); border-color: #114f8f; }

.info button:backdrop label, .info button:backdrop, .question button:backdrop label, .question button:backdrop, .warning button:backdrop label, .warning button:backdrop, .error button:backdrop label, .error button:backdrop { color: #d7e8fa; }

.info button:backdrop:disabled, .info label:disabled selection:backdrop, label:disabled .info selection:backdrop, .question button:backdrop:disabled, .question label:disabled selection:backdrop, label:disabled .question selection:backdrop, .warning button:backdrop:disabled, .warning label:disabled selection:backdrop, label:disabled .warning selection:backdrop, .error button:backdrop:disabled, .error label:disabled selection:backdrop, label:disabled .error selection:backdrop { border-color: #569fea; background-color: #569fea; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); border-color: #114f8f; }

.info button:backdrop:disabled label, .info label:disabled selection:backdrop label, label:disabled .info selection:backdrop label, .info button:backdrop:disabled, .info label:disabled selection:backdrop, label:disabled .info selection:backdrop, .question button:backdrop:disabled label, .question label:disabled selection:backdrop label, label:disabled .question selection:backdrop label, .question button:backdrop:disabled, .question label:disabled selection:backdrop, label:disabled .question selection:backdrop, .warning button:backdrop:disabled label, .warning label:disabled selection:backdrop label, label:disabled .warning selection:backdrop label, .warning button:backdrop:disabled, .warning label:disabled selection:backdrop, label:disabled .warning selection:backdrop, .error button:backdrop:disabled label, .error label:disabled selection:backdrop label, label:disabled .error selection:backdrop label, .error button:backdrop:disabled, .error label:disabled selection:backdrop, label:disabled .error selection:backdrop { color: #91c1f1; }

.info label:selected:focus-within, .info label:selected:hover, .info label:selected, .info headerbar.selection-mode label.subtitle:link, headerbar.selection-mode .info label.subtitle:link, .info .selection-mode.titlebar:not(headerbar) label.subtitle:link, .selection-mode.titlebar:not(headerbar) .info label.subtitle:link, .question label:selected:focus-within, .question label:selected:hover, .question label:selected, .question headerbar.selection-mode label.subtitle:link, headerbar.selection-mode .question label.subtitle:link, .question .selection-mode.titlebar:not(headerbar) label.subtitle:link, .selection-mode.titlebar:not(headerbar) .question label.subtitle:link, .warning label:selected:focus-within, .warning label:selected:hover, .warning label:selected, .warning headerbar.selection-mode label.subtitle:link, headerbar.selection-mode .warning label.subtitle:link, .warning .selection-mode.titlebar:not(headerbar) label.subtitle:link, .selection-mode.titlebar:not(headerbar) .warning label.subtitle:link, .error label:selected:focus-within, .error label:selected:hover, .error label:selected, .error headerbar.selection-mode label.subtitle:link, headerbar.selection-mode .error label.subtitle:link, .error .selection-mode.titlebar:not(headerbar) label.subtitle:link, .selection-mode.titlebar:not(headerbar) .error label.subtitle:link { background-color: #1a74d3; }

/************* Buttonbox * */
buttonbox { padding: 6px; }

/************ Tooltips * */
tooltip { padding: 1px; /* not working */ border-radius: 5px; box-shadow: none; text-shadow: 0 1px black; }

tooltip.background { background-color: rgba(0, 0, 0, 0.8); background-clip: padding-box; border: 1px solid rgba(255, 255, 255, 0.1); }

tooltip decoration { background-color: transparent; }

tooltip *, tooltip headerbar.selection-mode .subtitle:link, headerbar.selection-mode tooltip .subtitle:link, tooltip .selection-mode.titlebar:not(headerbar) .subtitle:link, .selection-mode.titlebar:not(headerbar) tooltip .subtitle:link { padding: 1px; background-color: transparent; color: white; }

/***************** Color Chooser * */
colorswatch, colorswatch:drop(active) { border-style: none; }

colorswatch.top { border-top-left-radius: 5.5px; border-top-right-radius: 5.5px; }

colorswatch.top overlay { border-top-left-radius: 5px; border-top-right-radius: 5px; }

colorswatch.bottom { border-bottom-left-radius: 5.5px; border-bottom-right-radius: 5.5px; }

colorswatch.bottom overlay { border-bottom-left-radius: 5px; border-bottom-right-radius: 5px; }

colorswatch.left, colorswatch:first-child:not(.top) { border-top-left-radius: 5.5px; border-bottom-left-radius: 5.5px; }

colorswatch.left overlay, colorswatch:first-child:not(.top) overlay { border-top-left-radius: 5px; border-bottom-left-radius: 5px; }

colorswatch.right, colorswatch:last-child:not(.bottom) { border-top-right-radius: 5.5px; border-bottom-right-radius: 5.5px; }

colorswatch.right overlay, colorswatch:last-child:not(.bottom) overlay { border-top-right-radius: 5px; border-bottom-right-radius: 5px; }

colorswatch.dark overlay { color: #ffffff; }

colorswatch.dark overlay:hover { border-color: rgba(0, 0, 0, 0.8); }

colorswatch.dark overlay:backdrop { color: #7d7d7d; }

colorswatch.light overlay { color: #212121; }

colorswatch.light overlay:hover { border-color: rgba(0, 0, 0, 0.5); }

colorswatch.light overlay:backdrop { color: #4c4c4c; }

colorswatch:drop(active) { box-shadow: none; }

colorswatch:drop(active).light overlay { border-color: #4e9a06; box-shadow: inset 0 0 0 2px #3d7805, inset 0 0 0 1px #4e9a06; }

colorswatch:drop(active).dark overlay { border-color: #4e9a06; box-shadow: inset 0 0 0 2px rgba(0, 0, 0, 0.3), inset 0 0 0 1px #4e9a06; }

colorswatch overlay { box-shadow: inset 0 2px 2px -3px rgba(0, 0, 0, 0.7); border: 1px solid rgba(0, 0, 0, 0.3); }

colorswatch overlay:hover { box-shadow: inset 0 1px rgba(255, 255, 255, 0.3); }

colorswatch overlay:backdrop, colorswatch overlay:backdrop:hover { border-color: rgba(0, 0, 0, 0.3); box-shadow: none; }

colorswatch#add-color-button { border-radius: 5px 5px 0 0; }

colorswatch#add-color-button:only-child, .linked:not(.vertical) > combobox:only-child > box > button#add-color-button.combo, .linked.vertical > combobox:only-child > box > button#add-color-button.combo { border-radius: 5px; }

colorswatch#add-color-button overlay { color: #3c3c3c; outline-color: rgba(60, 60, 60, 0.3); border-top-color: shade(#cecece, 0.8); border-right-color: shade(#cecece, 0.72); border-left-color: shade(#cecece, 0.72); border-bottom-color: shade(#cecece, 0.7); background-image: linear-gradient(to bottom, shade(shade(#cecece, 1.02), 1.05), shade(shade(#cecece, 1.02), 0.97)); box-shadow: inset 0 1px rgba(255, 255, 255, 0.6); }

colorswatch#add-color-button overlay:hover { color: #3c3c3c; outline-color: rgba(60, 60, 60, 0.3); border-color: #828282; background-image: linear-gradient(to bottom, shade(#cecece, 1.15), shade(#cecece, 1.07)); box-shadow: inset 0 1px rgba(255, 255, 255, 0.6); }

colorswatch#add-color-button overlay:backdrop { border-color: #898989; background-color: #cecece; text-shadow: none; -gtk-icon-shadow: none; box-shadow: inset 0 1px rgba(255, 255, 255, 0); }

colorswatch#add-color-button overlay:backdrop label, colorswatch#add-color-button overlay:backdrop { color: #858585; }

colorswatch:disabled { opacity: 0.5; }

colorswatch:disabled overlay { border-color: rgba(0, 0, 0, 0.6); box-shadow: none; }

row:selected colorswatch, headerbar.selection-mode row.subtitle:link colorswatch, .selection-mode.titlebar:not(headerbar) row.subtitle:link colorswatch { box-shadow: 0 0 0 2px #ffffff; }

colorswatch#editor-color-sample { border-radius: 4px; }

colorswatch#editor-color-sample overlay { border-radius: 4.5px; }

colorchooser .popover.osd { border-radius: 5px; }

/******** Misc * */
.content-view { background-color: #bcbcbc; }

.content-view:hover { -gtk-icon-effect: highlight; }

.content-view:backdrop { background-color: #bcbcbc; }

.osd .scale-popup button.flat { border-style: none; border-radius: 5px; }

.scale-popup button:hover { background-color: rgba(60, 60, 60, 0.1); border-radius: 5px; }

/********************** Window Decorations * */
window { border-width: 0px; }

window.csd { box-shadow: 0 3px 9px 1px rgba(0, 0, 0, 0.5), 0 0 0 1px rgba(0, 0, 0, 0.23); margin: 0px; border-radius: 7px 7px 0 0; }

window.csd:backdrop { box-shadow: 0 3px 9px 1px transparent, 0 2px 6px 2px rgba(0, 0, 0, 0.2), 0 0 0 1px rgba(0, 0, 0, 0.18); transition: 200ms ease-out; }

window.csd.popup { border-radius: 5px; box-shadow: 0 1px 2px rgba(0, 0, 0, 0.2), 0 0 0 1px rgba(0, 0, 0, 0.13); }

window.csd.dialog.message { border-radius: 7px; box-shadow: 0 1px 2px rgba(0, 0, 0, 0.2), 0 0 0 1px rgba(0, 0, 0, 0.13); }

window.solid-csd { margin: 0; padding: 4px; border: solid 1px #828282; border-radius: 0; box-shadow: inset 0 0 0 3px #cecece, inset 0 1px rgba(255, 255, 255, 0.8); }

window.solid-csd:backdrop { box-shadow: inset 0 0 0 3px #cecece, inset 0 1px rgba(255, 255, 255, 0.8); }

window.maximized, window.fullscreen { border-radius: 0; box-shadow: none; }

window.tiled, window.tiled-top, window.tiled-left, window.tiled-right, window.tiled-bottom { border-radius: 0; box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.23), 0 0 0 20px transparent; }

window.tiled:backdrop, window.tiled-top:backdrop, window.tiled-left:backdrop, window.tiled-right:backdrop, window.tiled-bottom:backdrop { box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.18), 0 0 0 20px transparent; }

window.popup { box-shadow: none; }

window.ssd { box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.23); }

tooltip.csd { border-radius: 5px; box-shadow: none; }

selection, .view:selected, .view text:selected, textview text:selected, iconview:selected, flowbox flowboxchild:selected, label:disabled selection, modelbutton.flat:selected, .menuitem.button.flat:selected, headerbar.selection-mode .view.subtitle:link, flowbox headerbar.selection-mode flowboxchild.subtitle:link, headerbar.selection-mode flowbox flowboxchild.subtitle:link, headerbar.selection-mode .flat.subtitle:link, popover.background checkbutton.flat:selected, popover.background radiobutton.flat:selected, popover.background checkbutton.button:selected, popover.background radiobutton.button:selected, row.activatable:selected, headerbar.selection-mode .activatable.subtitle:link, .selection-mode.titlebar:not(headerbar) .activatable.subtitle:link, row:selected, headerbar.selection-mode row.subtitle:link, .selection-mode.titlebar:not(headerbar) row.subtitle:link, calendar:selected, headerbar.selection-mode calendar.subtitle:link, .selection-mode.titlebar:not(headerbar) calendar.subtitle:link, button.button.sidebar-button:selected { outline-style: none; }

textview text:focus-within:selected, iconview:focus-within:selected, flowbox headerbar.selection-mode flowboxchild.subtitle:focus-within:link, headerbar.selection-mode flowbox flowboxchild.subtitle:focus-within:link, row:focus-within:selected, headerbar.selection-mode row.subtitle:focus-within:link, headerbar.selection-mode calendar.subtitle:focus-within:link, selection, .view:selected, .view text:selected, textview text:selected, iconview:selected, flowbox flowboxchild:selected, label:disabled selection, modelbutton.flat:selected, .menuitem.button.flat:selected, headerbar.selection-mode .view.subtitle:link, flowbox headerbar.selection-mode flowboxchild.subtitle:link, headerbar.selection-mode flowbox flowboxchild.subtitle:link, headerbar.selection-mode .flat.subtitle:link, popover.background checkbutton.flat:selected, popover.background radiobutton.flat:selected, popover.background checkbutton.button:selected, popover.background radiobutton.button:selected, row.activatable:selected, headerbar.selection-mode .activatable.subtitle:link, .selection-mode.titlebar:not(headerbar) .activatable.subtitle:link, row:selected, headerbar.selection-mode row.subtitle:link, .selection-mode.titlebar:not(headerbar) row.subtitle:link, calendar:selected, headerbar.selection-mode calendar.subtitle:link, .selection-mode.titlebar:not(headerbar) calendar.subtitle:link, button.button.sidebar-button:selected { color: #ffffff; background-color: #398ee7; }

selection:backdrop, .view:backdrop:selected, .view text:backdrop:selected, textview text:backdrop:selected, iconview:backdrop:selected, flowbox flowboxchild:backdrop:selected, label:disabled selection:backdrop, modelbutton.flat:backdrop:selected, .menuitem.button.flat:backdrop:selected, headerbar.selection-mode .view.subtitle:backdrop:link, flowbox headerbar.selection-mode flowboxchild.subtitle:backdrop:link, headerbar.selection-mode flowbox flowboxchild.subtitle:backdrop:link, headerbar.selection-mode .flat.subtitle:backdrop:link, popover.background checkbutton.flat:backdrop:selected, popover.background radiobutton.flat:backdrop:selected, popover.background checkbutton.button:backdrop:selected, popover.background radiobutton.button:backdrop:selected, headerbar.selection-mode .activatable.subtitle:backdrop:link, .selection-mode.titlebar:not(headerbar) .activatable.subtitle:backdrop:link, row:backdrop:selected, headerbar.selection-mode row.subtitle:backdrop:link, .selection-mode.titlebar:not(headerbar) row.subtitle:backdrop:link, calendar:backdrop:selected, headerbar.selection-mode calendar.subtitle:backdrop:link, .selection-mode.titlebar:not(headerbar) calendar.subtitle:backdrop:link, button.button.sidebar-button:backdrop:selected { color: #7d7d7d; background-color: #d1d1d1; }

row:selected label, label:selected, headerbar.selection-mode row.subtitle:link label, headerbar.selection-mode label.subtitle:link, selection, .view:selected, .view text:selected, textview text:selected, iconview:selected, flowbox flowboxchild:selected, label:disabled selection, modelbutton.flat:selected, .menuitem.button.flat:selected, headerbar.selection-mode .view.subtitle:link, flowbox headerbar.selection-mode flowboxchild.subtitle:link, headerbar.selection-mode flowbox flowboxchild.subtitle:link, headerbar.selection-mode .flat.subtitle:link, popover.background checkbutton.flat:selected, popover.background radiobutton.flat:selected, popover.background checkbutton.button:selected, popover.background radiobutton.button:selected, row.activatable:selected, headerbar.selection-mode .activatable.subtitle:link, .selection-mode.titlebar:not(headerbar) .activatable.subtitle:link, row:selected, headerbar.selection-mode row.subtitle:link, .selection-mode.titlebar:not(headerbar) row.subtitle:link, calendar:selected, headerbar.selection-mode calendar.subtitle:link, .selection-mode.titlebar:not(headerbar) calendar.subtitle:link, button.button.sidebar-button:selected { color: #ffffff; outline-color: rgba(255, 255, 255, 0.3); }

row:selected label:backdrop, label:backdrop:selected, headerbar.selection-mode row.subtitle:link label:backdrop, headerbar.selection-mode label.subtitle:backdrop:link, selection:backdrop, .view:backdrop:selected, .view text:backdrop:selected, textview text:backdrop:selected, iconview:backdrop:selected, flowbox flowboxchild:backdrop:selected, label:disabled selection:backdrop, modelbutton.flat:backdrop:selected, .menuitem.button.flat:backdrop:selected, headerbar.selection-mode .view.subtitle:backdrop:link, flowbox headerbar.selection-mode flowboxchild.subtitle:backdrop:link, headerbar.selection-mode flowbox flowboxchild.subtitle:backdrop:link, headerbar.selection-mode .flat.subtitle:backdrop:link, popover.background checkbutton.flat:backdrop:selected, popover.background radiobutton.flat:backdrop:selected, popover.background checkbutton.button:backdrop:selected, popover.background radiobutton.button:backdrop:selected, headerbar.selection-mode .activatable.subtitle:backdrop:link, .selection-mode.titlebar:not(headerbar) .activatable.subtitle:backdrop:link, row:backdrop:selected, headerbar.selection-mode row.subtitle:backdrop:link, .selection-mode.titlebar:not(headerbar) row.subtitle:backdrop:link, calendar:backdrop:selected, headerbar.selection-mode calendar.subtitle:backdrop:link, .selection-mode.titlebar:not(headerbar) calendar.subtitle:backdrop:link, button.button.sidebar-button:backdrop:selected { color: #7d7d7d; }

.monospace { font-family: monospace; }

/********************** Touch Copy & Paste * */
cursor-handle { background-color: transparent; background-image: none; box-shadow: none; border-style: none; }

cursor-handle.top:dir(ltr), cursor-handle.bottom:dir(rtl) { -gtk-icon-source: -gtk-scaled(url("assets/text-select-start.png"), url("assets/text-select-start@2.png")); padding-left: 10px; }

cursor-handle.bottom:dir(ltr), cursor-handle.top:dir(rtl) { -gtk-icon-source: -gtk-scaled(url("assets/text-select-end.png"), url("assets/text-select-end@2.png")); padding-right: 10px; }

cursor-handle.insertion-cursor:dir(ltr), cursor-handle.insertion-cursor:dir(rtl) { -gtk-icon-source: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above.png"), url("assets/slider-horz-scale-has-marks-above@2.png")); }

cursor-handle.top:hover:dir(ltr), cursor-handle.bottom:hover:dir(rtl) { -gtk-icon-source: -gtk-scaled(url("assets/text-select-start-hover.png"), url("assets/text-select-start-hover@2.png")); padding-left: 10px; }

cursor-handle.bottom:hover:dir(ltr), cursor-handle.top:hover:dir(rtl) { -gtk-icon-source: -gtk-scaled(url("assets/text-select-end-hover.png"), url("assets/text-select-end-hover@2.png")); padding-right: 10px; }

cursor-handle.insertion-cursor:hover:dir(ltr), cursor-handle.insertion-cursor:hover:dir(rtl) { -gtk-icon-source: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above-hover.png"), url("assets/slider-horz-scale-has-marks-above-hover@2.png")); }

cursor-handle.top:active:dir(ltr), cursor-handle.bottom:active:dir(rtl) { -gtk-icon-source: -gtk-scaled(url("assets/text-select-start-active.png"), url("assets/text-select-start-active@2.png")); padding-left: 10px; }

cursor-handle.bottom:active:dir(ltr), cursor-handle.top:active:dir(rtl) { -gtk-icon-source: -gtk-scaled(url("assets/text-select-end-active.png"), url("assets/text-select-end-active@2.png")); padding-right: 10px; }

cursor-handle.insertion-cursor:active:dir(ltr), cursor-handle.insertion-cursor:active:dir(rtl) { -gtk-icon-source: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above-active.png"), url("assets/slider-horz-scale-has-marks-above-active@2.png")); }

.context-menu { font: initial; }

button.circular { border-radius: 9999px; -gtk-outline-radius: 9999px; }

button.circular label { padding: 0; }

.keycap { min-width: 20px; min-height: 25px; margin-top: 2px; padding-bottom: 3px; padding-left: 6px; padding-right: 6px; color: #3c3c3c; background-color: #fcfcfc; border: 1px solid; border-color: #a8a8a8; border-radius: 5px; box-shadow: inset 0 -3px #d7d7d7; font-size: smaller; }

.keycap:backdrop { background-color: #f9f9f9; color: #858585; transition: 200ms ease-out; }

:not(decoration):not(window):drop(active):focus-within, :not(decoration):not(window):drop(active), dropdown:drop(active) button.combo:not(window), combobox:drop(active) button.combo:not(window) { border-color: #4e9a06; box-shadow: inset 0 0 0 1px #4e9a06; caret-color: #4e9a06; }

stackswitcher > button.text-button { min-width: 100px; }

stackswitcher.circular { border-spacing: 12px; }

stackswitcher.circular > button.circular, stackswitcher.circular > button.text-button.circular { min-width: 32px; min-height: 32px; padding: 0; }

/************* App Icons * */
/* Outline for low res icons */
.lowres-icon { -gtk-icon-shadow: 0 -1px rgba(0, 0, 0, 0.05), 1px 0 rgba(0, 0, 0, 0.1), 0 1px rgba(0, 0, 0, 0.3), -1px 0 rgba(0, 0, 0, 0.1); }

/* Dropshadow for large icons */
.icon-dropshadow { -gtk-icon-shadow: 0 1px 12px rgba(0, 0, 0, 0.05), 0 -1px rgba(0, 0, 0, 0.05), 1px 0 rgba(0, 0, 0, 0.1), 0 1px rgba(0, 0, 0, 0.3), -1px 0 rgba(0, 0, 0, 0.1); }

/********* Emoji * */
popover.emoji-picker { padding-left: 0; padding-right: 0; }

popover.emoji-picker entry.search { margin: 3px 5px 5px 5px; }

button.emoji-section { border-color: transparent; border-width: 3px; border-style: none none solid; border-radius: 0; margin: 2px 4px 2px 4px; padding: 3px 0 0; min-width: 32px; min-height: 28px; /* reset props inherited from the button style */ background: none; box-shadow: none; text-shadow: none; outline-offset: -5px; }

button.emoji-section:first-child, dropdown.linked button.emoji-section:nth-child(2):dir(rtl), combobox.linked button.emoji-section:nth-child(2):dir(rtl), .linked:not(.vertical) > combobox:first-child > box > button.emoji-section.combo, .linked.vertical > combobox:first-child > box > button.emoji-section.combo { margin-left: 7px; }

button.emoji-section:last-child, dropdown.linked button.emoji-section:nth-child(2):dir(ltr), combobox.linked button.emoji-section:nth-child(2):dir(ltr), .linked:not(.vertical) > combobox:last-child > box > button.emoji-section.combo, .linked.vertical > combobox:last-child > box > button.emoji-section.combo { margin-right: 7px; }

button.emoji-section:backdrop:not(:checked) { border-color: transparent; }

button.emoji-section:hover { border-color: #828282; }

button.emoji-section:checked { border-color: #398ee7; }

button.emoji-section label { padding: 0; opacity: 0.55; }

button.emoji-section:hover label { opacity: 0.775; }

button.emoji-section:checked label { opacity: 1; }

popover.emoji-picker .emoji { font-size: x-large; padding: 6px; }

popover.emoji-picker .emoji :hover { background: #398ee7; border-radius: 6px; }

popover.emoji-completion arrow { border: none; background: none; }

popover.emoji-completion contents row box { padding: 2px 10px; }

popover.emoji-completion .emoji:hover { background: #398ee7; }

/* GTK NAMED COLORS ---------------- use responsibly! */
/*
widget text/foreground color */
@define-color theme_fg_color #3c3c3c;
/*
text color for entries, views and content in general */
@define-color theme_text_color #212121;
/*
widget base background color */
@define-color theme_bg_color #cecece;
/*
text widgets and the like base background color */
@define-color theme_base_color #fcfcfc;
/*
base background color of selections */
@define-color theme_selected_bg_color #398ee7;
/*
text/foreground color of selections */
@define-color theme_selected_fg_color #ffffff;
/*
base background color of insensitive widgets */
@define-color insensitive_bg_color #e0e0e0;
/*
text foreground color of insensitive widgets */
@define-color insensitive_fg_color #858585;
/*
insensitive text widgets and the like base background color */
@define-color insensitive_base_color #fcfcfc;
/*
widget text/foreground color on backdrop windows */
@define-color theme_unfocused_fg_color #858585;
/*
text color for entries, views and content in general on backdrop windows */
@define-color theme_unfocused_text_color #212121;
/*
widget base background color on backdrop windows */
@define-color theme_unfocused_bg_color #cecece;
/*
text widgets and the like base background color on backdrop windows */
@define-color theme_unfocused_base_color #f9f9f9;
/*
base background color of selections on backdrop windows */
@define-color theme_unfocused_selected_bg_color #398ee7;
/*
text/foreground color of selections on backdrop windows */
@define-color theme_unfocused_selected_fg_color #ffffff;
/*
widgets main borders color */
@define-color borders #828282;
/*
widgets main borders color on backdrop windows */
@define-color unfocused_borders #898989;
/*
these are pretty self explicative */
@define-color warning_color #f57900;
@define-color error_color #cc0000;
@define-color success_color #4e9a06;
/*
these colors are exported for the window manager and shouldn't be used in applications,
read if you used those and something break with a version upgrade you're on your own... */
@define-color wm_title shade(#3c3c3c, 1.8);
@define-color wm_unfocused_title #858585;
@define-color wm_highlight rgba(255, 255, 255, 0.8);
@define-color wm_borders_edge rgba(255, 255, 255, 0.8);
@define-color wm_bg_a shade(#cecece, 1.2);
@define-color wm_bg_b #cecece;
@define-color wm_shadow alpha(black, 0.35);
@define-color wm_border alpha(black, 0.18);
@define-color wm_button_hover_color_a shade(#cecece, 1.3);
@define-color wm_button_hover_color_b #cecece;
@define-color wm_button_active_color_a shade(#cecece, 0.85);
@define-color wm_button_active_color_b shade(#cecece, 0.89);
@define-color wm_button_active_color_c shade(#cecece, 0.9);
@define-color content_view_bg #fcfcfc;
